globals
[
  clock tick-length          ;; clock variables
  box-x box-y                ;; patch coords of box's upper right corner
  total-particle-number
  maxparticles
  show-dark?
]

breeds [ particles ]

particles-own
[
  speed mass                 ;; particle info
  last-collision
  darkparticle?
]

to setup
  ca
  set show-dark? false
  set-default-shape particles "circle"
  set clock 0
  set maxparticles 400
  ;; starting this at zero means that no particles will move until we've
  ;; calculated vsplit, which we won't even try to do until there are some
  ;; particles.
  set tick-length 0
  set total-particle-number 0
  create-particles maxparticles 0 0
end

to go
  if bounce? [ ask particles [ bounce ] ] ;; all particles bounce
  ask particles [ move ]         ;; all particles move
  if collide?
    [
      ask particles
	      [
	        without-interruption
	          [ check-for-particlecollision ]
	      ]
	  ]
  set clock clock + tick-length
  ;; we need to check this down here as well, because if there are no
  ;; particles left, trying to set the new tick-length will cause an error...
  set tick-length 1 / (ceiling max values-from particles [speed])
end

to bounce  ;; particle procedure
  ;; if we're not about to hit a wall (yellow patch), or if we're already on a
  ;; wall, we don't need to do any further checks
  if pcolor = yellow or pcolor-of patch-at dx dy != yellow [ stop ]
  ;; get the coordinates of the patch we'll be on if we go forward 1
  let new-px round (xcor + dx)
  let new-py round (ycor + dy)
  ;; if hitting left or right wall, reflect heading around x axis
  if (abs new-px = box-x)
    [ set heading (- heading) ]
  ;; if hitting top or bottom wall, reflect heading around y axis
  if (abs new-py = box-y)
    [ set heading (180 - heading) ]
end

to move  ;; particle procedure
  let next-patch patch-ahead (speed * tick-length)
  ;; die if we're about to wrap...
  if ((pxcor != 0 and (pxcor-of next-patch) = (- pxcor)) or
      (pycor != 0 and (pycor-of next-patch) = (- pycor)))
    [ set darkparticle? true ifelse show-dark? [set shape "dark" set color red][set shape "nothing" set color green]]
  if next-patch != patch-here
    [ set last-collision nobody ]
  jump (speed * tick-length)
end

to check-for-particlecollision ;; particle procedure
  if count other-particles-here with [darkparticle? = darkparticle?-of myself ] >= 1
  [
    ;; the following conditions are imposed on collision candidates:
    ;;   1. they must have a lower who number than my own, because collision
    ;;      code is asymmetrical: it must always happen from the point of view
    ;;      of just one particle.
    ;;   2. they must not be the same particle that we last collided with on
    ;;      this patch, so that we have a chance to leave the patch after we've
    ;;      collided with someone.
    let candidate random-one-of other-particles-here with
      [who < who-of myself and myself != last-collision and darkparticle? = darkparticle?-of myself ]
    ;; we also only collide if one of us has non-zero speed. It's useless
    ;; (and incorrect, actually) for two particles with zero speed to collide.
    if (candidate != nobody) and (speed > 0 or speed-of candidate > 0)
    [
      collide-with candidate
      set last-collision candidate
      set last-collision-of candidate self
    ]
  ]
end

;; implements a collision with another particle.
;;
;; THIS IS THE HEART OF THE PARTICLE SIMULATION, AND YOU ARE STRONGLY ADVISED
;; NOT TO CHANGE IT UNLESS YOU REALLY UNDERSTAND WHAT YOU'RE DOING!
;;
;; The two particles colliding are self and other-particle, and while the
;; collision is performed from the point of view of self, both particles are
;; modified to reflect its effects. This is somewhat complicated, so I'll
;; give a general outline here:
;;   1. Do initial setup, and determine the heading between particle centers
;;      (call it theta).
;;   2. Convert the representation of the velocity of each particle from
;;      speed/heading to a theta-based vector whose first component is the
;;      particle's speed along theta, and whose second compenent is the speed
;;      perpendicular to theta.
;;   3. Modify the velocity vectors to reflect the effects of the collision.
;;      This involves:
;;        a. computing the velocity of the center of mass of the whole system
;;           along direction theta
;;        b. updating the along-theta components of the two velocity vectors.
;;   4. Convert from the theta-based vector representation of velocity back to
;;      the usual speed/heading representation for each particle.
;;   5. Perform final cleanup and update derived quantities.
to collide-with [ other-particle ] ;; particle procedure
  locals
  [
    ;; local copies of other-particle's relevant quantities
    mass2 speed2 heading2

    ;; quantities used in the collision itself
    theta   ;; heading of vector from my center to the center of other-particle.
    v1t     ;; velocity of self along direction theta
    v1l     ;; velocity of self perpendicular to theta
    v2t v2l ;; velocity of other-particle, represented in the same way
    vcm     ;; velocity of the center of mass of the colliding particles,
            ;;   along direction theta
  ]


  ;;; PHASE 1: initial setup

  ;; for convenience, grab some quantities from other-particle
  set mass2 mass-of other-particle
  set speed2 speed-of other-particle
  set heading2 heading-of other-particle

  ;; since particles are modeled as zero-size points, theta isn't meaningfully
  ;; defined. we can assign it randomly without affecting the model's outcome.
  set theta (random-float 360)


  ;;; PHASE 2: convert velocities to theta-based vector representation

  ;; now convert my velocity from speed/heading representation to components
  ;; along theta and perpendicular to theta
  set v1t (speed * cos (theta - heading))
  set v1l (speed * sin (theta - heading))

  ;; do the same for other-particle
  set v2t (speed2 * cos (theta - heading2))
  set v2l (speed2 * sin (theta - heading2))


  ;;; PHASE 3: manipulate vectors to implement collision

  ;; compute the velocity of the system's center of mass along theta
  set vcm (((mass * v1t) + (mass2 * v2t)) / (mass + mass2) )

  ;; now compute the new velocity for each particle along direction theta.
  ;; velocity perpendicular to theta is unaffected by a collision along theta,
  ;; so the next two lines actually implement the collision itself, in the
  ;; sense that the effects of the collision are exactly the following changes
  ;; in particle velocity.
  set v1t (2 * vcm - v1t)
  set v2t (2 * vcm - v2t)


  ;;; PHASE 4: convert back to normal speed/heading

  ;; now convert my velocity vector into my new speed and heading
  set speed sqrt ((v1t * v1t) + (v1l * v1l))
  ;; if the magnitude of the velocity vector is 0, atan is undefined. but
  ;; speed will be 0, so heading is irrelevant anyway. therefore, in that
  ;; case we'll just leave it unmodified.
  if v1l != 0 or v1t != 0
    [ set heading (theta - (atan v1l v1t)) ]

  ;; and do the same for other-particle
  set speed-of other-particle sqrt ((v2t * v2t) + (v2l * v2l))
  if v2l != 0 or v2t != 0
    [ set heading-of other-particle (theta - (atan v2l v2t)) ]

end

to recolor  ;; particle procedure
   ;; set color green
end

;;;
;;; drawing procedures
;;;

;; allows the user to place the box by clicking on one corner.
to place-box
  undraw-box
  set pcolor-of patch 0 0 grey
  while [not mouse-down?] [wait 0.01]
  set box-x (abs round mouse-xcor)
  set box-y (abs round mouse-ycor)
  if box-x <= 2 [set box-x 2]
  if box-y <= 2 [set box-y 2]
  draw-box

  while [mouse-down?] [wait 0.1]
  set pcolor-of patch 0 0 black
end

;; removes the box.
to undraw-box
  ask patches [ set pcolor black ]
end

;; draws a square yellow box at distance box-edge from the origin
to draw-box
  ask patches with [((abs pxcor = box-x) and (abs pycor <= box-y)) or
                    ((abs pycor = box-y) and (abs pxcor <= box-x))]
    [ set pcolor yellow ]
end

;; allows the user to place a particle using the mouse
to place-particles
  if mouse-down?
  [
    paint-particles number-of-particles-to-add mouse-xcor mouse-ycor
    while [mouse-down?] [wait 0.1]
  ]
end

;; places n particles in a cluster around point (x,y).
to create-particles [n x y]
  create-custom-particles n
  [
    set darkparticle? true
      ifelse show-dark? [set shape "dark" set color red][set shape "nothing" set color green]
    setxy ( 2 * random screen-edge-x) (2 *  random screen-edge-y)
    set speed 10
    set mass 2
    set heading random-float 360
    set last-collision nobody
    ;; if we're only placing one particle, use the exact position
    if n > 1
      [ jump random-float 5 ]
    ;;recolor
  ]
  set tick-length 1 / (ceiling max values-from particles [speed])
  set total-particle-number (count particles)
end

;; places n particles in a cluster around point (x,y).
to paint-particles [n x y]
   ifelse ( count particles with [ darkparticle? = true ] >= n )
   [
     ask random-n-of n particles with [darkparticle? = true]
     [
        set shape  "circle"
        setxy x y
        set speed 10
        set mass 2
        set color green
        set heading random-float 360
        set last-collision nobody
        set darkparticle? false
        ;; if we're only placing one particle, use the exact position
        if n > 1
        [ jump random-float 5 ]
        recolor
     ]
  ]
  [user-message "The maximum number of particles allowed in this model is " + maxparticles + ".  You can not add " + n +
  " more particles to the " + (count particles with [darkparticle? = false]) + " you already have in the model"]
  set tick-length 1 / (ceiling max values-from particles [speed])
  set total-particle-number (count particles)
end
@#$#@#$#@
GRAPHICS-WINDOW
236
10
458
253
26
26
4.0
1
10
1
1
1
0
1
1
1

CC-WINDOW
5
269
467
364
Command Center
0

MONITOR
15
206
96
255
clock
floor clock
0
1

SLIDER
14
47
227
80
number-of-particles-to-add
number-of-particles-to-add
1
50
10
1
1
NIL

BUTTON
14
124
89
157
go/stop
go
T
1
T
OBSERVER
T
NIL

BUTTON
14
10
89
43
NIL
setup
NIL
1
T
OBSERVER
T
NIL

SWITCH
14
163
124
196
collide?
collide?
1
1
-1000

SWITCH
127
163
231
196
bounce?
bounce?
1
1
-1000

MONITOR
101
206
230
255
Number
count particles
0
1

BUTTON
14
84
146
117
NIL
place-particles
T
1
T
OBSERVER
NIL
NIL

BUTTON
106
10
207
43
NIL
place-box
NIL
1
T
OBSERVER
T
NIL

@#$#@#$#@
(in this section of the interface, information about the model is usually provided)

You may freely download NetLogo at your home!
Go to our site: http://ccl.northwestern.edu/netlogo/

You can view models through a web browser as well:
http://ccl.northwestern.edu/netlogo/models/

This model is part of the Connected Chemistry high school curriculum.  Connected Chemistry is currently under development; for more information please refer to:
http://ccl.northwestern.edu/curriculum/chemistry/


CREDITS AND REFERENCES
----------------------
To refer to this model in academic publications, please use: Wilensky, U. (2002).  NetLogo P1_Bike_Tire model.  http://ccl.northwestern.edu/netlogo/models/P1_Bike_Tire.  Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.

In other publications, please use: Copyright 2002 by Uri Wilensky.  All rights reserved.  See http://ccl.northwestern.edu/netlogo/models/P1_Bike_Tire for terms of use.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

circle
false
0
Circle -7500403 true true 30 30 240

dark
true
0
Rectangle -7500403 true true 100 12 197 284

nothing
true
0

@#$#@#$#@
NetLogo 3.0beta1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@

