globals
[
  clock tick-length          ;; clock variables
  box-edge                   ;; distance of box edge from axes
  total-particle-number
  max-ever-speed current-max-speed
]

breeds [ particles ]

particles-own
[
  speed mass                 ;; particle info
  last-collision
]

to setup
  ca
  random-seed 10
  set-default-shape particles "circle"
  set clock 0
  ;; box has constant size...
  set box-edge (screen-edge-x - 1)
  make-box
  make-particles

;;  ask particles [recolor]
    ask particle 3 [ st set color orange]
end

to go
  locals [old-clock]
  ask particles [ bounce ]
  ask particles [ move ]
  ask particles
    [ ;; without-interruption is needed here so one collision is
      ;; happening at a time
      without-interruption
        [ check-for-collision ] ]
  set old-clock clock
  set clock clock + tick-length
  set current-max-speed (ceiling max values-from particles [speed])
  if (max-ever-speed < current-max-speed)
  [
    set max-ever-speed current-max-speed
    set tick-length 1 / max-ever-speed
  ]
;;  ifelse (clock < 6) [ ask patches [ if (pcolor != yellow) [ set pcolor black ]] ask turtles [ ht ] ask particle 3 [ st pu ]] [ ask turtles [ st ] ask particle 3 [ ]]
  ask turtles with [ abs xcor > 34 or abs ycor > 34 ] [die]
  wait 0.01
;;  if (clock > 12) [ set clock 0 ]
end

to bounce  ;; particle procedure
  locals [new-px new-py]
  ;; if we're not about to hit a wall (yellow patch), or if we're already on a
  ;; wall, we don't need to do any further checks
  if pcolor = yellow or pcolor-of patch-at dx dy != yellow
    [ stop ]
  ;; get the coordinates of the patch we'll be on if we go forward 1
  set new-px round (xcor + dx)
  set new-py round (ycor + dy)
  ;; if hitting left or right wall, reflect heading around x axis
  if (abs new-px = box-edge)
    [ set heading (- heading) ]
  ;; if hitting top or bottom wall, reflect heading around y axis
  if (abs new-py = box-edge)
    [ set heading (180 - heading) ]
end

to move  ;; particle procedure
  if patch-ahead (speed * tick-length) != patch-here
    [ set last-collision nobody ]
  jump (speed * tick-length)
end

to check-for-collision  ;; particle procedure
  locals [ candidate ]
  if count other-particles-here >= 1
  [
    ;; the following conditions are imposed on collision candidates:
    ;;   1. they must have a lower who number than my own, because collision
    ;;      code is asymmetrical: it must always happen from the point of view
    ;;      of just one particle.
    ;;   2. they must not be the same particle that we last collided with on
    ;;      this patch, so that we have a chance to leave the patch after we've
    ;;      collided with someone.
    set candidate random-one-of other-particles-here with
      [who < who-of myself and myself != last-collision]
    ;; we also only collide if one of us has non-zero speed. It's useless
    ;; (and incorrect, actually) for two particles with zero speed to collide.
    if (candidate != nobody) and (speed > 0 or speed-of candidate > 0)
    [
      collide-with candidate
      set last-collision candidate
      set last-collision-of candidate self
    ]
  ]
end

;; implements a collision with another particle.
;;
;; THIS IS THE HEART OF THE PARTICLE SIMULATION, AND YOU ARE STRONGLY ADVISED
;; NOT TO CHANGE IT UNLESS YOU REALLY UNDERSTAND WHAT YOU'RE DOING!
;;
;; The two particles colliding are self and other-particle, and while the
;; collision is performed from the point of view of self, both particles are
;; modified to reflect its effects. This is somewhat complicated, so I'll
;; give a general outline here:
;;   1. Do initial setup, and determine the heading between particle centers
;;      (call it theta).
;;   2. Convert the representation of the velocity of each particle from
;;      speed/heading to a theta-based vector whose first component is the
;;      particle's speed along theta, and whose second compenent is the speed
;;      perpendicular to theta.
;;   3. Modify the velocity vectors to reflect the effects of the collision.
;;      This involves:
;;        a. computing the velocity of the center of mass of the whole system
;;           along direction theta
;;        b. updating the along-theta components of the two velocity vectors.
;;   4. Convert from the theta-based vector representation of velocity back to
;;      the usual speed/heading representation for each particle.
;;   5. Perform final cleanup and update derived quantities.
to collide-with [ other-particle ] ;; particle procedure
  locals
  [
    ;; local copies of other-particle's relevant quantities
    mass2 speed2 heading2

    ;; quantities used in the collision itself
    theta   ;; heading of vector from my center to the center of other-particle.
    v1t     ;; velocity of self along direction theta
    v1l     ;; velocity of self perpendicular to theta
    v2t v2l ;; velocity of other-particle, represented in the same way
    vcm     ;; velocity of the center of mass of the colliding particles,
            ;;   along direction theta
  ]



  ;;; PHASE 1: initial setup

  ;; for convenience, grab some quantities from other-particle
  set mass2 mass-of other-particle
  set speed2 speed-of other-particle
  set heading2 heading-of other-particle

  ;; since particles are modeled as zero-size points, theta isn't meaningfully
  ;; defined. we can assign it randomly without affecting the model's outcome.
  set theta (random-float 360)



  ;;; PHASE 2: convert velocities to theta-based vector representation

  ;; now convert my velocity from speed/heading representation to components
  ;; along theta and perpendicular to theta
  set v1t (speed * cos (theta - heading))
  set v1l (speed * sin (theta - heading))

  ;; do the same for other-particle
  set v2t (speed2 * cos (theta - heading2))
  set v2l (speed2 * sin (theta - heading2))



  ;;; PHASE 3: manipulate vectors to implement collision

  ;; compute the velocity of the system's center of mass along theta
  set vcm (((mass * v1t) + (mass2 * v2t)) / (mass + mass2) )

  ;; now compute the new velocity for each particle along direction theta.
  ;; velocity perpendicular to theta is unaffected by a collision along theta,
  ;; so the next two lines actually implement the collision itself, in the
  ;; sense that the effects of the collision are exactly the following changes
  ;; in particle velocity.
  set v1t (2 * vcm - v1t)
  set v2t (2 * vcm - v2t)



  ;;; PHASE 4: convert back to normal speed/heading

  ;; now convert my velocity vector into my new speed and heading
  set speed sqrt ((v1t * v1t) + (v1l * v1l))
  ;; if the magnitude of the velocity vector is 0, atan is undefined. but
  ;; speed will be 0, so heading is irrelevant anyway. therefore, in that
  ;; case we'll just leave it unmodified.
  if v1l != 0 or v1t != 0
    [ set heading (theta - (atan v1l v1t)) ]

  ;; and do the same for other-particle
  set speed-of other-particle sqrt ((v2t * v2t) + (v2l * v2l))
  if v2l != 0 or v2t != 0
    [ set heading-of other-particle (theta - (atan v2l v2t)) ]



  ;; PHASE 5: final updates

  ;; now recolor, since color is based on quantities that may have changed
 ;; recolor
 ;; ask other-particle
 ;;   [ recolor ]
end

to recolor  ;; particle procedure
set color green
 ;; ifelse ( speed < (0.5 * 10) and speed > 0 )
 ;; [
;;    set color blue
 ;; ]
 ;; [
 ;;   ifelse speed > (1.5 * 10)
  ;;    [ set color red ]
;;      [ set color green ]
 ;; ]
end

;;;
;;; drawing procedures
;;;

;; draws the box
to make-box
  ask patches with [ ((abs pxcor = box-edge) and (abs pycor <= box-edge)) or
                     ((abs pycor = box-edge) and (abs pxcor <= box-edge)) ]
    [ set pcolor yellow ]
end

;; creates some particles
to make-particles
 set total-particle-number 200
  create-custom-particles 200
  [
    set speed random-float 20
    set mass 1.0
    set last-collision nobody
    random-position
    recolor
  ;;  ht
  ]
  set tick-length 1 / (ceiling max values-from particles [speed])
end

;; place particle at random location inside the box.
to random-position ;; particle procedure
  setxy ((1 - box-edge) + random-float ((2 * box-edge) - 2))
        ((1 - box-edge) + random-float ((2 * box-edge) - 2))
  set heading random-float 360
end

;; make turtles appear more like particles
to-report particle [n]
  report turtle n
end
@#$#@#$#@
GRAPHICS-WINDOW
3
10
257
285
30
30
4.0
1
10
1
1
1
0
1
1
1

CC-WINDOW
5
299
476
394
Command Center
0

BUTTON
390
12
467
45
go/stop
go
T
1
T
OBSERVER
T
NIL

BUTTON
332
12
387
45
NIL
setup
NIL
1
T
OBSERVER
T
NIL

@#$#@#$#@

@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

circle
false
0
Circle -7500403 true true 30 30 240

@#$#@#$#@
NetLogo 3.0beta1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
