globals
[
  clock tick-length          ;; clock variables
  box-edge                   ;; distance of box edge from axes
  message-shown?             ;; whether we've shown the warning message yet
  phase-two?
  pressure
	total-particle-number
]

breeds [ particles flashes spinner ]

flashes-own [birthday]

particles-own
[
  speed mass                 ;; particle info
  last-collision
 darkparticle?
]

;; message-shown? needs to be false initially...
to startup
  set message-shown? false
end

to setup
  locals [tmp]
  set tmp message-shown?
  ca
  set pressure 0
  set message-shown? tmp
  set-default-shape particles "circle"
  set-default-shape spinner "clock"
  set clock 0
  ;; box has constant size...
  set box-edge (screen-edge-x - 10)
  make-box
  make-particles 100
  set phase-two? false
end

to go
  locals [old-clock]
  ask particles [ bounce ]
  ask particles [ move ]
  ask particles with [darkparticle? = false]
    [ ;; without-interruption is needed here so one collision is
      ;; happening at a time
      without-interruption
	[ check-for-collision ] ]
 ask particles with [darkparticle? = false]
    [ check-world-edge ]
  set old-clock clock
  set clock clock + tick-length
  set tick-length 1 / (ceiling max values-from particles [speed])

  if not phase-two? and clock mod 8 >= 2
    [ make-hole-in-box
      set phase-two? true
      ask flashes [ set birthday 0 ]
      ]
  if phase-two? and clock mod 8 < 2
    [ patch-hole-in-box
      set phase-two? false ]

  ask flashes with [clock - birthday > 0.4]
    [ set pcolor yellow
      die ]

  if ((count (particles with [darkparticle? = false]) = 0) or (clock > 500))  [reset-particles set clock 0]
end

to check-world-edge
  if (((round abs xcor) = screen-edge-x) or ((round abs ycor) = screen-edge-y))
    [set shape "nothing" set darkparticle? true]
end

to make-hole-in-box
    ask patches with [ (pxcor = (-1 * box-edge)) and (abs pycor < 5) ] [ set pcolor black ]
    ask flashes with [ (pxcor = (-1 * box-edge)) and (abs pycor < 5) ] [die]
end

to patch-hole-in-box
    ask patches with [ (pxcor = (-1 * box-edge)) and (abs pycor < 5) ] [ set pcolor yellow ]
end

to bounce  ;; particle procedure
  locals [new-px new-py]
  ;; if we're not about to hit a wall (yellow patch), or if we're already on a
  ;; wall, we don't need to do any further checks
  if shade-of? yellow pcolor or not shade-of? yellow pcolor-of patch-at dx dy
    [ stop ]
  ;; get the coordinates of the patch we'll be on if we go forward 1
  set new-px round (xcor + dx)
  set new-py round (ycor + dy)
  ;; if hitting left or right wall, reflect heading around x axis
  if (abs new-px = box-edge)
    [ set heading (- heading) ]
  ;; if hitting top or bottom wall, reflect heading around y axis
  if (abs new-py = box-edge)
    [ set heading (180 - heading) ]
  ;; show collision in white
     if (darkparticle? = false) [
  ask patch new-px new-py
    [ sprout 1 [ ht
                 set breed flashes
                 set birthday clock
                 set pcolor yellow - 3 ] ]
                 ]
end

to move  ;; particle procedure
  if patch-ahead (speed * tick-length) != patch-here
    [ set last-collision nobody ]
  jump (speed * tick-length)
end

to check-for-collision  ;; particle procedure
  locals [ candidate ]
if (count other-particles-here with [darkparticle? = false] = 1) [

  if count other-particles-here >= 1
  [
    ;; the following conditions are imposed on collision candidates:
    ;;   1. they must have a lower who number than my own, because collision
    ;;      code is asymmetrical: it must always happen from the point of view
    ;;      of just one particle.
    ;;   2. they must not be the same particle that we last collided with on
    ;;      this patch, so that we have a chance to leave the patch after we've
    ;;      collided with someone.
    set candidate random-one-of other-particles-here with
      [who < who-of myself and myself != last-collision]
    ;; we also only collide if one of us has non-zero speed. It's useless
    ;; (and incorrect, actually) for two particles with zero speed to collide.
    if (candidate != nobody) and (speed > 0 or speed-of candidate > 0)
    [
      collide-with candidate
      set last-collision candidate
      set last-collision-of candidate self
    ]
  ]
    ]
end

;; implements a collision with another particle.
;;
;; THIS IS THE HEART OF THE PARTICLE SIMULATION, AND YOU ARE STRONGLY ADVISED
;; NOT TO CHANGE IT UNLESS YOU REALLY UNDERSTAND WHAT YOU'RE DOING!
;;
;; The two particles colliding are self and other-particle, and while the
;; collision is performed from the point of view of self, both particles are
;; modified to reflect its effects. This is somewhat complicated, so I'll
;; give a general outline here:
;;   1. Do initial setup, and determine the heading between particle centers
;;      (call it theta).
;;   2. Convert the representation of the velocity of each particle from
;;      speed/heading to a theta-based vector whose first component is the
;;      particle's speed along theta, and whose second compenent is the speed
;;      perpendicular to theta.
;;   3. Modify the velocity vectors to reflect the effects of the collision.
;;      This involves:
;;        a. computing the velocity of the center of mass of the whole system
;;           along direction theta
;;        b. updating the along-theta components of the two velocity vectors.
;;   4. Convert from the theta-based vector representation of velocity back to
;;      the usual speed/heading representation for each particle.
;;   5. Perform final cleanup and update derived quantities.
to collide-with [ other-particle ] ;; particle procedure
  locals
  [
    ;; local copies of other-particle's relevant quantities
    mass2 speed2 heading2

    ;; quantities used in the collision itself
    theta   ;; heading of vector from my center to the center of other-particle.
    v1t     ;; velocity of self along direction theta
    v1l     ;; velocity of self perpendicular to theta
    v2t v2l ;; velocity of other-particle, represented in the same way
    vcm     ;; velocity of the center of mass of the colliding particles,
            ;;   along direction theta
  ]



  ;;; PHASE 1: initial setup

  ;; for convenience, grab some quantities from other-particle
  set mass2 mass-of other-particle
  set speed2 speed-of other-particle
  set heading2 heading-of other-particle

  ;; since particles are modeled as zero-size points, theta isn't meaningfully
  ;; defined. we can assign it randomly without affecting the model's outcome.
  set theta (random-float 360)



  ;;; PHASE 2: convert velocities to theta-based vector representation

  ;; now convert my velocity from speed/heading representation to components
  ;; along theta and perpendicular to theta
  set v1t (speed * cos (theta - heading))
  set v1l (speed * sin (theta - heading))

  ;; do the same for other-particle
  set v2t (speed2 * cos (theta - heading2))
  set v2l (speed2 * sin (theta - heading2))



  ;;; PHASE 3: manipulate vectors to implement collision

  ;; compute the velocity of the system's center of mass along theta
  set vcm (((mass * v1t) + (mass2 * v2t)) / (mass + mass2) )

  ;; now compute the new velocity for each particle along direction theta.
  ;; velocity perpendicular to theta is unaffected by a collision along theta,
  ;; so the next two lines actually implement the collision itself, in the
  ;; sense that the effects of the collision are exactly the following changes
  ;; in particle velocity.
  set v1t (2 * vcm - v1t)
  set v2t (2 * vcm - v2t)



  ;;; PHASE 4: convert back to normal speed/heading

  ;; now convert my velocity vector into my new speed and heading
  set speed sqrt ((v1t * v1t) + (v1l * v1l))
  ;; if the magnitude of the velocity vector is 0, atan is undefined. but
  ;; speed will be 0, so heading is irrelevant anyway. therefore, in that
  ;; case we'll just leave it unmodified.
  if v1l != 0 or v1t != 0
    [ set heading (theta - (atan v1l v1t)) ]

  ;; and do the same for other-particle
  set speed-of other-particle sqrt ((v2t * v2t) + (v2l * v2l))
  if v2l != 0 or v2t != 0
    [ set heading-of other-particle (theta - (atan v2l v2t)) ]



  ;; PHASE 5: final updates

  ;; now recolor, since color is based on quantities that may have changed
  recolor
  ask other-particle
    [ recolor ]
end

to recolor  ;; particle procedure
  set color green
end

;;;
;;; drawing procedures
;;;

;; draws the box
to make-box
  ask patches with [ ((abs pxcor = box-edge) and (abs pycor <= box-edge)) or
                     ((abs pycor = box-edge) and (abs pxcor <= box-edge)) ]
    [ set pcolor yellow ]
end

;; creates some particles
to make-particles [number]
  create-custom-particles number
  [
    set speed random-float 20
    set mass 1.0
    set last-collision nobody
    random-position
       set darkparticle? false
 ;; set total-particle-number number-of-particles
    ask particles with [who <= number]
    [
    recolor
      ]
  ]
  set tick-length 1 / (ceiling max values-from particles [speed])
end

;; place particle at random location inside the box.
to random-position ;; particle procedure
  setxy ((1 - box-edge) + random-float ((2 * box-edge) - 2))
        ((1 - box-edge) + random-float ((2 * box-edge) - 2))
  set heading random-float 360
end

to reset-particles
 ask particles [set shape "circle" set darkparticle? false random-position]
end

;; make turtles appear more like particles
to-report particle [n]
  report turtle n
end

to make-spinner
  create-custom-spinner 1
  [
    setxy (screen-edge-x - 6) (screen-edge-y - 6)
    set color grey - 1.5
    set size 10
    set heading 0
    set label 0
  ]
end

; *** NetLogo Model Copyright Notice ***
;
; This activity and associated models and materials were created as part of the project:
; MODELING ACROSS THE CURRICULUM.  The project gratefully acknowledges the support of the
; National Science Foundation, National Institute of Health and the Department of Education
; (IERI program) -- grant number REC # 0115699. Additional support was provided through the
; project: PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN CLASSROOMS
; -- NSF (REPP program) -- grant number REC #9814682.
;
; Copyright 2004 by Uri Wilensky.  Updated 2004.  All rights reserved.
;
; Permission to use, modify or redistribute this model is hereby granted,
; provided that both of the following requirements are followed:
; a) this copyright notice is included.
; b) this model will not be redistributed for profit without permission
;    from Uri Wilensky.
; Contact Uri Wilensky for appropriate licenses for redistribution for
; profit.
;
; To refer to this model in academic publications, please use:
; Wilensky, U. (2004).  NetLogo P2 Movie 1 model.
; http://ccl.northwestern.edu/netlogo/models/P2_movie_1
; Center for Connected Learning and Computer-Based Modeling,
; Northwestern University, Evanston, IL.
;
; In other publications, please use:
; Copyright 1998 by Uri Wilensky.  All rights reserved.  See
; http://ccl.northwestern.edu/netlogo/models/ChemPressure2
; for terms of use.
;
; *** End of NetLogo Model Copyright Notice ***
@#$#@#$#@
GRAPHICS-WINDOW
3
10
257
285
30
30
4.0
1
10
1
1
1
0
1
1
1

CC-WINDOW
5
349
377
444
Command Center
0

BUTTON
211
302
288
335
go/stop
go
T
1
T
OBSERVER
T
NIL

BUTTON
153
302
208
335
NIL
setup
NIL
1
T
OBSERVER
T
NIL

MONITOR
311
52
368
101
NIL
clock
0
1

@#$#@#$#@

@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

circle
false
0
Circle -7500403 true true 30 30 240

clock
true
0
Circle -7500403 true true 30 30 240
Polygon -16777216 true false 150 31 128 75 143 75 143 150 158 150 158 75 173 75
Circle -16777216 true false 135 135 30

nothing
true
0

@#$#@#$#@
NetLogo 3.0beta1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
