globals [
  clock        ;; how many ticks have passed
  key-patches  ;; these are the patches where the aggregate indicators are centered
]

breeds [
  particles    ;; the individual fluid particles
  indicators   ;; yellow arrows that show the average of particles in a region
]

indicators-own [
  region       ;; agentset of the patches this indicator covers
]

to setup
  ca
  set-default-shape particles "particle"
  set-default-shape indicators "arrow"
  set clock 0
  ;; create the indicator turtles
  ask patches with [pxcor mod aggregate-size = 0 and
                    pycor mod aggregate-size = 0]
    [ sprout 1
        [ set breed indicators
          set color yellow
          set size 0
          set region (patches in-radius (ceiling ((sqrt 2) * floor (aggregate-size / 2))))
                       with [abs (pxcor - pxcor-of myself) <= floor (aggregate-size / 2) and
                             abs (pycor - pycor-of myself) <= floor (aggregate-size / 2)] ] ]
  ask indicators
    [ update-indicator ]
  ;; create the walls
  ask patches with [abs pycor = screen-edge-y]
    [ set pcolor gray ]
  ;; create the obstacle
  ask patches with [pxcor = round (-0.5 * screen-edge-x) and
                    pycor > -0.2 * screen-edge-y and
                    pycor <  0.2 * screen-edge-y]
    [ set pcolor white ]
  ;; initially fill the space
  ;; (commented out for now since it doesn't affect result)
  ; ask patches with [random-float 1.0 < density]
  ;  [ sprout 1
  ;      [ setup-particle
  ;        set heading 30 + 60 * random 6 ] ]
end

to setup-particle  ;; turtle procedure
  set breed particles
  set color blue - 1 + random 4
  ;; every other row is offset right by half a patch.  since
  ;; patches include their west boundaries, this doesn't move
  ;; them to a different patch
  if pycor mod 2 = 0
    [ set xcor xcor - 0.5 ]
  if not show-particles?
    [ hide-turtle ]
end

to go
  no-display
  ;; bring in new particles from the left
  ask patches with [pxcor = (- screen-edge-x) and
                    abs pycor < screen-edge-y and
                    random-float 1.0 < influx-density]
    [ sprout 1
        [ setup-particle
          set heading random-one-of [30 90 150] ] ]
  ;; move the particles;
  ;; particles which hit the right or left edge disappear
  ask particles
    [ if not shade-of? color blue
        [ set color color + 40 ]
      move-on-lattice
      if abs pxcor = screen-edge-x
        [ die ] ]
  ;; apply the rotation rule
  ask patches
    [ if (pcolor = black) and momentum-sum-zero?
        [ ask particles-here
            [ lt 60
              set color color - 40 ] ] ]
  ;; update the indicators
  without-interruption ;; for speed
    [ ask indicators
        [ update-indicator ] ]
  ;; check the show-particles? switch
  ifelse show-particles?
    [ ask particles [ st ] ]
    [ ask particles [ ht ] ]
  ;; increment the clock
  set clock clock + 1
  display
end

;; this is used in the rotation rule
to-report momentum-sum-zero?  ;; patch procedure
  report (abs sum values-from particles-here [sin heading] < 0.000001)
         and
         (abs sum values-from particles-here [cos heading] < 0.000001)
end

to move-on-lattice  ;; particle procedure
  setxy (xcor + item floor (heading / 60) [0.5 1 0.5 -0.5 -1 -0.5])
        (ycor + item floor (heading / 60) [1 0 -1 -1 0 1])
  if pcolor != black
    [ ifelse pcolor = white
        ;; bounce off obstacle
        [ set heading (- heading) ]
        ;; bounce off wall
        [ set heading 180 - heading ] ]
end

to update-indicator  ;; indicator procedure
  ;; compute the resultant of all the particles in our region,
  ;; considered as vectors
  let x-sum sum values-from (particles-on region) [sin heading]
  let y-sum sum values-from (particles-on region) [cos heading]
  let magnitude sqrt (x-sum ^ 2 + y-sum ^ 2)
  ;; scale the arrow to make it a nice reasonable size for viewing
  set size magnitude * (aggregate-size / count region) / influx-density
  ;; set the heading, if there is one
  if (x-sum != 0) or (y-sum != 0)
    [ set heading atan x-sum y-sum ]
end
@#$#@#$#@
GRAPHICS-WINDOW
240
10
1920
871
83
41
10.0
1
10
1
1
1
0

CC-WINDOW
5
885
1929
980
Command Center

BUTTON
83
10
146
43
NIL
setup
NIL
1
T
OBSERVER
T
NIL

BUTTON
117
50
185
83
NIL
go
T
1
T
OBSERVER
T
NIL

BUTTON
35
50
112
83
step
go
NIL
1
T
OBSERVER
T
NIL

MONITOR
68
172
157
221
NIL
clock
3
1

SLIDER
28
129
200
162
aggregate-size
aggregate-size
1
21
9
2
1
NIL

MONITOR
59
267
164
316
density
count particles / count patches
3
1

SLIDER
29
93
201
126
influx-density
influx-density
0
1.0
0.5
0.01
1
NIL

SWITCH
36
230
191
263
show-particles?
show-particles?
0
1
-1000

@#$#@#$#@
WHAT IS IT?
-----------
This is a model of flow in a fluid.  The fluid contains an obstacle.  When the fluid hits the obstacle, turbulent eddies should be created behind the obstacle (as shown in the pictures in the Kadanoff and Wolfram references; see CREDITS AND REFERENCES, below).
That doesn't happen yet; we're still working on it.

The following changes are needed:

- the world may need to be a lot larger

- we need to figure out how the obstacle should be shaped and how it should function -- that may not be right yet

- we may need to have a different method of introducing new particles: we're not sure what density to use, and whether to give them all uniform orientation or randomize them somehow (and if so how)


HOW IT WORKS
------------
We treat the square lattice as if it were a triangle lattice, as follows.  Particles on even patch rows are offset left by half a patch.  (Since the west boundary of a patch is inside the patch, this does not move the particles to a different patch.)  The resulting hexagons aren't regular, but it doesn't matter as long as the particles move forward not using "fd 1" but using our special "iso-fd" procedure.

The rules for the particles are:
1) move forward to next vertex
2) then, at each vertex, if the resultant of the particles' headings is zero, then all the particles turn left 60 degrees

Particles that hit the obstacle or the walls reflect specularly (as a light beam off a mirror or a billiard ball off a cushion).

To make the aggregate behavior visible, we divide the grid up into sections, whose size is determined by the AGGREGATE-SIZE slider.  The big yellow arrows show the resultant heading of all the particles located in their section.


CREDITS AND REFERENCES
----------------------
This is based on a model presented at the NU Complexity Conference on October 24, 2003 by Leo P. Kadanoff, professor of physics and mathematics at the University of Chicago.  The model is also described in his article "On two levels" (Physics Today, September 1986).

A slightly different version of the model is given in Stephen Wolfram's book "A New Kind of Science", on and around page 378.  The rule diagrams on page 378 don't jibe with Kadanoff's description, which is why I say that Wolfram is presenting a different version, although the outcomes seem similar.  Note that we can't figure out from Wolfram's diagrams what rules he is actually proposing.  Wolfram doesn't explain it enough and the diagrams seem to underspecify the rules.  The model is not included in the NKS Explorer software that can be purchased as a companion for the book.

Nonetheless, Wolfram's book is helpful at explaining what kind of initial setup you should have and what results you should expect to see.

Kadanoff's article says that the model was "originally proposed by J. Hard, O. de Pazzis and Yves Pompeau", but he does not give a specific reference for that (though, see the Pomeau reference below).  He also says "For some more recent papers on the version of this model discussed here, see the references on page 9."  Those references are:

- U. Frisch, B. Hasslacher, Y. Pomeau, Phys. Rev. Lett. 56, 1505 (1986)
- S. Orszag, V. Yakhot, Phys. Rev. Lett. 56, 1691 (1986)
- N. Margolis, T. Toffoli, G. Vichniac, Phys. Rev. Lett. 56, 1694 (1986).
- J. Salem, S. Wolfram, in Theory and Applications of Cellular Automata, S. Wolfram, ed., World Scientific, Singapore (1986), p. 362.

Eric Betzold got us copies of these, but we haven't actually read these yet.

The last of the above is available online at:
http://www.stephenwolfram.com/publications/articles/ca/85-thermodynamics/

Another Wolfram paper online that discusses this model is:
http://www.stephenwolfram.com/publications/articles/ca/86-fluids/
@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7566196 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7566196 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7566196 true true 150 285 285 225 285 75 150 135
Polygon -7566196 true true 150 135 15 75 150 15 285 75
Polygon -7566196 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7566196 true true 96 182 108
Circle -7566196 true true 110 127 80
Circle -7566196 true true 110 75 80
Line -7566196 true 150 100 80 30
Line -7566196 true 150 100 220 30

butterfly
true
0
Polygon -7566196 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7566196 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7566196 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7566196 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7566196 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7566196 true true 47 195 58
Circle -7566196 true true 195 195 58

circle
false
0
Circle -7566196 true true 0 0 300

circle 2
false
0
Circle -7566196 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7566196 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7566196 true true 73 210 86 251 62 249 48 208
Polygon -7566196 true true 25 114 16 195 9 204 23 213 25 200 39 123

face happy
false
0
Circle -7566196 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7566196 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7566196 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7566196 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7566196 true true 60 15 75 300
Polygon -7566196 true true 90 150 270 90 90 30
Line -7566196 true 75 135 90 135
Line -7566196 true 75 45 90 45

flower
false
0
Polygon -11352576 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7566196 true true 85 132 38
Circle -7566196 true true 130 147 38
Circle -7566196 true true 192 85 38
Circle -7566196 true true 85 40 38
Circle -7566196 true true 177 40 38
Circle -7566196 true true 177 132 38
Circle -7566196 true true 70 85 38
Circle -7566196 true true 130 25 38
Circle -7566196 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -11352576 true false 189 233 219 188 249 173 279 188 234 218
Polygon -11352576 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7566196 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7566196 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7566196 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7566196 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7566196 true 150 0 150 300

particle
true
0
Line -7566196 true 150 150 150 0
Line -7566196 true 121 23 180 23

pentagon
false
0
Polygon -7566196 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7566196 true true 110 5 80
Polygon -7566196 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7566196 true true 127 79 172 94
Polygon -7566196 true true 195 90 240 150 225 180 165 105
Polygon -7566196 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7566196 true true 135 90 165 300
Polygon -7566196 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7566196 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7566196 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7566196 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7566196 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7566196 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7566196 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7566196 true true 30 30 270 270

square 2
false
0
Rectangle -7566196 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7566196 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7566196 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7566196 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7566196 true true 120 120 60

tree
false
0
Circle -7566196 true true 118 3 94
Rectangle -6524078 true false 120 195 180 300
Circle -7566196 true true 65 21 108
Circle -7566196 true true 116 41 127
Circle -7566196 true true 45 90 120
Circle -7566196 true true 104 74 152

triangle
false
0
Polygon -7566196 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7566196 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7566196 true true 4 45 195 187
Polygon -7566196 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7566196 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7566196 false true 24 174 42
Circle -7566196 false true 144 174 42
Circle -7566196 false true 234 174 42

turtle
true
0
Polygon -11352576 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -11352576 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -11352576 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -11352576 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -11352576 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7566196 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7566196 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7566196 true 150 285 150 15
Line -7566196 true 15 150 285 150
Circle -7566196 true true 120 120 60
Line -7566196 true 216 40 79 269
Line -7566196 true 40 84 269 221
Line -7566196 true 40 216 269 79
Line -7566196 true 84 40 221 269

x
false
0
Polygon -7566196 true true 270 75 225 30 30 225 75 270
Polygon -7566196 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 2.1beta4
@#$#@#$#@
setup
repeat screen-size-x [ go ]
@#$#@#$#@
@#$#@#$#@
