globals [
  jumps   ;; the total number of jumps that have occurred
  diff    ;; used by the bottom plot to determine when to update
]

patches-own [
  neighborhood    ;; a cached no-wrapping neighborhood of patches
]

breeds [
  reds    ;; red atoms are on the left
  blues   ;; blue atoms are on the right
]

to setup
  ca
  set-default-shape turtles "circle"
  ;; set up patch neighborhoods to disallow wrapping around
  ;; the edges of the screen
  ask patches
    [ set neighborhood neighbors4 with [distance-nowrap myself = 1] ]
  ;; make appropriate atoms on left and right
  ask patches with [pxcor != 0]
    [ sprout 1
        [ ifelse (pxcor < 0)
            [ set breed reds
              set color red ]
            [ set breed blues
              set color blue ] ] ]
  set jumps 0
  set diff 1000
  ;; plot the initial state of the system
  setup-plot
  update-plot
end

to go
  ;; change the empty patches on the left
  every (left-delay / 100)
  [
    ask patches with [not any? turtles-here and pxcor <= 0]
      [ set jumps jumps + 1
        move-atom-to-here ]
  ]
  ;; change the empty patches on the right
  every (right-delay / 100)
  [
    ask patches with [not any? turtles-here and pxcor > 0]
      [ set jumps jumps + 1
        move-atom-to-here ]
  ]
  ;; update the top plot
  every 1
    [ update-plot ]
  ;; update the bottom plot only when this is true
  if ( jumps > diff )
    [ plot-diffusion
      set diff diff + 1000 ]
end

;; chooses a neighboring atom to move onto a empty patch
to move-atom-to-here  ;; patch procedure
  let atom random-one-of turtles-on neighborhood
  if ( atom != nobody )
    [ ask atom
        [ setxy (pxcor-of myself) (pycor-of myself) ] ]
end

;;; plotting procedures

to setup-plot
  set-current-plot "Atoms By Column"
  set-plot-x-range (- screen-edge-x) (screen-edge-x + 1)
  set-plot-y-range 0 screen-size-y
  set-current-plot "Max Diffusion Distance"
  set-plot-x-range 0 100
  set-plot-y-range 0 700
end

;; updates the top plot
to update-plot
  set-current-plot "Atoms By Column"
  set-current-plot-pen "Reds"
  plot-atoms reds
  set-current-plot-pen "Blues"
  plot-atoms blues
end

to plot-atoms [atoms]
  plot-pen-reset
  ppu
  let column (- screen-edge-x)
  repeat screen-size-x
    [ plotxy column
             count atoms with [pxcor = column]
      ppd
      plotxy column + 1
             count atoms with [pxcor = column]
      set column column + 1 ]
end

;; updates the bottom plot
to plot-diffusion
  set-current-plot "Max Diffusion Distance"
  plot (value-from max-one-of reds [ pxcor ] [ pxcor ] - value-from min-one-of blues [ pxcor ] [ pxcor ]) ^ 2
end


; *** NetLogo Model Copyright Notice ***
;
; This model was created as part of the projects:
; PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN
; CLASSROOMS and INTEGRATED SIMULATION AND MODELING ENVIRONMENT.
; The project gratefully acknowledges the support of the
; National Science Foundation (REPP & ROLE programs) -- grant numbers
; REC #9814682 and REC-0126227.
;
; Copyright 2004 by Uri Wilensky.  Updated 2004.  All rights reserved.
;
; Permission to use, modify or redistribute this model is hereby granted,
; provided that both of the following requirements are followed:
; a) this copyright notice is included.
; b) this model will not be redistributed for profit without permission
;    from Uri Wilensky.
; Contact Uri Wilensky for appropriate licenses for redistribution for
; profit.
;
; To refer to this model in academic publications, please use:
; Wilensky, U. (2004).  NetLogo Solid Diffusion model.
; http://ccl.northwestern.edu/netlogo/models/SolidDiffusion.
; Center for Connected Learning and Computer-Based Modeling,
; Northwestern University, Evanston, IL.
;
; In other publications, please use:
; Copyright 2004 Uri Wilensky.  All rights reserved.
; See http://ccl.northwestern.edu/netlogo/models/SolidDiffusion
; for terms of use.
;
; *** End of NetLogo Model Copyright Notice ***
@#$#@#$#@
GRAPHICS-WINDOW
310
10
740
461
17
17
12.0
0
10
1
1
1
0
1
1
1

CC-WINDOW
5
547
749
642
Command Center
0

BUTTON
30
24
93
58
NIL
setup
NIL
1
T
OBSERVER
T
NIL

BUTTON
106
24
169
57
NIL
go
T
1
T
OBSERVER
T
NIL

PLOT
10
128
294
339
Atoms By Column
NIL
NIL
-1.0
1.0
0.0
1.0
false
false
PENS
"Reds" 1.0 0 -2674135 true
"Blues" 1.0 0 -13345367 true

SLIDER
10
80
147
113
left-delay
left-delay
0
10
0
1
1
NIL

SLIDER
154
80
293
113
right-delay
right-delay
0
10
0
1
1
NIL

MONITOR
194
17
294
66
NIL
Jumps
0
1

PLOT
13
342
290
533
Max Diffusion Distance
K Jumps
Max Distance Squared
0.0
100.0
0.0
700.0
true
false

@#$#@#$#@
WHAT IS IT?
-----------
Diffusion is the phenomenon of the transport of material through atomic motions.  It can occur in the gas, liquid, and solid state of matter.  This model describes how diffusion occurs between two adjacent solids.  In particular, it demonstrates a diffusion couple.  An example of this would be Copper and Nickel.  To increase the motion of the particles, the sample would be heated to increase the kinetic energy or vibrations of the atoms.

This type of diffusion uses vacancy diffusion, which is caused by imperfections in the metal crystal.  These imperfections in this model consist of vacancies or missing atoms in the lattice.  The extent to which the diffusion can happen depends on the number of defects in the crystal.

In addition, there are various other conditions that are needed for solid diffusion to take place.  Some examples of these are similar atomic size, similar crystal structure, and similar electronegativity.


HOW IT WORKS
------------
There are two type of metal atoms - red and blue.  At the beginning all red atoms are to left of the center and all the blue atoms are to the right.  Although this is incorrect model of reality, all the vacancies start out between the two metals, and disperse after the model runs.

There are two main rules for how an atom can move to a new location.
- There needs to be an empty neighbor
- It needs to have enough energy to break the bonds with its current neighbors.

In this model we assume that the heat is evenly distributed throughout the metal.  Therefore, each atom has an equal chance of breaking bonds with its neighbors.  We simulate the second rule by varying the time it takes for atoms to jump to a new location (The longer it takes, the cooler the metal is).


HOW TO USE IT
-------------
To run the model- First press the SETUP button, then press the GO button.  This will cause the model to run.  The "Atoms by Column" graph is a distribution diagram of the two atom types.  This graph is updated every second.  The other graph is a maximum diffusion distance squared versus number of jumps.  This is updated every 1000 jumps.  Finally, there are two sliders - LEFT-DELAY and RIGHT-DELAY.  They will slow down the jump frequency for a particular side.  This will simulate temperature decreases.


THINGS TO NOTICE
----------------
If you run the model for about a minute, the distribution graph should look like two interleaving curves.  The extremities should be pure one metal, while the middle is about 50-50.  The other graph should be generally linear.  If you convert distance to atomic distance and jumps to time, it would be easy to determine the Diffusion Coefficient of the metal by diving the slope by two.

One thing to notice is that the vacancies are limited to the screen.  They will never wrap around the screen.  What would happen if they did?


THINGS TO TRY
-------------
Try changing the delay for one of the sides.  Is the diffusion symmetrical?

Try turning off the display for a long time.  Do you think it will ever become completely diffused?

Try increasing the dimensions of the graphics window.  Does the behavior change at all?


EXTENDING THE MODEL
-------------------
Vacancies are always fixed by the screen-size-y.  Try making a slider that dictates how many vacancies there are and in which metal they start out in.

Try changing the crystal structure of the atoms.  In close-packing atoms, atoms actually have 6 neighbors instead of 4 (hexagonal) in two dimensions.


NETLOGO FEATURES
----------------
Notice how this model achieves no wrapping by caching every patch's neighborhood during setup into a patch variable called NEIGHBORHOOD.  Later on in the model, it uses this variable instead of the nighbors4 primitive to avoid wrapping.  This is a quick and clean way to obtain this effect.


RELATED MODELS
--------------
Look at the GasLab models to learn more about atomic diffusion.


CREDITS AND REFERENCES
----------------------
To refer to this model in academic publications, please use: Wilensky, U. (2004). NetLogo Solid Diffusion model. http://ccl.northwestern.edu/netlogo/models/SolidDiffusion. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.

In other publications, please use: Copyright 2004 Uri Wilensky. All rights reserved. See http://ccl.northwestern.edu/netlogo/models/SolidDiffusion for terms of use.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 3.0beta2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
