;;**** Breed, Patch, Global Variables ****
breeds [
  People             ;; population of a city
  El                 ;; public transportation
]

El-own [prev-road#]  ;; the previous road id # that an el tracked upon

People-own [
  class              ;; "urbanites" or "suburbanites" or "ruralites"
  prev-class         ;; class from previous round

  pop-density-tol    ;; population density tolerance
  my-pop-density     ;; population density of surrounding home environment
  tol-diff           ;; difference b.w. pop-density-tol and pop-density

  home-x             ;; x-coordinate of a person's home
  home-y             ;; y-coordiante of a person's home

  commute-time       ;; length of time (of clock) to get to core

  density-multiple   ;; weight of population density in utility calculation
  time-multiple      ;; weight of commute time in utility calculation

  utility            ;; happiness
  prev-road#
  land-level         ;; 0 = urban; 1 = suburb; 2 = rural
]

patches-own [
  land-class         ;; string specifying whether land is "core", "urban", "suburb", or "rural"
  road#              ;; should a patch be a road, then it has road id #
  special-road?      ;; one patch with intersection with el tracks and hwy
]

globals [
  clock              ;; Count of number of cycles
  Avg-Utility        ;; Average Utility (Happiness) of the population

  Urban-Radius       ;; Radius length from the center (0,0) to edge of Urban area of city
  Suburb-Radius      ;; Radius length from the center (0,0) to edge of Suburb area of city

  Urban-pop          ;; Population in Urban Area
  Suburb-pop         ;; Population in Suburb Area
  Rural-pop          ;; Population in Rural Area

  el-radius          ;; radius from the origin where the el is located
  hwy-radius         ;; radius from the origin where the hwy is located

  hwy-revolution     ;; list of quadrant numbers how cars on hwy travel counter clockwise
  el-revolution      ;; list of quadrant numbers how el travels counter clockwise

  max-hwy            ;; the max hwy road id
  max-el-tracks      ;; the max el track id

  lowest-tol-diff
  highest-tol-diff
  highest-commute-time
  lowest-commute-time

  default-shape      ;; default shape of people

  rural-outskirt-dist ;; portion of rural-area inhabitable

  Urban-PopDen
  Suburb-PopDen
  Rural-PopDen

  ready-to-build?

  n/a                ;; initialization
]

;;**** Expermentation Run ****
to go
  if (Suburb-Radius = screen-edge-x) [stop]
  inc-clock
  ask el [operate]
  ifelse everyone-at-work?
    [perform-survey# 1
     ask people [
       do-utility-analysis
       move
       cyclic-setup
     ]
     ifelse greenbelt-policy
       [if (Suburb-Radius < GreenBelt-Radius)
          [extend-suburb-into-rural]
       ]
       [extend-suburb-into-rural]
     perform-survey# 2
     plot-graphs
     reset-timer
    ]
    [ask people with [not at-work?] [go-to-work]
     ask people with [at-work? and commute-time = n/a] [get-commute-time]
    ]
end

to extend-suburb-into-rural
  if (ready-to-build?)
    [ask people with [in-area? "rural"] [convert-to "suburbanites"]
     ask patches with [in-area? "rural"] [
       set land-class "suburb"
       set pcolor (land->color "suburb")
     ]
     set SuburbDistance SuburbDistance + rural-outskirt-dist
     set Suburb-Radius Suburb-Radius + rural-outskirt-dist
     ask patches with [(at-axis? pxcor pycor and
                       (pxcor = Suburb-Radius or pxcor = (- Suburb-Radius) or
                        pycor = Suburb-Radius or pycor = (- Suburb-Radius)))
                      ] [set pcolor green]
     ask patches with [(at-axis? pxcor pycor and
                       (pxcor = Suburb-Radius - 1 or pxcor = (- Suburb-Radius) + 1 or
                        pycor = Suburb-Radius - 1 or pycor = (- Suburb-Radius) + 1))
                      ] [set pcolor blue]
    ]
  set ready-to-build? false
  if (Rural-PopDen >= Build-Rural-PopDen)
    [set ready-to-build? true]

end

to convert-to [class-type]
  set class class-type
  set land-level (class->level class-type)
end

to-report in-area? [land-name]
  report (land-class = land-name and (distancexy-nowrap 0 0 <= (land->radius land-name)))
end

to plot-graphs
  plot-pop-histogram
  plot-avg-utility
  plot-pop-line
end

to plot-pop-line
  set-current-plot "Population"
  class->plot-pop-line "urban"
  class->plot-pop-line "rural"
  class->plot-pop-line "suburb"
end

to class->plot-pop-line [land]
  set-current-plot-pen land
  plot count-population land
end

to plot-avg-utility
  set-current-plot "Average Utility"
  class->plot-avg-utility "all"
;  class->plot-avg-utility "urbanites"
;  class->plot-avg-utility "suburbanites"
;  class->plot-avg-utility "ruralites"
end

to class->plot-avg-utility [class-name]
  set-current-plot-pen class-name
  plot calc-avg-utility class-name
end

to plot-pop-histogram
  set-current-plot "Population Distribution"
  histogram-class "urbanites"
  histogram-class "suburbanites"
  histogram-class "ruralites"
end

to histogram-class [class-name]
  set-current-plot-pen class-name
  histogram-from people with [class = class-name] [land-level]
end

to perform-survey# [edition#]
  ifelse edition# = 1
    [set lowest-tol-diff min values-from people [tol-diff]
     set highest-tol-diff max values-from people [tol-diff]
     set highest-commute-time max values-from people [commute-time]
     set lowest-commute-time min values-from people [commute-time]
    ]
    [survey-population]
end

to survey-population
  set urban-pop count-population "urban"
  set suburb-pop count-population "suburb"
  set rural-pop count-population "rural"

  set Urban-PopDen (calc-pop-density "urban")
  set Suburb-PopDen (calc-pop-density "suburb")
  set Rural-PopDen (calc-pop-density "rural")

  set Avg-Utility mean values-from people [utility]
end

to-report calc-avg-utility [class-name]
  locals [dataset]
  if (class-name = "all") [report mean values-from people [utility]]
  set dataset values-from people with [class = class-name] [utility]
  ifelse (length dataset > 0)
    [report mean dataset]
    [report n/a]
end

to move
  locals [
    prev-home-x
    prev-home-y
  ]
  go-home
  set prev-home-x home-x
  set prev-home-y home-y
  if prev-class != class
    [move-to (class->land class)
     set home-x xcor
     set home-y ycor
     setxy prev-home-x prev-home-y
     set heading towardsxy-nowrap home-x home-y
    ]
   st
   if prev-class != class [
     while [not at-home?] [wait 0.1 step-towards home-x home-y 1]
   ]
end

to-report at-home?
  report xcor = home-x and ycor = home-y
end

to step-towards [x y step-size]
  ifelse (distancexy-nowrap x y) > step-size
    [fd step-size]
    [setxy x y]
end

to-report avg-commute-for [pop-class]
  locals [agent-set]
  set agent-set people with [prev-class = pop-class]

  ifelse (empty-agentset? agent-set)
    [report n/a]
    [report (round-to 1000 mean values-from agent-set [commute-time])]
end

to-report avg-tol-diff-for [pop-class]
  locals [agent-set]
  set agent-set people with [prev-class = pop-class]

  ifelse (empty-agentset? agent-set)
    [report n/a]
    [report (round-to 1000 mean values-from agent-set [tol-diff])]
end

to-report empty-agentset? [agentset]
  ifelse (one-of agentset = nobody)
    [report true]
    [report false]
end

to inc-clock
  set clock clock + 1
end

to do-utility-analysis
  set utility calc-utility tol-diff commute-time
  set prev-class class

  ifelse (prev-class = "urbanites")
    [do-analysis "suburbanites" "ruralites"]
    [ifelse (prev-class = "suburbanites")
      [do-analysis "ruralites" "urbanites"]
      [do-analysis "suburbanites" "urbanites"]
    ]
end

to do-analysis [class1 class2]
  locals [
    utility1
    utility2
    my-class
    my-avg-utility
  ]
  without-interruption [
  set utility1 calc-utility (avg-tol-diff-for class1) (avg-commute-for class1)
  set utility2 calc-utility (avg-tol-diff-for class2) (avg-commute-for class2)

  ifelse (utility1 = n/a or utility2 = n/a)
    [set my-avg-utility (calc-utility (avg-tol-diff-for class) (avg-commute-for class))
     if my-avg-utility > utility
       [set class class1]
    ]
    [ifelse utility1 > utility
       [ifelse utility2 > utility1
          [set class class2]
          [set class class1]
       ]
       [if utility2 > utility
          [set class class2]
       ]
    ]
  ]
end

to-report calc-utility [tol commute]
  locals [
    tol-diff-range
    commute-range
    my-utility
    commute-factor
    density-factor
  ]
  set tol-diff-range (highest-tol-diff - lowest-tol-diff)
  set commute-range (highest-commute-time - lowest-commute-time)

  ifelse (tol = n/a and commute = n/a)
    [report n/a]
    [ifelse tol-diff-range = n/a
      [ifelse (lowest-tol-diff = highest-tol-diff) and (tol = highest-tol-diff)
        [set density-factor density-multiple]
        [set density-factor n/a]
      ]
      [set density-factor density-multiple * ((tol - lowest-tol-diff) / tol-diff-range)]

     ifelse commute-range = n/a
       [ifelse (highest-commute-time = lowest-commute-time) and (commute = lowest-commute-time)
          [set commute-factor time-multiple]
          [set commute-factor n/a]
       ]
       [set commute-factor time-multiple * ((highest-commute-time - commute) / commute-range)]

     set my-utility commute-factor + density-factor
     report (round-to 1000 my-utility)
    ]
end


to move-to [land]
  setxy 0 0
  set heading (random-float 360)
  fd (inner-land-radius land) + 1
  jump (random land->width land)
  if pcolor != (land->color land)
    [move-to land]
end

to-report inner-land-radius [land-name]
  ifelse (land-name = "urban")
    [report Core-Radius]
    [ifelse (land-name = "suburb")
       [report Urban-Radius]
       [report Suburb-Radius]
    ]
end

to-report land->width [land-name]
  if (land-name = "core") [report Core-Radius]
  if (land-name = "urban") [report UrbanDistance]
  if (land-name = "suburb") [report SuburbDistance]
  report rural-outskirt-dist
end

to-report land->radius [land-name]
  if (land-name = "core") [report Core-Radius]
  if (land-name = "urban") [report Urban-Radius]
  if (land-name = "suburb") [report Suburb-Radius]
  report Suburb-Radius + rural-outskirt-dist
end

to go-home
  setxy home-x home-y
  set heading towardsxy-nowrap 0 0
end

to go-to-work
  ifelse (class = "urbanites")
    [go-to-el]
    [go-to-hwy]
end

to go-to-hwy
  ifelse on-hwy?
    [drive]
    [find-road "hwy"]
end

to go-to-el
  ifelse at-el-stop?
    [ride-el]
    [find-road "tracks"]
end

to find-road [name]
  locals [next-patch]
  set next-patch one-of neighbors with [road# > 0 and land-class = name]
  ifelse next-patch = nobody
    [fd 1]
    [step-to-patch next-patch]
end

to ride-el
  if (max-one-of other-el-here [who] != nobody) [arrive-at-work]
end

to arrive-at-work
  set shape default-shape
  setxy 0 0
  ht
end

to get-commute-time
  if train-arrived? [set commute-time timer]
end

to-report train-arrived?
  ifelse road#-of (max-one-of el [who]) = 1
    [report true]
    [report false]
end

to-report at-work?
  report xcor = 0 and ycor = 0
end

to-report at-el-stop?
  report on-track?
end

to-report on-hwy?
  ifelse (land-class != "hwy")
    [report false]
    [report true]
end

to-report everyone-at-work?
  ifelse (count people-at 0 0 = population) and
         (count people with [commute-time != n/a] = population)
    [report true]
    [report false]
end

to drive
  locals [next-road#]
  if (on-hwy? and shape != "car") [set shape "car"]
  ifelse (road# = max-hwy or prev-road# = max-hwy or prev-road# = 1)
    [go-to-core "hwy"]
    [if (prev-road# = n/a) [set prev-road# road#]
     run-on "hwy"
    ]
end

to operate
  locals [next-road#]
  if (hidden? and on-track?) [st]
  ifelse (prev-road# = max-el-tracks)
    [go-to-core "tracks"]
    [ifelse (land-class != "tracks" and (land-class-of patch-ahead 1) != "tracks")
      [set heading 0 step-to-patch patch-ahead 1]
      [run-on "tracks"]
    ]
end

to go-to-core [road-name]
  ifelse road# = 1
    [ifelse road-name = "tracks"
       [set prev-road# 1
        set heading 0
       ]
       [arrive-at-work]
    ]
    [step-to-patch (min-one-of neighbors with [land-class = road-name][road#])]
end

to run-on [road-name]
  locals [
    next-road#
    update
  ]
  ifelse (road-name = "hwy" and xcor >= 0)
    [set update -1]
    [set update 1]
  set next-road# prev-road# + update
  step-to-patch (get-next-road road-name next-road#)
  set prev-road# next-road#
end

to-report on-track?
  ifelse land-class = "tracks"
    [report true]
    [report false]
end

to-report get-next-road [road id]
  locals [next]
  set next (one-of neighbors with [road# = id and (road->bool road)] )
  if next = nobody [set next one-of neighbors with [special-road?]]
  report next
end

to-report road->bool [road-name]
  ifelse (road-name = "hwy")
    [report on-hwy?]
    [report on-track?]
end

to step-to-patch [next-patch]
  set heading towards-nowrap next-patch
  fd distancexy pxcor-of next-patch pycor-of next-patch
end


;**** Utility Functions ****

;; on the x-axis or y-axis
to-report at-axis? [x y]
  ifelse (x = 0 or y = 0)
    [report true]
    [report false]
end

to-report land->color [land]
  if (land = "rural") [report green]
  if (land = "suburb") [report blue]
  if (land = "urban") [report red]
  ifelse (land = "core") [report yellow]
    [report white]
end



;**** Calculation Function *****

to-report count-population [land-type]
  report count people with [class = (land->class land-type)]
end

to-report calc-pop-density [land-type]
  locals [land-area]
  set land-area (count patches with [in-area? land-type])
  ifelse (land-area = n/a)
    [report n/a]
    [report (count-population land-type) / land-area]
end

to-report pop-density
  locals [turtle-num]
  set turtle-num count turtles-here + (sum values-from neighbors [count turtles-here])
  report (round-to 1000 turtle-num / 4) ;;square miles
end

to-report calc-pop-density-tol
  locals [
    random-sum
    scale
    tol-range
    tol
  ]
  set random-sum (random 10) + (random 10)
  ;; most occurring sum will be 11 (1/10 times)
  ;; the range for random some generator is 0 (0 + 0) to 20 (9 + 9)
  ;; the range for tol [0 , 1]
  set scale (random-sum - 9) / 18  ;; 9 is the mean of random sum and 18 is the range
  set tol-range (2 * (min (list Avg-PopDensityTol (1 - Avg-PopDensityTol))))
  set tol (scale * tol-range + Avg-PopDensityTol)
  report (round-to 100 tol)
end

;;rounds number to decimal-place
to-report round-to [decimal-place num]
  report (round (num * decimal-place)) / decimal-place
end


;;**** Initial Setup ****
to setup
  ca
  reset-timer
  setup-globals
  setup-city
  setup-populace
  setup-plots
end


to setup-globals
  set clock 0
  set n/a 0
  set Avg-Utility n/a
  set Urban-Radius Core-Radius + UrbanDistance
  set Suburb-Radius  Urban-Radius + SuburbDistance

  set el-radius Core-Radius + (round (0.5 * UrbanDistance)) - 1
  set hwy-radius Urban-Radius + (round (0.5 * SuburbDistance)) - 1

  set highest-tol-diff n/a
  set lowest-commute-time n/a
  set highest-commute-time n/a
  set lowest-commute-time n/a

  set el-revolution [2 3 4 1]
  set hwy-revolution [4 1 2 3]
  set default-shape "default"
  set rural-outskirt-dist 1

  set ready-to-build? false

  set Urban-pop n/a
  set Suburb-pop n/a
  set Rural-pop n/a

  set Urban-PopDen n/a
  set Suburb-PopDen n/a
  set Rural-PopDen n/a

  set Avg-Utility n/a
end

to setup-city
  setup-land
  setup-el
  setup-hwy
end


to setup-land
  ;; dummy turtle for setting up w.r.t origin
  create-custom-people 1 [
    setxy 0 0
    set class "special"
  ]
  ask patches [name-paint-land "rural" set special-road? false]

  ask People with [class = "special"] [

    ask patches in-radius Suburb-Radius [
      name-paint-land "suburb"
      smooth-land Suburb-Radius "rural"
    ]
    ask patches in-radius Urban-Radius[
      name-paint-land "urban"
      smooth-land Urban-Radius "suburb"
    ]
    ask patches in-radius Core-Radius [
      name-paint-land "core"
      smooth-land Core-Radius "urban"
    ]
    die
  ]
end

to name-paint-land [land-name]
  set land-class land-name
  set pcolor (land->color land-name)
end


to smooth-land [radius land-name]
  if (distancexy 0 0) = radius and (at-axis? pxcor pycor)
    [name-paint-land land-name]
end


to setup-el
  locals [num-out]
  setup-track
  create-custom-el 5 [
    set shape "square"
    set heading 0
    setxy 0 (who mod 5) + (el-radius - Core-Radius - 1)
    set prev-road# road#
    if (land-class != "tracks") [ht]
    set color scale-color red who 5 -1
  ]
end

to setup-track
  setup-road "tracks" el-radius "urban"
  ask patch-at 0 (- el-radius) [set special-road? true]
end


to setup-hwy
  setup-road "hwy" hwy-radius "suburb"
end

to setup-road [road-name radius outer-land]
  ask patches with [distancexy 0 0 > radius and
                    distancexy 0 0 <= radius + 1][

    name-paint-land road-name

    if (distancexy 0 0) = radius + 1 and (at-axis? pxcor pycor)
       [sprout 1
         [set heading towardsxy-nowrap 0 0
          fd 1
          set pcolor white
          set land-class road-name
          die
         ]
       ]
    smooth-land (radius + 1) outer-land
  ]
  connect-to-core radius road-name
  trace-road road-name radius
end

to trace-road [road-name radius]
  locals [
    road-id
    x-range
    quad#
    revolution
  ]
  set x-range radius
  set road-id 1
  set revolution 0

  set road-id setup-runway road-name road-id
  repeat 4 [
    set quad# revolution-quad revolution road-name
    set road-id (tracer-helper x-range road-name quad# road-id)
    set road-id setup-axis quad# radius road-id
    set revolution revolution + 1
  ]
  ifelse (road-name = "hwy")
    [set max-hwy road-id - 1]
    [set max-el-tracks road-id - 1]
end

to-report setup-axis [quad radius id]
  if quad = 2 [
    code-road# id (- radius) 0
    set id id + 1
  ]
  if quad = 4 [
    code-road# id radius  0
    set id id + 1
  ]
  if quad = 1 and radius != el-radius  [
    code-road# id 0 radius
    set id id + 1
  ]

  if quad = 3 and radius != hwy-radius [
    code-road# id 0 (- radius)
    set id id + 1
  ]
  report id
end

to-report revolution-quad [revolution road-name]
  ifelse (road-name = "hwy")
    [report item revolution hwy-revolution]
    [report item revolution el-revolution]
end

to-report setup-runway [road-name start#]
  locals [
    id#
    curr-y
    runway-range
    update
  ]
  set id# start#
  ifelse (road-name = "hwy")
    [set runway-range (hwy-radius - Core-Radius + 1)
     set update -1
    ]
    [set runway-range (el-radius - Core-Radius + 1)
     set update 1
    ]
  set curr-y (update * Core-Radius)
  repeat runway-range [
    ask patches with [pxcor = 0 and pycor = curr-y]
       [set road# id#]
       set id# id# + 1
       set curr-y curr-y + update
  ]
  report id#
end

to-report tracer-helper [x-range road-name quad# id#]
  locals [
    curr-x
    curr-y
    y-lst
    update
  ]
  ifelse quad# = 2 or quad# = 1
    [set update -1
     ifelse quad# = 2
       [set curr-x -1]
       [set curr-x x-range]
     ]
    [set update 1
     ifelse quad# = 3
       [set curr-x (- x-range)]
       [set curr-x 1]
    ]

  repeat x-range [
    set y-lst (get-collision-y-lst road-name curr-x quad#)

    ifelse (length y-lst) = 1
      [code-road# id# curr-x (first y-lst)
       set id# id# + 1
      ]
      [while [not empty? y-lst] [
         set curr-y first y-lst
         code-road# id# curr-x curr-y
         set id# id# + 1
         set y-lst (but-first y-lst)
       ]
      ]
    set curr-x curr-x + update
  ]
  report id#
end


to code-road# [label# x y]
  ask patches with [pxcor = x and pycor = y]
    [set road# label#]
end

to-report get-collision-y-lst [name x quad#]
  locals [y-lst]

  set y-lst sort values-from patches with [land-class = name and pxcor = x and (in-quad quad# pxcor pycor)] [pycor]
  ifelse (quad# = 2 or quad# = 3)
    [report (reverse y-lst)]
    [report y-lst]
end

to-report in-quad [quad# x y]
  locals [
    x-multiple
    y-multiple
  ]
  set x-multiple 1
  set y-multiple 1

  if (quad# = 2) [set x-multiple -1]
  if (quad# = 3) [
    set x-multiple -1
    set y-multiple -1
  ]
  if (quad# = 4) [set y-multiple -1]

  set x x * x-multiple
  set y y * y-multiple

  ifelse (x > 0 and y > 0)
    [report true]
    [report false]
end

;; draw white stripe from corresponding road to center
to connect-to-core [edge-dist land-name]
  locals [
    outer-ycor
    inner-ycor
  ]
  ifelse land-name = "hwy"
    [set outer-ycor (- Core-Radius)
     set inner-ycor (- edge-dist)
    ]
    [set outer-ycor edge-dist
     set inner-ycor Core-Radius
    ]
  ask patches with [pxcor = 0 and pycor <= outer-ycor and pycor >= inner-ycor]
    [name-paint-land land-name]
end

to setup-populace
  create-custom-People Population [
    initial-setup
    cyclic-setup
  ]
  survey-population
end

to initial-setup
  set class "urbanites"
  set prev-class class
  set pop-density-tol  calc-pop-density-tol
  set density-multiple ((random 99) + 1) / 100
  set time-multiple (1 - density-multiple)
  move-to "urban"
end

to cyclic-setup
  set home-x (round xcor)
  set home-y (round ycor)

  set xcor home-x
  set ycor home-y

  set my-pop-density pop-density

  set commute-time n/a
  set tol-diff pop-density-tol - pop-density
  set prev-road# n/a
  if (shape != default-shape) [set shape default-shape]

  set heading towardsxy-nowrap 0 0
  set land-level (class->level class)
  set color black
  if (distancexy-nowrap 0 0) <= el-radius [lt 180]
  if (distancexy-nowrap 0 0) > Urban-Radius  and (distancexy-nowrap 0 0) <= hwy-radius [lt 180]
end

to-report class->level [class-type]
  ifelse (class-type = "ruralites")
    [report 2]
    [ifelse (class-type = "suburbanites")
       [report 1]
       [report 0]
    ]
end

to setup-plots
  clear-all-plots
end

to-report  land->class [land-name]
  if (land-name = "urban") [report "urbanites"]
  if (land-name = "suburb") [report "suburbanites"]
  report "ruralites"
end

to-report class->land [class-name]
  if (class-name = "urbanites") [report "urban"]
  if (class-name = "suburbanites") [report "suburb"]
  report "rural"
end
@#$#@#$#@
GRAPHICS-WINDOW
518
10
1016
529
30
30
8.0
1
10
1
1
1
0

CC-WINDOW
5
597
1025
692
Command Center

SLIDER
20
217
192
250
Core-Radius
Core-Radius
3
10
3
1
1
mi

SLIDER
20
253
192
286
UrbanDistance
UrbanDistance
3
10
5
1
1
mi

SLIDER
20
290
192
323
SuburbDistance
SuburbDistance
3
15
8
1
1
mi

BUTTON
29
11
107
44
Setup
setup
NIL
1
T
OBSERVER
T
NIL

BUTTON
114
11
189
44
Go
go
T
1
T
OBSERVER
T
NIL

SLIDER
1
75
214
108
Population
Population
0
200
109
1
1
million

SLIDER
1
111
215
144
Avg-PopDensityTol
Avg-PopDensityTol
0
1
0.32
0.01
1
mil/sq-mi

TEXTBOX
23
193
208
211
Landscape Variable Initialization

TEXTBOX
54
55
172
73
Population Variables

SLIDER
20
408
192
441
GreenBelt-Radius
GreenBelt-Radius
0
30
16
1
1
mi

SWITCH
20
372
188
405
GreenBelt-Policy
GreenBelt-Policy
0
1
-1000

MONITOR
244
479
321
528
Urban-pop
Urban-pop
0
1

MONITOR
326
479
402
528
Suburb-pop
Suburb-pop
0
1

MONITOR
406
479
482
528
Rural-pop
Rural-pop
0
1

TEXTBOX
53
351
167
369
GreenBelt Variables

SLIDER
1
149
216
182
Build-Rural-PopDen
Build-Rural-PopDen
0
0.5
0.05
0.01
1
mil/sq-mi

PLOT
225
333
501
472
Population Distribution
Class
Population
0.0
3.0
0.0
100.0
true
false
PENS
"default" 1.0 1 -16777216 true
"Urbanites" 1.0 1 -65536 true
"Suburbanites" 1.0 1 -16776961 true
"Ruralites" 1.0 1 -11352576 true

MONITOR
214
534
308
583
Urban-PopDen
Urban-PopDen
3
1

MONITOR
311
534
409
583
NIL
Suburb-PopDen
3
1

MONITOR
412
534
505
583
Rural-PopDen
Rural-PopDen
3
1

PLOT
224
10
499
160
Average Utility
Time
Utility
0.0
30.0
0.5
1.0
true
false
PENS
"All" 1.0 0 -16777216 true
"Urbanites" 1.0 0 -65536 true
"Suburbanites" 1.0 0 -16776961 true
"Ruralites" 1.0 0 -11352576 true

PLOT
224
172
501
322
Population
Time
Population
0.0
30.0
0.0
100.0
true
false
PENS
"urban" 1.0 0 -65536 true
"suburb" 1.0 0 -16776961 true
"rural" 1.0 0 -11352576 true

@#$#@#$#@
@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7566196 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7566196 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7566196 true true 150 285 285 225 285 75 150 135
Polygon -7566196 true true 150 135 15 75 150 15 285 75
Polygon -7566196 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7566196 true true 96 182 108
Circle -7566196 true true 110 127 80
Circle -7566196 true true 110 75 80
Line -7566196 true 150 100 80 30
Line -7566196 true 150 100 220 30

butterfly
true
0
Polygon -7566196 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7566196 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7566196 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7566196 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7566196 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7566196 true true 47 195 58
Circle -7566196 true true 195 195 58

circle
false
0
Circle -7566196 true true 0 0 300

circle 2
false
0
Circle -7566196 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7566196 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7566196 true true 73 210 86 251 62 249 48 208
Polygon -7566196 true true 25 114 16 195 9 204 23 213 25 200 39 123

face happy
false
0
Circle -7566196 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7566196 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7566196 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7566196 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7566196 true true 60 15 75 300
Polygon -7566196 true true 90 150 270 90 90 30
Line -7566196 true 75 135 90 135
Line -7566196 true 75 45 90 45

flower
false
0
Polygon -11352576 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7566196 true true 85 132 38
Circle -7566196 true true 130 147 38
Circle -7566196 true true 192 85 38
Circle -7566196 true true 85 40 38
Circle -7566196 true true 177 40 38
Circle -7566196 true true 177 132 38
Circle -7566196 true true 70 85 38
Circle -7566196 true true 130 25 38
Circle -7566196 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -11352576 true false 189 233 219 188 249 173 279 188 234 218
Polygon -11352576 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7566196 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7566196 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7566196 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7566196 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7566196 true 150 0 150 300

pentagon
false
0
Polygon -7566196 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7566196 true true 110 5 80
Polygon -7566196 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7566196 true true 127 79 172 94
Polygon -7566196 true true 195 90 240 150 225 180 165 105
Polygon -7566196 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7566196 true true 135 90 165 300
Polygon -7566196 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7566196 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7566196 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7566196 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7566196 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7566196 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7566196 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7566196 true true 30 30 270 270

square 2
false
0
Rectangle -7566196 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7566196 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7566196 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7566196 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7566196 true true 120 120 60

tree
false
0
Circle -7566196 true true 118 3 94
Rectangle -6524078 true false 120 195 180 300
Circle -7566196 true true 65 21 108
Circle -7566196 true true 116 41 127
Circle -7566196 true true 45 90 120
Circle -7566196 true true 104 74 152

triangle
false
0
Polygon -7566196 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7566196 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7566196 true true 4 45 195 187
Polygon -7566196 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7566196 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7566196 false true 24 174 42
Circle -7566196 false true 144 174 42
Circle -7566196 false true 234 174 42

turtle
true
0
Polygon -11352576 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -11352576 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -11352576 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -11352576 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -11352576 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7566196 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7566196 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7566196 true 150 285 150 15
Line -7566196 true 15 150 285 150
Circle -7566196 true true 120 120 60
Line -7566196 true 216 40 79 269
Line -7566196 true 40 84 269 221
Line -7566196 true 40 216 269 79
Line -7566196 true 84 40 221 269

x
false
0
Polygon -7566196 true true 270 75 225 30 30 225 75 270
Polygon -7566196 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 2.1beta4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
