globals [
  init-nbr-students      ;; initial number of students
  init-nbr-schools       ;; initial number of schools
  max-capacity           ;; the maximum size of a school
  school-nbr-index
  schools-with-room   ;; an agentset of schools with available spaces
  pct-moving          ;; pct of students not attending their assigned school
  pct-leaving         ;; pct of students leaving the district
  pct-capacity        ;; pct of spaces in school district that are filled (can be over 100% to handle local area students)
  stdev-ach           ;; std dev of achievement across all students
  min-enroll          ;; minimum number of students a school must keep to stay open
  enroll-ma-thresh    ;; minimum number your 3 year moving average needs to stay above in order to stay open
  nbr-new-students    ;; number of new students potentially entering the district in a year
  new-school          ;; the new school created in a the current time period
  pct-satisfied
  nbr-incoming-list
  max-distance        ;; this is the farthest two points can be from each other is ths world
  nr-sort?             ;; distribute initial conditions by catchment area instead of uniformly
  total-closed
  total-new
  leaving-list
  moving-list
  closed-red-vas
  closed-red-areas
  closed-red-yrs-here
  closed-blue-vas
  closed-blue-areas
  closed-blue-yrs-here
  new-vas
  closed-vas
  closed-mas
  open-blue-areas
  frac-new-schools
  red-survivors
  blue-survivors
  gini
]

breeds [ households students schools ]

students-own [
  assigned-school     ;; the neighborhood school assigned to this student
  preferred-school    ;; the school the student would like to go to
  attended-school     ;; school actually attended
  time-here           ;; amount of years in spent in a school
  achievement         ;; measured in grade levels, 12 = highest
  achievement-quart   ;; quartile of achievement distribution student is in.  1 is highest achieving
  my-household        ;; the household the student comes from
  my-school-info      ;; a list of all schools, and their perceived characteristics (includes null values)
  schools-i-know      ;; the subset of schools, and their perceived characteristics, that the student has info about
  better-schools      ;; schools that are better than the one I am assigned to, or better than the one I perceive as best
  max-ach             ;; highest perceived mean achievement of all schools
  max-ach-school      ;; school with the highest perceived mean-achievement
  max-green           ;; highest perceived percentage of students with green prefs
  max-pink            ;; highest perceived percentage of students with pink prefs
  max-yellow          ;; highest perceived percentage of students with yellow prefs
  max-green-school    ;; school with the highest perceived pct of green students
  max-pink-school    ;; school with the highest perceived pct of pink students
  max-yellow-school    ;; school with the highest perceived pct of yellow students
  max-my-color
  satisfied?

]

schools-own [
  school-nbr          ;; unique id
  avail-spaces        ;; total nbr of available spaces for students at the school
  mean-achievement    ;; the mean achievement of students attendeding the school
  enroll              ;; current enrollment in school
  enroll-p1           ;; enrollment two periods ago
  enroll-p2           ;; enrollment two periods ago
  enroll-ma           ;; moving average of enrollment
  pct-green           ;; pct of students at school with green preferences
  pct-pink            ;; pct of students at school with pink preferences
  pct-yellow          ;; pct of students at school with yellow preferences
  value-added         ;; the std deviation change of achievement of a student attending your school
  pct-quart1          ;; pct of total students in the 1st quartile of achievement that are in this school
  pct-quart2          ;; pct of total students in the 2nd quartile of achievement that are in this school
  pct-quart3          ;; pct of total students in the 3rd quartile of achievement that are in this school
  pct-quart4          ;; pct of total students in the 4th quartile of achievement that are in this school
  years-here          ;; number of time-periods school has been open
  incoming-students   ;; number of incoming 9th graders in a school
  school-area         ;; catchment area from which a school gets assigned students
  va-rank             ;; rank among schools wrt value-added ( 1 is highest)
  ma-rank             ;; rank among schools wrt initial mean-achievement ( 1 is highest)
  init-ma             ;; mean achievement at time 0
]

households-own [
  my-kids-schools         ;; a list of schools that my kids attend
  perceived-school-info   ;; a list of the household's perception of school characteristics
  pcd-ach-1               ;; perceived achievement of school nbr 1
  pcd-ach-2
  pcd-ach-3
  pcd-ach-4
  pcd-ach-5
  pcd-ach-6
  pcd-ach-7
  pcd-ach-8
  pcd-ach-9
  pcd-ach-1-prev           ;; perceived achievement of school nbr 1 from the previous time period
  pcd-ach-2-prev
  pcd-ach-3-prev
  pcd-ach-4-prev
  pcd-ach-5-prev
  pcd-ach-6-prev
  pcd-ach-7-prev
  pcd-ach-8-prev
  pcd-ach-9-prev
  resourcefulness         ;; a measure of how good a household is at finding out school info
  decision-rule
  mobility                ;; a measuer of a household's ability to send their kids to a non-assigned school
  achievement-thresh      ;; minimum mean achievement of a school you are willing to accept if you have a choice
  %-similar-wanted        ;; minimum percentage of those similar to you, you are willing to accept if you have a choice
  catchment-school        ;; assigned school for students in my household
]

patches-own [
  catchment-area      ;; region defining schools that could potentially be the "assigned" school for a hh on that patch
  zone-x              ;; used to determine catchment areas
  zone-y              ;; used to determine catchment areas
  hh-color            ;; color of the households on that patch
]

to setup
  ca
  init-globals
  setup-patches
  setup-schools
  setup-households

  ;; setup students
  create-new-students init-nbr-students
  ask random-n-of (init-nbr-students / 4) students [ set time-here 3 ]
  ask random-n-of (init-nbr-students / 4) students with [ time-here < 3][ set time-here 2 ]
  ask random-n-of (init-nbr-students / 4) students with [ time-here < 2][ set time-here 1 ]
  ask students [ set attended-school assigned-school ]  ;; initially everyone attends their assigned school
  set nbr-new-students count students with [ time-here = 0 ]

  ;; initialize schools, households, and students
  update-student-quartiles
  update-schools
  update-households
  update-students

  ;; initiliaze value-added of the schools based on catchment area and sd of achievement across students
  if school-effects? [
    ask schools [
        let mean-va (catchment-area / 9 ) * 0.4 * standard-deviation values-from students [achievement]
        set value-added random-normal mean-va 0.1
    ]
  ]

  ;; re-initialize existing student achievement to account for the value-added of the school they attend
  ask students [
    ifelse time-here = 4
      [  set achievement (achievement + 4 * value-added-of attended-school) ]
      [ ifelse time-here = 3
        [ set achievement (achievement + 3 * value-added-of attended-school) ]
        [ ifelse time-here = 2
          [ set achievement (achievement + 2 * value-added-of attended-school) ]
          [ set achievement (achievement + value-added-of attended-school) ]
        ]
      ]
  ]

  update-globals      ;; initialize global variables based on initial school, household, and student info
  setup-plots
  do-plots
  ask students [go-to-school]   ;; move students close to their attended school in graphics window
  get-b-space-data

  ; ask students [ set color scale-color green achievement 5 13 set hidden? false ]
  ;ask schools with-max [ mean-achievement ] [ set size 3 set color green]
  ;ask schools with-max [ value-added ] [ set size 3 set color yellow]
  ;ask schools with-max [ value-added ] [ set size 3 set color yellow]
  ;show sort-by [?2 < ?1] values-from schools [ mean-achievement]

end

to go
  set total-new 0
  set total-closed 0
  set leaving-list []
  set moving-list []

  turnover-students
  update-student-quartiles
  update-school-capacity
  ask students with [ assigned-school = nobody ] [           ;; in case the school you were assigned to closed last year
    set assigned-school catchment-school-of my-household
  ]
  if new-schools? [ propose-new-schools ] ;; every year a new school(s) are proposed
  show "nbr-proposed: " + count schools with [ years-here = 0 ]
  pick-school
  if new-schools? [ new-school-exists? ]  ;; the proposed school opens if there was enough demand for it
    show "nbr-open: " + count schools with [ years-here = 0 ]
  ask students [go-to-school] ;; move to school that you will be attending -- for graphics only
  update-students
  update-schools
 ask schools [ set label precision mean-achievement 2 ]
  update-households
  update-globals
  do-plots




  ;; for b-space
  set red-survivors schools with [ color = red and years-here >= 5 ]
  set blue-survivors schools with [ color = blue and years-here >= 5 ]
end

to turnover-students
  ;; students who have been at school for 4 years leave
  let students-leaving students with [ time-here = 4 ]
  ask students-leaving [ die ]

;  let nbr-leaving count students-leaving
;  show "nbr-leaving: " + nbr-leaving

  ;; create new students who are coming into the school this year
  create-new-students init-nbr-students / 4
  set nbr-new-students count students with [ time-here = 0 ]
;  show "nbr-incoming: " + nbr-new-students
  ask students with [ time-here = 0 ] [ determine-satisfaction assigned-school]

end

to update-school-capacity
  ;; update enrollments after turnover
  ;; set avail-spaces equal to the maximum capacity minus the 3 grades of students who are still there
  ;; and minus the incoming students assigned to their school who will be coming to their school
  ;; Note:  some unsatified students may be coming as well because they realize that they have no available better choice.
  ;; If that happens there is the potential to go over capacity (and the school will because it has to take assigned students)
  ask schools [
    set enroll (count students with [ attended-school = myself ]) +
               (count students with [ time-here = 0 and assigned-school = myself and satisfied? = true ])
    set avail-spaces (max-capacity - enroll)
  ]
end

to pick-school
  ;; first, update the info available to student based on their household's perceptions
  ask students [
     set my-school-info perceived-school-info-of my-household
     set schools-i-know filter [ item 1 ? != 99 ] my-school-info
   ]

 ;; second, relocate any students from schools that had closed down last year
 without-interruption [
   ask students with [ time-here > 0 and attended-school = nobody ] [
       choose-district-school
    ]
 ]

 ;; now incoming students evaluate district schools
 without-interruption [
   ask students with [ time-here = 0 ][
     ifelse ( choice-basis = "similarity" or (choice-basis = "mix" and decision-rule-of my-household = "S") ) and satisfied?
       [ set attended-school assigned-school ]
       [ choose-district-school
         determine-satisfaction attended-school

         ;; if your favorite district school is not good enough, then try to leave the system.
         if (not satisfied?)  and
            (mobility-of my-household > external-mobility-thresh)
           [ ask attended-school [ set avail-spaces avail-spaces + 1 ]
             ;show "Mobility: " + mobility-of my-household
             set leaving-list lput achievement-quart leaving-list
             die
           ]

         ;; if you are unsatisfied with your options, but aren't mobile enough to leave the district
         ;; see if you can go to the new school in the district.  otherwise, you are stuck in the system
         if (new-schools? = true) and (not satisfied?) and (internal-choice? = true) [
         let my-hh my-household
         let nearby-new-school min-one-of schools with [ years-here = 0 ][ distance-nowrap my-hh ]
        ; let nearby-new-school new-school
       ;  show nearby-new-school

           if  (mobility-of my-household > mobility-thresh nearby-new-school) and ( avail-spaces-of nearby-new-school > 0 )
               [ ask attended-school [ set avail-spaces avail-spaces + 1 ]
                 set attended-school nearby-new-school
                 ask nearby-new-school [ set avail-spaces avail-spaces - 1 ]
               ]
         ]
       ]

  ]
 ]

end


to choose-district-school
 ;; check to make sure the schools you know about haven't closed on you
 set schools-i-know filter [ hidden?-of item 0 ? = false ] schools-i-know

 ;; then find top choice
 ifelse (not empty? schools-i-know) and (internal-choice? = true)
  [ set max-ach max map [ item 1 ? ] schools-i-know
    set max-green max map [ item 2 ? ] schools-i-know
    set max-pink max map [ item 3 ? ] schools-i-know
    set max-yellow max map [ item 4 ? ] schools-i-know

    set max-ach-school item 0 (random-one-of ( filter [ item 1 ? = max-ach ] schools-i-know ) )
    set max-green-school item 0 (random-one-of ( filter [ item 2 ? = max-green ] schools-i-know ) )
    set max-pink-school item 0 (random-one-of ( filter [ item 3 ? = max-pink ] schools-i-know ) )
    set max-yellow-school item 0 (random-one-of ( filter [ item 4 ? = max-yellow ] schools-i-know ) )

    let in-my-area filter [ item 5 ? = catchment-area-of my-household ] schools-i-know
    let sim-enough-list []
    let sim-enough nobody

    ifelse color = green
      [ set max-my-color max-green-school
        set sim-enough-list filter [ item 2 ? >= %-similar-wanted-of my-household ] in-my-area  ;; find sim enough schools in my area
        if empty? sim-enough-list [ set sim-enough-list filter [ item 2 ? >= %-similar-wanted-of my-household ] schools-i-know ]   ;; if there aren't any, try everywhere in the district
      ]
      [ ifelse color = pink
        [ set max-my-color max-pink-school
          set sim-enough-list filter [ item 3 ? >= %-similar-wanted-of my-household ] in-my-area
          if empty? sim-enough-list [ set sim-enough-list filter [ item 3 ? >= %-similar-wanted-of my-household ] schools-i-know ]
        ]
        [ set max-my-color max-yellow-school
          set sim-enough-list filter [ item 4 ? >= %-similar-wanted-of my-household ] in-my-area
          if empty? sim-enough-list [ set sim-enough-list filter [ item 4 ? >= %-similar-wanted-of my-household ] schools-i-know ]
        ]
      ]

    ;; if there are not any schools similar enough anyhwere in the district, pick the one that comes closest
    ifelse not empty? sim-enough-list
      [ set sim-enough item 0 (random-one-of sim-enough-list) ]
      [ set sim-enough max-my-color ]

    if choice-basis = "achievement" [ set preferred-school max-ach-school ]
    if choice-basis = "similarity" [ set preferred-school sim-enough ]
    if choice-basis = "mix" [
      ifelse decision-rule-of my-household = "A"     ;; "A" stands for achievement
         [ set preferred-school max-ach-school ]
         [ set preferred-school sim-enough ]
     ]

    ;; if your preferred schools is your assigned school then go to it.
    ;; if your preferred schools is not your assigned school, then try to go to it if there is enough room and you have enough mobility
    ;; otherwise, try the next school on your list
    ifelse preferred-school = assigned-school
      [ set attended-school assigned-school
        if (not satisfied?) [ ask attended-school [ set avail-spaces avail-spaces - 1 ]  ]  ;; you weren't initially counted so decrement avail-spaces
      ]
      [  ifelse (avail-spaces-of preferred-school > 0) and (mobility-of my-household > mobility-thresh preferred-school)
         [ set attended-school preferred-school
           ask preferred-school [ set avail-spaces avail-spaces - 1 ] ;; take up a space at your new school
  ;         if satisfied? [ ask assigned-school [ set avail-spaces avail-spaces + 1 ] ]  ;; free up the space we thought you were going to take at your assigned school
         ]
         [ set schools-i-know filter [item 0 ? != preferred-school] schools-i-know
           choose-district-school
         ]
      ]
   ]

   ;; when I run out of schools to try or I have no choice to begin with
   ;; then I go to my assigned school
   [  set attended-school assigned-school
      set preferred-school nobody

      ;; if a not satisfed student comes to the school, we need to decrease the number
      ;; of avail-spaces because when we initialized this value, we only assumed that satisfied
      ;; students assigned to this school were coming
      if (not satisfied?) [ ask attended-school [ set avail-spaces avail-spaces - 1 ]  ]

      stop
   ]

end

to update-students
  ask students [
    set time-here time-here + 1
    if time-here = 0 [ show "time-here = 0 ???"] ;; error checking
    set achievement ( achievement + value-added-of attended-school )

    ;; update satisfaction
    determine-satisfaction attended-school

  ]
end

to update-schools
  let worst-school min-one-of schools with [ years-here >= 5][ value-added ]
  let better-options schools with [ school-area = school-area-of worst-school and value-added > value-added-of worst-school]

  ask schools [
    let my-students students with [attended-school = myself ]
    let countq1 (count students with [achievement-quart = 1])
    let countq2 (count students with [achievement-quart = 2])
    let countq3 (count students with [achievement-quart = 3])
    let countq4 (count students with [achievement-quart = 4])

    ;; update enrollments
    set enroll-p2 enroll-p1
    set enroll-p1 enroll
    set enroll count my-students
;    if enroll > 1.50 * max-capacity [ show "I'm way over capacity. Enrollment: " + enroll + " Max-Capacity: " + max-capacity]
    set enroll-ma (enroll + enroll-p1 + enroll-p2) / 3  ;; calc 3-year moving average of enrollment

    ;; close school right away if there are only a handful of students there unless you are a new school between years 1 and 4.
    ;; note:  if you are in year zero and don't have enough enrollment you don't really open (i.e., shutdown before you appear)
    ifelse (enroll < min-enroll) or (control-close? and worst-school = self and any? better-options )
      [ set total-closed total-closed + 1
        set closed-vas lput value-added closed-vas
       ; show "I'm closing. Value-added: " + value-added  + " , ma:"  + mean-achievement
        ifelse color = red
          [ set closed-red-vas lput value-added closed-red-vas
            set closed-mas lput init-ma closed-mas  ;; only makes sense for original schools
            set closed-red-areas lput school-area closed-red-areas
            set closed-red-yrs-here lput years-here closed-red-yrs-here
          ]
          [ set closed-blue-vas lput value-added closed-blue-vas
            set closed-blue-areas lput school-area closed-blue-areas
            set closed-blue-yrs-here lput years-here closed-blue-yrs-here
          ]
        die
      ]
      [ showturtle
        set mean-achievement mean values-from my-students [achievement]
        set label precision mean-achievement 2
        set pct-green ( count my-students with [ color = green ] ) / enroll * 100
        set pct-pink ( count my-students with [ color = pink ] ) / enroll * 100
        set pct-yellow ( count my-students with [ color = yellow ] ) / enroll * 100
        set incoming-students count my-students with [ time-here = 1]

        ifelse countq1 > 0
          [ set pct-quart1 ( count my-students with [achievement-quart = 1] ) / countq1 * 100 ]
          [ set pct-quart1 0 ]
        ifelse countq2 > 0
          [ set pct-quart2 ( count my-students with [achievement-quart = 2] ) / countq2 * 100 ]
          [ set pct-quart2 0 ]
        ifelse countq3 > 0
          [ set pct-quart3 ( count my-students with [achievement-quart = 3] ) / countq3 * 100 ]
          [ set pct-quart3 0 ]
        ifelse countq4 > 0
          [ set pct-quart4 ( count my-students with [achievement-quart = 4] ) / countq4 * 100 ]
          [ set pct-quart4 0 ]
     ]

   set years-here years-here + 1
  ]

end

to update-households
  ;; this procedure calculates each household's perception of the the characteristics of each school depending
  ;; on which info-source is specified on the interface

  let school-list values-from schools [who]
  let perceptions []
  let temp-school nobody

  ;; if your school closed this round then you get assigned a new local school
  ask households [
    if catchment-school = nobody [ assign-local-school ]
  ]

  ;; if info-source is "perfect", just set perceptions to reality
  ifelse info-source = "perfect"
  [  foreach school-list [
       set temp-school one-of schools with [ who = ? ]
       set perceptions lput (list temp-school (mean-achievement-of temp-school) (pct-green-of temp-school)
                                  (pct-pink-of temp-school) (pct-yellow-of temp-school) (school-area-of temp-school) ) perceptions
     ]

  ]

  ;; otherwise (i.e, info-source = "neighbors" or "indiv var"), the only perfect info you have is
  ;; about schools were you send your own kids and information on the rest of the schools comes from
  ;; your neighbors' perceptions (more specifically, the average perception of your neighbors)

  [ ;; first, get your kids info about their schools
    without-interruption [
      ask students [
        let my-school attended-school-of self

        ask my-household [
        ;  if my-school = school-1  [set pcd-ach-1 (mean-achievement-of my-school)]
        ;  if my-school = school-2  [set pcd-ach-2 (mean-achievement-of my-school)]
        ;  if my-school = school-3  [set pcd-ach-3 (mean-achievement-of my-school)]
        ;  if my-school = school-4  [set pcd-ach-4 (mean-achievement-of my-school)]
        ;  if my-school = school-5  [set pcd-ach-5 (mean-achievement-of my-school)]
        ;  if my-school = school-6  [set pcd-ach-6 (mean-achievement-of my-school)]
        ;  if my-school = school-7  [set pcd-ach-7 (mean-achievement-of my-school)]
        ;  if my-school = school-8  [set pcd-ach-8 (mean-achievement-of my-school)]
        ;  if my-school = school-9  [set pcd-ach-9 (mean-achievement-of my-school)]

          set my-kids-schools lput my-school my-kids-schools

        ]
      ]
    ]

    ;; second, calculate a perception of other schools based on your neighbors perceptions
    ask households [
     set pcd-ach-1-prev pcd-ach-1
     set pcd-ach-2-prev pcd-ach-2
     set pcd-ach-3-prev pcd-ach-3
     set pcd-ach-4-prev pcd-ach-4
     set pcd-ach-5-prev pcd-ach-5
     set pcd-ach-6-prev pcd-ach-6
     set pcd-ach-7-prev pcd-ach-7
     set pcd-ach-8-prev pcd-ach-8
     set pcd-ach-9-prev pcd-ach-9

     let my-neighbors households-on neighbors
     let ach-1-non-null-neighbors my-neighbors with [pcd-ach-1-prev != 99]
     let ach-2-non-null-neighbors my-neighbors with [pcd-ach-2-prev != 99]
     let ach-3-non-null-neighbors my-neighbors with [pcd-ach-3-prev != 99]
     let ach-4-non-null-neighbors my-neighbors with [pcd-ach-4-prev != 99]
     let ach-5-non-null-neighbors my-neighbors with [pcd-ach-5-prev != 99]
     let ach-6-non-null-neighbors my-neighbors with [pcd-ach-6-prev != 99]
     let ach-7-non-null-neighbors my-neighbors with [pcd-ach-7-prev != 99]
     let ach-8-non-null-neighbors my-neighbors with [pcd-ach-8-prev != 99]
     let ach-9-non-null-neighbors my-neighbors with [pcd-ach-9-prev != 99]

 ;    if not member? school-1 my-kids-schools and any? ach-1-non-null-neighbors
 ;      [ set pcd-ach-1 mean values-from ach-1-non-null-neighbors [pcd-ach-1-prev] ]

 ;    if not member? school-2 my-kids-schools and any? ach-2-non-null-neighbors
 ;      [ set pcd-ach-2 mean values-from ach-2-non-null-neighbors [pcd-ach-2-prev] ]

  ;   if not member? school-3 my-kids-schools and any? ach-3-non-null-neighbors
  ;     [ set pcd-ach-3 mean values-from ach-3-non-null-neighbors [pcd-ach-3-prev] ]

   ;  if not member? school-4 my-kids-schools and any? ach-4-non-null-neighbors
    ;   [ set pcd-ach-4 mean values-from ach-4-non-null-neighbors [pcd-ach-4-prev] ]

;     if not member? school-5 my-kids-schools and any? ach-5-non-null-neighbors
 ;      [ set pcd-ach-5 mean values-from ach-5-non-null-neighbors [pcd-ach-5-prev] ]

  ;   if not member? school-6 my-kids-schools and any? ach-6-non-null-neighbors
   ;    [ set pcd-ach-6 mean values-from ach-6-non-null-neighbors [pcd-ach-6-prev] ]

;     if not member? school-7 my-kids-schools and any? ach-7-non-null-neighbors
 ;      [ set pcd-ach-7 mean values-from ach-7-non-null-neighbors [pcd-ach-7-prev] ]

  ;   if not member? school-8 my-kids-schools and any? ach-8-non-null-neighbors
   ;    [ set pcd-ach-8 mean values-from ach-8-non-null-neighbors [pcd-ach-8-prev] ]

;     if not member? school-9 my-kids-schools and any? ach-9-non-null-neighbors
 ;      [ set pcd-ach-9 mean values-from ach-9-non-null-neighbors [pcd-ach-9-prev]
  ;     ]

    ] ;; end ask households

  ]  ;; end ifelse "perfect"


 ;; If individual variation selected, then "resourcefulness" of households determines the likelihood
 ;; that they will get accurate information and they do not have to rely only on their neighbors.
 ;; (Note that if info-source is set to "neighbors" this part not be executed.)

 if info-source = "indiv var" [
   ask households [
     if random-float 100 < resourcefulness
       ;; set perceptions to reality
       [ ;set pcd-ach-1 mean-achievement-of school-1
         ;set pcd-ach-2 mean-achievement-of school-2
         ;set pcd-ach-3 mean-achievement-of school-3
         ;set pcd-ach-4 mean-achievement-of school-4
         ;set pcd-ach-5 mean-achievement-of school-5
         ;set pcd-ach-6 mean-achievement-of school-6
         ;set pcd-ach-7 mean-achievement-of school-7
         ;set pcd-ach-8 mean-achievement-of school-8
         ;set pcd-ach-9 mean-achievement-of school-9
       ]
    ]
 ]  ;; endif "indiv var"

 ;; after getting perceptions based on info-source specified, create a list of school percepetions
 ask households [

  ; set perceived-school-info  (list (list school-1 pcd-ach-1 pct-green-of school-1 pct-blue-of school-1 pct-red-of school-1 pct-yellow-of school-1)
  ;                                  (list school-2 pcd-ach-2 pct-green-of school-2 pct-blue-of school-1 pct-red-of school-2 pct-yellow-of school-2)
  ;                                  (list school-3 pcd-ach-2 pct-green-of school-3 pct-blue-of school-1 pct-red-of school-3 pct-yellow-of school-3)
  ;                                  (list school-4 pcd-ach-4 pct-green-of school-4 pct-blue-of school-1 pct-red-of school-4 pct-yellow-of school-4)
  ;                                  (list school-5 pcd-ach-5 pct-green-of school-5 pct-blue-of school-1 pct-red-of school-5 pct-yellow-of school-5)
  ;                                  (list school-6 pcd-ach-6 pct-green-of school-6 pct-blue-of school-1 pct-red-of school-6 pct-yellow-of school-6)
  ;                                  (list school-7 pcd-ach-7 pct-green-of school-7 pct-blue-of school-1 pct-red-of school-7 pct-yellow-of school-7)
  ;                                  (list school-8 pcd-ach-8 pct-green-of school-8 pct-blue-of school-1 pct-red-of school-8 pct-yellow-of school-8)
  ;                                  (list school-9 pcd-ach-9 pct-green-of school-9 pct-blue-of school-1 pct-red-of school-9 pct-yellow-of school-9))

  set perceived-school-info perceptions
 ]

end

to create-new-students [nbr]
  create-custom-students nbr [
    set hidden? true
    set shape "person"
    set time-here 0
    setxy (random screen-size-x) (random screen-size-y)
    set my-household random-one-of households-here
    set color color-of my-household

    ;; assign students to a default school
    set assigned-school catchment-school-of my-household
    set attended-school nobody  ;; no one goes anywhere just yet

    ;; initialize incoming achievement. If non-random sort, scale the achievement by catchment area
    let my-catchment-area catchment-area-of my-household
    if my-catchment-area != catchment-area-of patch-here [ show "catchment area mismatch?" ] ;; error checking

    ifelse nr-sort? = true
      [ set achievement random-normal (6 + 0.5 * my-catchment-area) 0.1 ]
      [ set achievement random-normal 7.5  1.37 ]
    if achievement < 0 [ set achievement 0 ]   ; if neg number, just make zero

    set my-school-info []
    set schools-i-know []

  ]
end

to go-to-school-2
;; this is just for display purposes
  if attended-school != assigned-school [
    setxy xcor-of assigned-school  (ycor-of assigned-school - 1)
    set heading towards-nowrap attended-school
    set hidden? false
    pd
    fd (distance-nowrap attended-school)
  ]
  let xcor-temp xcor-of attended-school
  let ycor-temp ycor-of attended-school
  setxy (random-one-of (list (xcor-temp + random-float 1) (xcor-temp - random-float 1) ))
        (random-one-of (list (ycor-temp + random-float 1) (ycor-temp - random-float 1) ))

end

to go-to-school
;; this is just for display purposes
  let xcor-temp xcor-of attended-school
  let ycor-temp ycor-of attended-school
  setxy (random-one-of (list (xcor-temp + random-float 1) (xcor-temp - random-float 1) ))
        (random-one-of (list (ycor-temp + random-float 1) (ycor-temp - random-float 1) ))
  set hidden? false
end

to update-globals

    ;set nbr-schools count schools
  ;  set nbr-students count students
  let totalschools count schools

  ;  set pcd-ma-1 mean values-from households with [ pcd-ach-1 != 99 ][ pcd-ach-1 ]
  ;  set pcd-ma-2 mean values-from households with [ pcd-ach-2 != 99 ][ pcd-ach-2 ]
  ;  set pcd-ma-3 mean values-from households with [ pcd-ach-3 != 99 ][ pcd-ach-3 ]
  ;  set pcd-ma-4 mean values-from households with [ pcd-ach-4 != 99 ][ pcd-ach-4 ]
  ;  set pcd-ma-5 mean values-from households with [ pcd-ach-5 != 99 ][ pcd-ach-5 ]
  ;  set pcd-ma-6 mean values-from households with [ pcd-ach-6 != 99 ][ pcd-ach-6 ]
  ;  set pcd-ma-7 mean values-from households with [ pcd-ach-7 != 99 ][ pcd-ach-7 ]
  ;  set pcd-ma-8 mean values-from households with [ pcd-ach-8 != 99 ][ pcd-ach-8 ]
  ;  set pcd-ma-9 mean values-from households with [ pcd-ach-9 != 99 ][ pcd-ach-9 ]

    set pct-moving ( count students with [ attended-school != assigned-school and time-here = 1] )/
                     nbr-new-students * 100

    set pct-leaving ( 1 - ( count students with [ time-here = 1 ] / nbr-new-students ) ) * 100

    set pct-satisfied count students with [ satisfied? ] / count students * 100

    ifelse totalschools > 0
      [ set pct-capacity (count students) / (max-capacity * totalschools) * 100 ]
      [ set pct-capacity 0 ]

    ifelse any? students
      [ set stdev-ach standard-deviation values-from students [achievement] ]
      [ set stdev-ach 0 ]

    set frac-new-schools (count schools with [ color = blue ]) / totalschools

end

to do-plots
  set-current-plot "Mean Achievement"
  plot (mean values-from students [achievement] )

  set-current-plot "Pct Choosing"
  set-current-plot-pen "moving"
  plot pct-moving
  set-current-plot-pen "leaving"
  plot pct-leaving

  set-current-plot "Nbr of Schools"
  set-current-plot-pen "total"
  plot count schools
  set-current-plot-pen "new"
  plot total-new
  set-current-plot-pen "closed"
  plot total-closed

 ; set-current-plot "Pct Capacity"
 ; set-current-plot-pen "capacity"
 ; plot pct-capacity
 ; set-current-plot-pen "hundred"
 ; plot 100

 set-current-plot "District Enrollment"
 set-current-plot-pen "students"
 plot count students

 set-current-plot "%-Satisfied"
 plot pct-satisfied

 set-current-plot "Size Distribution"
 set-plot-x-range 0 round (max values-from schools [enroll] * 1.2 )
 histogram-from schools [enroll]

 set-current-plot "Leaving By Quartile"
 histogram-list leaving-list

 set-current-plot "Moving By Quartile"
 ;set moving-list values-from students with [ attended-school != assigned-school and time-here = 1][achievement-quart]
 ;histogram-list moving-list
 ;show moving-list
 histogram-from students with [ attended-school != assigned-school and time-here = 1][achievement-quart]

 ;plot-enrollments
 ;plot-incoming-students
 update-lorenz-and-gini-plots

end

to update-lorenz-and-gini-plots
  set-current-plot "Lorenz Curve"
  clear-plot

  ;; draw a straight line from lower left to upper right
  set-current-plot-pen "equal"
  plot 0
  plot 100

  set-current-plot-pen "lorenz"
  let interv precision (100 / (count schools with [hidden? = false])) 5
  set-plot-pen-interval interv
  plot 0

  let sorted-schools sort values-from schools with [hidden? = false] [pct-quart4]
  ;let total-achievement sum sorted-achievement
  let pct-sum-so-far 0
  let index 0
  let gini-index-reserve 0
  let xprev 0
  let xnow 0
  let yprev 0
  let ynow 0
  let x 0
  let y 0
  let sumxy 0
  let nbr-open-schools count schools with [hidden? = false]


  ;; now actually plot the Lorenz curve -- along the way, we also
  ;; calculate the Gini index
  repeat (count schools with [hidden? = false]) [
    set pct-sum-so-far (pct-sum-so-far + item index sorted-schools)
    plot pct-sum-so-far
    set index (index + 1)
    set xprev xnow
    set xnow (index / nbr-open-schools)
    set x xnow - xprev
    set yprev ynow
    set ynow (pct-sum-so-far / 100)
    set y (ynow + yprev)
    set sumxy (sumxy + (x * y))
    set gini-index-reserve
      gini-index-reserve +
      (index / nbr-open-schools) -
      (pct-sum-so-far / 100)
  ]

  let new (1 - sumxy)
  let old 0
  ifelse nbr-open-schools > 1
    [ set old (gini-index-reserve / nbr-open-schools) / area-of-equality-triangle ]
    [ set old 0 ]
  let diff new - old
 ; show "new: " + new + ", old: " + old + ", diff: " + diff + ", nbr-schools: " + nbr-open-schools
  set gini new

  ;; plot Gini Index
  set-current-plot "Gini Index"
 ; plot (gini-index-reserve / nbr-students) / area-of-equality-triangle
  plot gini
end

to-report area-of-equality-triangle
  ;; not really necessary to compute this when num-people is large;
  ;; if num-people is large, could just use estimate of 0.5
  let nbr-open-schools count schools with [hidden? = false]
  report (nbr-open-schools * (nbr-open-schools - 1) / 2) / (nbr-open-schools ^ 2)
end

to update-student-quartiles
   let sorted-achievement sort values-from students [achievement]
   let total-nbr length sorted-achievement
   ask students [
     ifelse total-nbr >= 4  ;; doesn't really makes sense to divide into quartiles if not at least 4 students
       [ ifelse achievement <= item (round total-nbr / 4) sorted-achievement
           [ set achievement-quart 4 ]
           [ ifelse achievement <= item (round total-nbr / 2) sorted-achievement
             [ set achievement-quart 3 ]
             [ ifelse achievement <= item (round total-nbr * (3 / 4)) sorted-achievement
               [ set achievement-quart 2 ]
               [ set achievement-quart 1 ]
             ]
           ]
       ]
       [ set achievement-quart 0 ]
   ]
end

to setup-patches
  ;; set up 9 zones for catchment areas
  ask patches [
    ifelse pxcor > screen-edge-x / 3
      [ set zone-x 3 ]
      [ ifelse pxcor >= (- screen-edge-x ) / 3
        [ set zone-x 2 ]
        [ set zone-x 1 ]
      ]
    ifelse pycor > screen-edge-y / 3
      [ set zone-y 1 ]
      [ ifelse pycor >= (- screen-edge-y ) / 3
        [ set zone-y 2 ]
        [ set zone-y 3 ]
      ]
   ]
    ;; assign a catchment area for each zone and initialize values
    ask patches [
    ifelse zone-x = 1
      [ ifelse zone-y = 1
        [ set catchment-area 1 ]
        [ ifelse zone-y = 2
          [ set catchment-area 4 ]
          [ set catchment-area 7 ]
        ]
      ]
      [ ifelse zone-x = 2
        [ ifelse zone-y = 1
          [ set catchment-area 2 ]
          [ ifelse zone-y = 2
            [ set catchment-area 5 ]
            [ set catchment-area 8 ]
          ]
        ]
        [ if zone-x = 3
          [ ifelse zone-y = 1
            [ set catchment-area 3 ]
            [ ifelse zone-y = 2
              [ set catchment-area 6 ]
              [ set catchment-area 9 ]
            ]
          ]
        ]
      ]

    ;; randomly assign hh-color
    ifelse random-float 100 < 33.33333
      [ set hh-color pink ]
      [ ifelse random-float 100 < 50.0
        [ set hh-color green ]
        [ set hh-color yellow ]
      ]
   ]

   ;; if nr-sort, concentrate hh-color by catchment-area
  if nr-sort?
    [ let c9-patches count patches with [ catchment-area = 9 ]
      let c8-patches count patches with [ catchment-area = 8 ]
      let c7-patches count patches with [ catchment-area = 7 ]
      let c6-patches count patches with [ catchment-area = 6 ]
      let c5-patches count patches with [ catchment-area = 5 ]
      let c4-patches count patches with [ catchment-area = 4 ]
      let c3-patches count patches with [ catchment-area = 3 ]
      let c2-patches count patches with [ catchment-area = 2 ]
      let c1-patches count patches with [ catchment-area = 1 ]
      let pink-min 0.7
      let green-min 0.7
      let yellow-min 0.7

      ask random-n-of (pink-min * (c6-patches + c8-patches + c9-patches)) patches with [ catchment-area = 6 or catchment-area = 8 or catchment-area = 9 ]
         [ set hh-color pink ]
      ask random-n-of (green-min * (c3-patches + c5-patches + c7-patches)) patches with [ catchment-area = 3 or catchment-area = 5 or catchment-area = 7 ]
        [ set hh-color green ]
      ask random-n-of (yellow-min * (c1-patches + c2-patches + c4-patches)) patches with [ catchment-area = 1 or catchment-area = 2 or catchment-area = 4]
        [ set hh-color yellow ]
    ]

end
to setup-schools
  ;; setup schools
  create-custom-schools init-nbr-schools [
    set color red
    set size 1.5
    set avail-spaces max-capacity
    set shape "building institution"
    set value-added 0
    set enroll init-nbr-students     ;; set these really high at first so schools don't get closed down
    set enroll-p1 init-nbr-students  ;; just because the get initialized to zero
    set enroll-p2 init-nbr-students
    set years-here 10  ;; initialize to something high
    set school-area 99
    set school-nbr school-nbr-index
    set school-nbr-index school-nbr-index + 1
    set label school-nbr
  ]

  ask random-n-of (init-nbr-schools / 9) schools with [school-area = 99][
    let c9patch random-one-of patches with [ catchment-area = 9 ]
    setxy (pxcor-of c9patch) (pycor-of c9patch)
    set school-area 9
  ]
  ask random-n-of (init-nbr-schools / 9) schools with [school-area = 99][
    let c8patch random-one-of patches with [ catchment-area = 8 ]
    setxy (pxcor-of c8patch) (pycor-of c8patch)
    set school-area 8
  ]
  ask random-n-of (init-nbr-schools / 9) schools with [school-area = 99][
    let c7patch random-one-of patches with [ catchment-area = 7 ]
    setxy (pxcor-of c7patch) (pycor-of c7patch)
    set school-area 7
  ]
  ask random-n-of (init-nbr-schools / 9) schools with [school-area = 99][
    let c6patch random-one-of patches with [ catchment-area = 6 ]
    setxy (pxcor-of c6patch) (pycor-of c6patch)
    set school-area 6
  ]
  ask random-n-of (init-nbr-schools / 9) schools with [school-area = 99][
    let c5patch random-one-of patches with [ catchment-area = 5 ]
    setxy (pxcor-of c5patch) (pycor-of c5patch)
    set school-area 5
  ]
  ask random-n-of (init-nbr-schools / 9) schools with [school-area = 99][
    let c4patch random-one-of patches with [ catchment-area = 4 ]
    setxy (pxcor-of c4patch) (pycor-of c4patch)
    set school-area 4
  ]
  ask random-n-of (init-nbr-schools / 9) schools with [school-area = 99][
    let c3patch random-one-of patches with [ catchment-area = 3 ]
    setxy (pxcor-of c3patch) (pycor-of c3patch)
    set school-area 3
  ]
  ask random-n-of (init-nbr-schools / 9) schools with [school-area = 99][
    let c2patch random-one-of patches with [ catchment-area = 2 ]
    setxy (pxcor-of c2patch) (pycor-of c2patch)
    set school-area 2
  ]
  ask random-n-of (init-nbr-schools / 9) schools with [school-area = 99][
    let c1patch random-one-of patches with [ catchment-area = 1 ]
    setxy (pxcor-of c1patch) (pycor-of c1patch)
    set school-area 1
  ]

end

to setup-schools-2
  ;; setup schools
  create-custom-schools 9 [
    set color red
    set size 2
    set avail-spaces max-capacity
    set shape "building institution"
    set value-added 0
    set enroll init-nbr-students     ;; set these really high at first so schools don't get closed down
    set enroll-p1 init-nbr-students  ;; just because the get initialized to zero
    set enroll-p2 init-nbr-students
    set years-here 10  ;; initialize to something larger than the length of a new school charter
  ]


  ;; move school to the appropriate place in the graphics window
  let school-list values-from schools [who]
  let dir 0
  foreach school-list [
    ask turtle ?  [
      set heading dir
      set dir dir + 45
    ]
  ]
  ask schools [
    ifelse (heading = 0 or heading = 180)
      [ fd screen-size-y / 3 ]
      [ ifelse (heading = 90 or heading = 270)
        [ fd screen-size-x / 3]
        [ fd sqrt ( screen-size-x ^ 2 + screen-size-y ^ 2 ) / 3]
      ]
   ]

 ;; one the school ends up at the same place as another under logic above.
 ;; move this one to the middle
 without-interruption [
   ask schools [
     if any? other-schools-here [ setxy 0 0 ]
   ]
 ]

 ask schools [
      set school-nbr catchment-area-of patch-here ;; assign a school to each catchment area
      set label school-nbr
 ]

end

to setup-households
  ;; create households
  ask patches [
    sprout-households 1 [
      set color hh-color-of patch-here
      set shape "house"
      set heading 90
      set hidden? true
      assign-local-school
   ;   set perceived-school-info
    ;    (list [1 99 99] [2 99 99] [3 99 99] [4 99 99] [5 99 99] [6 99 99] [7 99 99] [8 99 99] [9 99 99] )  ;; 99s are nulls
      set pcd-ach-1 99
      set pcd-ach-2 99
      set pcd-ach-3 99
      set pcd-ach-4 99
      set pcd-ach-5 99
      set pcd-ach-6 99
      set pcd-ach-7 99
      set pcd-ach-8 99
      set pcd-ach-9 99
    ;  set resourcefulness random-normal mean-resourcefulness 15
      set achievement-thresh random-normal mean-achiev-thresh 1
      set %-similar-wanted random-normal mean-%-sim-wanted 10
      if %-similar-wanted > 100 [ set %-similar-wanted 100 ]
      ifelse nr-sort? = true
        [ set mobility random-normal (10 * catchment-area-of patch-here) 5
          if mobility < 0 [ set mobility 0 ]
          if mobility > 100 [ set mobility 100 ]

        ]
        [ set mobility random-float 100 ]

      ;; if perfect-mobility then override previous values
      if perfect-mobility? [ set mobility 100 ]

      ;; distribute decision rules across households
      ifelse random-float 100 < pct-ach   ;; note:  this parameter is only used if choice-basis = "mix"
        [ set decision-rule "A"]  ;; make school choice decision based on max-achievement
        [ set decision-rule "S"]  ;; make school choice decision based on max-similarity
    ]
  ]
end

to propose-new-schools
  let tries 0
  create-custom-schools new-attempted [
    hideturtle
    set color blue
    set size 1.5
    set avail-spaces max-capacity
    set shape "building institution"
    set value-added (random-float 0.5)  ;; don't know how good the school will be
    set enroll 0
    set avail-spaces max-capacity
    set years-here 0
    setxy (random screen-size-x) (random screen-size-y)
    set new-school self

    ;; find a new spot if you are right on top of another school
    while [any? other-schools-here and tries < 5] [
      fd 1
      set tries tries + 1
    ]

    set school-area catchment-area-of patch-here
  ]


end

to new-school-exists?
  ask schools with [ years-here = 0 ] [
    let my-students students with [attended-school = myself ]
    set enroll-p2 enroll-p1
    set enroll-p1 enroll
    set enroll count my-students
    set enroll-ma (enroll + enroll-p1 + enroll-p2) / 3  ;; calc 3-year moving average of enrollment

    ;; if you are in year zero and don't have enough enrollment you don't really open (i.e., shutdown before you appear)
    ;; if you do have enough enrollment, you open and get an official school nbr
    ifelse (enroll < 0.01 * init-nbr-students); or (enroll-ma < enroll-ma-thresh)
      [ die ]
      [ set school-nbr school-nbr-index
        set school-nbr-index school-nbr-index + 1
        set label school-nbr
        set total-new total-new + 1
        set new-vas lput value-added new-vas
        set open-blue-areas lput school-area open-blue-areas
      ]
  ]

 ;; if the hoped for new school didn't end up having enough enrollment to open, then take your best option
 without-interruption [
   ask students with [ time-here = 0 and attended-school = nobody ] [
       choose-district-school
    ]
  ]


end

to assign-local-school
  let my-catchment-area catchment-area-of patch-here
  let catch-schools schools with [ school-area = my-catchment-area ]

  ifelse any? catch-schools
     [ set catchment-school random-one-of catch-schools ]
       ;set assigned-school min-one-of catch-schools [ distance-nowrap myself] ]
     [ set catchment-school min-one-of schools [ distance-nowrap myself]
       ;show "assigned to a school outside my ca"
     ]
end

to determine-satisfaction [school]
    let %-similar 0
    ;; first update %-similar
    ifelse color = green
      [ set %-similar pct-green-of school ]
      [ ifelse color = pink
        [ set %-similar pct-pink-of school ]
        [ set %-similar pct-yellow-of school ]
      ]

    if choice-basis = "achievement" or ( choice-basis = "mix" and decision-rule-of my-household = "A") [
     ifelse mean-achievement-of school >= achievement-thresh-of my-household
       [ set satisfied? true ]
       [ set satisfied? false ]
    ]
    if choice-basis = "similarity" or ( choice-basis = "mix" and decision-rule-of my-household != "A") [
     ifelse %-similar >= %-similar-wanted-of my-household
       [ set satisfied? true ]
       [ set satisfied? false ]
    ]

end

to plot-incoming-students
   let school-list values-from schools [ who ]
   let temp-school nobody
   set nbr-incoming-list []

   foreach school-list [
     set temp-school one-of schools with [ who = ? ]
     set nbr-incoming-list lput (list temp-school (count students with [ attended-school = temp-school and time-here = 1]) ) nbr-incoming-list
   ]
   set nbr-incoming-list sort-by [ item 1 ?1 > item 1 ?2] nbr-incoming-list
   set-current-plot "Incoming Students"
   plot-pen-reset
   foreach nbr-incoming-list [
     plot item 1 ?
   ]
end

to plot-enrollments
   let school-list values-from schools [ who ]
   let temp-school nobody
   let enroll-list []

   foreach school-list [
     set temp-school one-of schools with [ who = ? ]
     set enroll-list lput (list temp-school (enroll-of temp-school) ) enroll-list
   ]
   set enroll-list sort-by [ item 1 ?1 > item 1 ?2] enroll-list
   set-current-plot "Enrollments"
   plot-pen-reset
   foreach enroll-list [
     plot item 1 ?
   ]
end

to-report mobility-thresh [ school ]
  ;; this creates a mobility-threshold needed to attend a school based on the students distance
  ;; from that school.  i'm running the normalized (and recentered) distance through the logistic equation to smooth out the tails
  ;; (i.e., up to a certain distance the incremental distance it doesn't matter so much, and after a certain distance,
  ;; the incremental distance doesn't matter so much)
  let temp 0
  ask my-household [
    set temp (distance-nowrap school) / max-distance ;; normalize
    set temp (2 * temp) - 1                          ;; recenter
  ]
  report 1 / ( 1 + exp(- temp / 0.4)) * 100

end

to init-globals
  set nr-sort? true
  set init-nbr-students 500
  set init-nbr-schools 27
  set max-capacity init-nbr-students * max-capacity-pct
  set enroll-ma-thresh (1 / 2) * (1 / 9) * init-nbr-students
  set min-enroll init-nbr-students / init-nbr-schools * 0.1
  set school-nbr-index 1
  ask patch (- screen-edge-x) (- screen-edge-y) [ set max-distance distancexy-nowrap screen-edge-x screen-edge-y ]
  set leaving-list []
  set moving-list []
  set closed-mas []
  set closed-vas []
  set new-vas []
  set closed-red-vas []
  set closed-red-areas []
  set closed-red-yrs-here []
  set closed-blue-vas []
  set closed-blue-areas  []
  set closed-blue-yrs-here []
  set open-blue-areas []
  set red-survivors schools with [ color = red and years-here >= 5 ]
  set blue-survivors schools with [ color = blue and years-here >= 5 ]


end

to setup-plots
 ;; setup plots and plot initial values
 ;  set-current-plot "Pcd Minus Real"
 ;  set-current-plot-pen "zero"
 ;  repeat 10 [plot 0]
 set-current-plot "Size Distribution"
 ;set-plot-x-range 0 max-capacity-pct * init-nbr-students * 1.2
 set-plot-x-range 0 max values-from schools [enroll] * 1.2
 set-plot-y-range 0 count schools
 ;let k ( min list (sqrt init-nbr-students) (10 * ln (init-nbr-students) / ln (10)) )  ;; default formula from STATA for determine # of bins
 set-histogram-num-bars 6

 set-current-plot "Leaving By Quartile"
 set-plot-x-range 1 4
 set-histogram-num-bars 4

 set-current-plot "Moving By Quartile"
 set-plot-x-range 1 4
 set-histogram-num-bars 4

end

to get-b-space-data
  let rank 1
  let temp-list-va []
  let temp-list-ma []
  let va-list sort-by [ item 1 ?2  < item 1 ?1 ] values-from schools [ (list self value-added) ]
  let ma-list sort-by [ item 1 ?2  < item 1 ?1 ] values-from schools [ (list self mean-achievement) ]
  ;show va-list
  ;show ma-list

  ;; create initial value-added rankings
  foreach va-list [
    let temp-item ?
    set temp-item fput rank temp-item
    set temp-list-va lput temp-item temp-list-va
    set rank rank + 1 ]
  set va-list temp-list-va
  ;show va-list

  foreach va-list [
    ask schools [ if item 1 ? = self [ set va-rank item 0 ? ] ]
  ]

  ;; create initial mean achievement rankings
  set rank 1
  foreach ma-list [
    let temp-item ?
    set temp-item fput rank temp-item
    set temp-list-ma lput temp-item temp-list-ma
    set rank rank + 1 ]
  set ma-list temp-list-ma
  ;show ma-list
  foreach ma-list [
    ask schools [ if item 1 ? = self [ set ma-rank item 0 ? set init-ma mean-achievement ] ]
  ]

  ;show sort-by [ item 2 ?2 < item 2 ?1 ] values-from schools [ (list va-ranking self value-added) ]
 ; show sort-by [ item 2 ?2 < item 2 ?1 ] values-from schools [ (list ma-ranking self mean-achievement) ]

end

;; report overall numbers
to-report nbrschools report count schools end
to-report fracnew report frac-new-schools end
to-report dstenroll report count students end
to-report dstma report mean values-from students [achievement] end
to-report maxenroll report max values-from schools [ enroll ] end
to-report minenroll report min values-from schools [ enroll ] end
to-report fracq1leav
  ifelse not empty? leaving-list
    [ report (length filter [ ? = 1 ] leaving-list) / (length leaving-list)  ]
    [ report 999 ]
 end

;; report initial ma of closers (only doing this for original schools)
to-report clsdma_m
  ifelse not empty? closed-mas
    [ report mean closed-mas ]
    [ report 999 ]
end
to-report clsdma_sd
  ifelse length closed-mas > 1
    [ report standard-deviation closed-mas ]
    [ report 999 ]
end
to-report clsdma_n report length closed-mas end

;; report vas of all survivors and all closers
to-report srvva_m
  ifelse any? blue-survivors or any? red-survivors
    [ report mean values-from schools with [years-here >= 5][value-added] ]
    [ report 999 ]
end
to-report srvva_sd
  ifelse ( count blue-survivors + count red-survivors ) > 1
    [ report standard-deviation values-from schools with [years-here >= 5][value-added] ]
    [ report 999 ]
end
to-report srvva_n report length values-from schools with [years-here >= 5][value-added] end
to-report clsdva_m
  ifelse not empty? closed-vas
    [ report mean closed-vas ]
    [ report 999 ]
end
to-report clsdva_sd
  ifelse length closed-vas > 1
    [ report mean closed-vas ]
    [ report 999 ]
end
to-report clsdva_n report length closed-vas end


;; break out vas by original survivors versus new survivors
to-report srvva_r_m
  ifelse any? red-survivors
    [ report mean values-from red-survivors [value-added] ]
    [ report 999 ]
end
to-report srvva_r_sd
  ifelse count red-survivors > 1
    [ report standard-deviation values-from red-survivors [value-added] ]
    [ report 999 ]
end
to-report srvva_r_n report length values-from red-survivors [value-added] end
to-report srvva_b_m
  ifelse any? blue-survivors
    [ report mean values-from blue-survivors [value-added] ]
    [ report 999 ]
end
to-report srvva_b_sd
  ifelse count blue-survivors > 1
    [ report standard-deviation values-from blue-survivors [value-added] ]
    [ report 999 ]
end
to-report srvva_b_n report length values-from blue-survivors [value-added] end

;; break out vas by original closers versus new closers
to-report clsdva_r_m
  ifelse not empty? closed-red-vas
    [ report mean closed-red-vas ]
    [ report 999 ]
end
to-report clsdva_r_sd
  ifelse length closed-red-vas > 1
    [ report standard-deviation closed-red-vas ]
    [ report 999 ]
end
to-report clsdva_r_n report length closed-red-vas end
to-report clsdva_b_m
  ifelse not empty? closed-blue-vas
    [ report mean closed-blue-vas ]
    [ report 999 ]
end
to-report clsdva_b_sd
  ifelse length closed-blue-vas > 1
    [ report standard-deviation closed-blue-vas ]
    [ report 999 ]
end
to-report clsdva_b_n report length closed-blue-vas end

;; report the number of top 5 and bottom 5 who survived
to-report top5va report length filter [ ? <= 5 and ? != 0 ] values-from schools [ va-rank ] end
to-report btm5va report length filter [ ? >= 23 and ? != 0 ] values-from schools [ va-rank ] end
to-report top5ma report length filter [ ? <= 5 and ? != 0 ] values-from schools [ ma-rank ] end
to-report btm5ma report length filter [ ? >= 23 and ? != 0 ] values-from schools [ ma-rank ] end

;; count the number of closings in each catchment area broken out by
;; closings of original schools versus closings of new schools
to-report redclsd1 report length filter [ ? = 1 ] closed-red-areas end
to-report redclsd2 report length filter [ ? = 2 ] closed-red-areas end
to-report redclsd3 report length filter [ ? = 3 ] closed-red-areas end
to-report redclsd4 report length filter [ ? = 4 ] closed-red-areas end
to-report redclsd5 report length filter [ ? = 5 ] closed-red-areas end
to-report redclsd6 report length filter [ ? = 6 ] closed-red-areas end
to-report redclsd7 report length filter [ ? = 7 ] closed-red-areas end
to-report redclsd8 report length filter [ ? = 8 ] closed-red-areas end
to-report redclsd9 report length filter [ ? = 9 ] closed-red-areas end
to-report bluclsd1 report length filter [ ? = 1 ] closed-blue-areas end
to-report bluclsd2 report length filter [ ? = 2 ] closed-blue-areas end
to-report bluclsd3 report length filter [ ? = 3 ] closed-blue-areas end
to-report bluclsd4 report length filter [ ? = 4 ] closed-blue-areas end
to-report bluclsd5 report length filter [ ? = 5 ] closed-blue-areas end
to-report bluclsd6 report length filter [ ? = 6 ] closed-blue-areas end
to-report bluclsd7 report length filter [ ? = 7 ] closed-blue-areas end
to-report bluclsd8 report length filter [ ? = 8 ] closed-blue-areas end
to-report bluclsd9 report length filter [ ? = 9 ] closed-blue-areas end

;; count the number of openings in each catchment area
to-report bluopen1 report length filter [ ? = 1 ] open-blue-areas end
to-report bluopen2 report length filter [ ? = 2 ] open-blue-areas end
to-report bluopen3 report length filter [ ? = 3 ] open-blue-areas end
to-report bluopen4 report length filter [ ? = 4 ] open-blue-areas end
to-report bluopen5 report length filter [ ? = 5 ] open-blue-areas end
to-report bluopen6 report length filter [ ? = 6 ] open-blue-areas end
to-report bluopen7 report length filter [ ? = 7 ] open-blue-areas end
to-report bluopen8 report length filter [ ? = 8 ] open-blue-areas end
to-report bluopen9 report length filter [ ? = 9 ] open-blue-areas end
@#$#@#$#@
GRAPHICS-WINDOW
813
10
1243
461
17
17
12.0
1
10
1
1
1
0
1
1
1

CC-WINDOW
5
597
1252
692
Command Center
0

BUTTON
6
10
61
43
NIL
setup
NIL
1
T
OBSERVER
T
NIL

BUTTON
64
10
130
43
NIL
go
T
1
T
OBSERVER
T
NIL

PLOT
5
366
205
516
Size Distribution
NIL
NIL
0.0
0.0
0.0
10.0
true
false
PENS
"default" 1.0 1 -16777216 true

SLIDER
7
78
132
111
max-capacity-pct
max-capacity-pct
0
1
0.05
0.01
1
NIL

CHOOSER
139
10
273
55
choice-basis
choice-basis
"achievement" "similarity" "mix"
2

PLOT
207
210
407
360
Pct Choosing
NIL
NIL
0.0
100.0
0.0
100.0
true
true
PENS
"moving" 1.0 0 -1184463 true
"leaving" 1.0 0 -13345367 true

PLOT
611
52
811
205
Mean Achievement
NIL
NIL
0.0
100.0
5.0
8.0
true
false

SWITCH
278
131
405
164
school-effects?
school-effects?
0
1
-1000

CHOOSER
278
10
405
55
info-source
info-source
"perfect" "neighbors" "indiv var"
0

SLIDER
139
57
273
90
pct-ach
pct-ach
0
100
100
1
1
NIL

PLOT
612
206
812
356
Lorenz Curve
School %
Quart-4 %
0.0
100.0
0.0
100.0
true
false
PENS
"equal" 100.0 0 -16777216 true
"lorenz" 1.0 0 -2674135 true

SLIDER
7
46
131
79
external-mobility-thresh
external-mobility-thresh
0
100
75
1
1
NIL

PLOT
411
55
611
205
District Enrollment
NIL
NIL
0.0
100.0
0.0
10.0
true
false
PENS
"students" 1.0 0 -16777216 true
"schools" 1.0 0 -13840069 true

SLIDER
139
92
274
125
mean-achiev-thresh
mean-achiev-thresh
0
12
9
1
1
NIL

SLIDER
137
129
273
162
mean-%-sim-wanted
mean-%-sim-wanted
0
100
70
1
1
NIL

PLOT
7
210
207
360
%-Satisfied
NIL
NIL
0.0
10.0
0.0
100.0
true
false
PENS
"default" 1.0 0 -13840069 true

SWITCH
279
57
405
90
internal-choice?
internal-choice?
0
1
-1000

SWITCH
280
92
405
125
new-schools?
new-schools?
0
1
-1000

PLOT
411
207
611
357
Nbr of Schools
NIL
NIL
0.0
10.0
0.0
10.0
true
true
PENS
"New" 1.0 0 -13345367 true
"Closed" 1.0 0 -2674135 true
"Total" 1.0 0 -16777216 true

PLOT
206
366
406
516
Leaving By Quartile
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 1 -16777216 true

PLOT
407
367
607
517
Moving By Quartile
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 1 -16777216 true

PLOT
612
362
812
512
Gini Index
NIL
NIL
0.0
100.0
0.0
1.0
true
false

SWITCH
7
112
132
145
perfect-mobility?
perfect-mobility?
1
1
-1000

SWITCH
8
146
131
179
control-close?
control-close?
1
1
-1000

SLIDER
202
550
374
583
replication
replication
0
100
20
1
1
NIL

SLIDER
137
165
275
198
new-attempted
new-attempted
1
10
2
1
1
NIL

@#$#@#$#@
WHAT IS IT?
-----------
This section could give a general understanding of what the model is trying to show or explain.


HOW IT WORKS
------------
This section could explain what rules the agents use to create the overall behavior of the model.


HOW TO USE IT
-------------
This section could explain how to use the model, including a description of each of the items in the interface tab.


THINGS TO NOTICE
----------------
This section could give some ideas of things for the user to notice while running the model.


THINGS TO TRY
-------------
This section could give some ideas of things for the user to try to do (move sliders, switches, etc.) with the model.


EXTENDING THE MODEL
-------------------
This section could give some ideas of things to add or change in the procedures tab to make the model more complicated, detailed, accurate, etc.


NETLOGO FEATURES
----------------
This section could point out any especially interesting or unusual features of NetLogo that the model makes use of, particularly in the Procedures tab.  It might also point out places where workarounds were needed because of missing features.


RELATED MODELS
--------------
This section could give the names of models in the NetLogo Models Library or elsewhere which are of related interest.


CREDITS AND REFERENCES
----------------------
This section could contain a reference to the model's URL on the web if it has one, as well as any other necessary credits or references.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

building institution
false
0
Rectangle -7500403 true true 0 60 300 270
Rectangle -16777216 true false 130 196 168 256
Rectangle -16777216 false false 0 255 300 270
Polygon -7500403 true true 0 60 150 15 300 60
Polygon -16777216 false false 0 60 150 15 300 60
Circle -1 true false 135 26 30
Circle -16777216 false false 135 25 30
Rectangle -16777216 false false 0 60 300 75
Rectangle -16777216 false false 218 75 255 90
Rectangle -16777216 false false 218 240 255 255
Rectangle -16777216 false false 224 90 249 240
Rectangle -16777216 false false 45 75 82 90
Rectangle -16777216 false false 45 240 82 255
Rectangle -16777216 false false 51 90 76 240
Rectangle -16777216 false false 90 240 127 255
Rectangle -16777216 false false 90 75 127 90
Rectangle -16777216 false false 96 90 121 240
Rectangle -16777216 false false 179 90 204 240
Rectangle -16777216 false false 173 75 210 90
Rectangle -16777216 false false 173 240 210 255
Rectangle -16777216 false false 269 90 294 240
Rectangle -16777216 false false 263 75 300 90
Rectangle -16777216 false false 263 240 300 255
Rectangle -16777216 false false 0 240 37 255
Rectangle -16777216 false false 6 90 31 240
Rectangle -16777216 false false 0 75 37 90
Line -16777216 false 112 260 184 260
Line -16777216 false 105 265 196 265

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 30 30 240

circle 2
false
0
Circle -7500403 true true 16 16 270
Circle -16777216 true false 46 46 210

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 60 270 150 0 240 270 15 105 285 105
Polygon -7500403 true true 75 120 105 210 195 210 225 120 150 75

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 3.0pre5
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="vary_capacity_no_new" repetitions="1" runMetricsEveryTick="false">
    <setup>random-seed replication
setup</setup>
    <go>go</go>
    <timeLimit ticks="50"/>
    <metric>replication</metric>
    <metric>nbrschools</metric>
    <metric>fracnew</metric>
    <metric>dstma</metric>
    <metric>dstenroll</metric>
    <metric>gini</metric>
    <metric>pct-leaving</metric>
    <metric>pct-moving</metric>
    <metric>pct-satisfied</metric>
    <metric>maxenroll</metric>
    <metric>minenroll</metric>
    <metric>fracq1leav</metric>
    <metric>srvva_m</metric>
    <metric>srvva_sd</metric>
    <metric>srvva_n</metric>
    <metric>clsdva_m</metric>
    <metric>clsdva_sd</metric>
    <metric>clsdva_n</metric>
    <metric>clsdma_m</metric>
    <metric>clsdma_sd</metric>
    <metric>clsdma_n</metric>
    <metric>top5va</metric>
    <metric>btm5va</metric>
    <metric>top5ma</metric>
    <metric>btm5ma</metric>
    <metric>redclsd1</metric>
    <metric>redclsd2</metric>
    <metric>redclsd3</metric>
    <metric>redclsd4</metric>
    <metric>redclsd5</metric>
    <metric>redclsd6</metric>
    <metric>redclsd7</metric>
    <metric>redclsd8</metric>
    <metric>redclsd9</metric>
    <steppedValueSet variable="replication" first="1" step="1" last="20"/>
    <enumeratedValueSet variable="max-capacity-pct">
      <value value="0.2"/>
      <value value="0.1"/>
      <value value="0.05"/>
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pct-ach">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info-source">
      <value value="&quot;perfect&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-achiev-thresh">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-schools?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="choice-basis">
      <value value="&quot;mix&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-%-sim-wanted">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="internal-choice?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perfect-mobility?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="external-mobility-thresh">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="school-effects?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-close?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-attempted?">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="vary_capacity_new" repetitions="1" runMetricsEveryTick="false">
    <setup>random-seed replication
setup</setup>
    <go>go</go>
    <timeLimit ticks="50"/>
    <metric>replication</metric>
    <metric>nbrschools</metric>
    <metric>fracnew</metric>
    <metric>dstma</metric>
    <metric>dstenroll</metric>
    <metric>gini</metric>
    <metric>pct-leaving</metric>
    <metric>pct-moving</metric>
    <metric>pct-satisfied</metric>
    <metric>maxenroll</metric>
    <metric>minenroll</metric>
    <metric>fracq1leav</metric>
    <metric>srvva_m</metric>
    <metric>srvva_sd</metric>
    <metric>srvva_n</metric>
    <metric>clsdva_m</metric>
    <metric>clsdva_sd</metric>
    <metric>clsdva_n</metric>
    <metric>srvva_r_m</metric>
    <metric>srvva_r_sd</metric>
    <metric>srvva_r_n</metric>
    <metric>srvva_b_m</metric>
    <metric>srvva_b_sd</metric>
    <metric>srvva_b_n</metric>
    <metric>clsdva_r_m</metric>
    <metric>clsdva_r_sd</metric>
    <metric>clsdva_r_n</metric>
    <metric>clsdva_b_m</metric>
    <metric>clsdva_b_sd</metric>
    <metric>clsdva_b_n</metric>
    <metric>top5va</metric>
    <metric>btm5va</metric>
    <metric>top5ma</metric>
    <metric>btm5ma</metric>
    <metric>redclsd1</metric>
    <metric>redclsd2</metric>
    <metric>redclsd3</metric>
    <metric>redclsd4</metric>
    <metric>redclsd5</metric>
    <metric>redclsd6</metric>
    <metric>redclsd7</metric>
    <metric>redclsd8</metric>
    <metric>redclsd9</metric>
    <metric>bluclsd1</metric>
    <metric>bluclsd2</metric>
    <metric>bluclsd3</metric>
    <metric>bluclsd4</metric>
    <metric>bluclsd5</metric>
    <metric>bluclsd6</metric>
    <metric>bluclsd7</metric>
    <metric>bluclsd8</metric>
    <metric>bluclsd9</metric>
    <metric>bluopen1</metric>
    <metric>bluopen2</metric>
    <metric>bluopen3</metric>
    <metric>bluopen4</metric>
    <metric>bluopen5</metric>
    <metric>bluopen6</metric>
    <metric>bluopen7</metric>
    <metric>bluopen8</metric>
    <metric>bluopen9</metric>
    <steppedValueSet variable="replication" first="1" step="1" last="20"/>
    <enumeratedValueSet variable="max-capacity-pct">
      <value value="0.2"/>
      <value value="0.1"/>
      <value value="0.05"/>
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pct-ach">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info-source">
      <value value="&quot;perfect&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-achiev-thresh">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-schools?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="choice-basis">
      <value value="&quot;mix&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-%-sim-wanted">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="internal-choice?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perfect-mobility?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="external-mobility-thresh">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="school-effects?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-close?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-attempted?">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="ach_vs_sim" repetitions="1" runMetricsEveryTick="false">
    <setup>random-seed replication
setup</setup>
    <go>go</go>
    <timeLimit ticks="50"/>
    <metric>replication</metric>
    <metric>nbrschools</metric>
    <metric>fracnew</metric>
    <metric>dstma</metric>
    <metric>dstenroll</metric>
    <metric>gini</metric>
    <metric>pct-leaving</metric>
    <metric>pct-moving</metric>
    <metric>pct-satisfied</metric>
    <metric>maxenroll</metric>
    <metric>minenroll</metric>
    <metric>fracq1leav</metric>
    <metric>srvva_m</metric>
    <metric>srvva_sd</metric>
    <metric>srvva_n</metric>
    <metric>clsdva_m</metric>
    <metric>clsdva_sd</metric>
    <metric>clsdva_n</metric>
    <metric>top5va</metric>
    <metric>btm5va</metric>
    <metric>top5ma</metric>
    <metric>btm5ma</metric>
    <metric>redclsd1</metric>
    <metric>redclsd2</metric>
    <metric>redclsd3</metric>
    <metric>redclsd4</metric>
    <metric>redclsd5</metric>
    <metric>redclsd6</metric>
    <metric>redclsd7</metric>
    <metric>redclsd8</metric>
    <metric>redclsd9</metric>
    <metric>bluclsd1</metric>
    <metric>bluclsd2</metric>
    <metric>bluclsd3</metric>
    <metric>bluclsd4</metric>
    <metric>bluclsd5</metric>
    <metric>bluclsd6</metric>
    <metric>bluclsd7</metric>
    <metric>bluclsd8</metric>
    <metric>bluclsd9</metric>
    <metric>bluopen1</metric>
    <metric>bluopen2</metric>
    <metric>bluopen3</metric>
    <metric>bluopen4</metric>
    <metric>bluopen5</metric>
    <metric>bluopen6</metric>
    <metric>bluopen7</metric>
    <metric>bluopen8</metric>
    <metric>bluopen9</metric>
    <steppedValueSet variable="replication" first="1" step="1" last="20"/>
    <enumeratedValueSet variable="max-capacity-pct">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pct-ach">
      <value value="0"/>
      <value value="25"/>
      <value value="50"/>
      <value value="75"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info-source">
      <value value="&quot;perfect&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-achiev-thresh">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-schools?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="choice-basis">
      <value value="&quot;mix&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-%-sim-wanted">
      <value value="75"/>
      <value value="50"/>
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="internal-choice?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perfect-mobility?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="external-mobility-thresh">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="school-effects?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-close?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-attempted?">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="close_control" repetitions="1" runMetricsEveryTick="false">
    <setup>random-seed replication
setup</setup>
    <go>go</go>
    <timeLimit ticks="50"/>
    <metric>replication</metric>
    <metric>nbrschools</metric>
    <metric>fracnew</metric>
    <metric>dstma</metric>
    <metric>dstenroll</metric>
    <metric>gini</metric>
    <metric>pct-leaving</metric>
    <metric>pct-moving</metric>
    <metric>pct-satisfied</metric>
    <metric>maxenroll</metric>
    <metric>minenroll</metric>
    <metric>fracq1leav</metric>
    <metric>srvva_m</metric>
    <metric>srvva_sd</metric>
    <metric>srvva_n</metric>
    <metric>clsdva_m</metric>
    <metric>clsdva_sd</metric>
    <metric>clsdva_n</metric>
    <metric>top5va</metric>
    <metric>btm5va</metric>
    <metric>top5ma</metric>
    <metric>btm5ma</metric>
    <metric>redclsd1</metric>
    <metric>redclsd2</metric>
    <metric>redclsd3</metric>
    <metric>redclsd4</metric>
    <metric>redclsd5</metric>
    <metric>redclsd6</metric>
    <metric>redclsd7</metric>
    <metric>redclsd8</metric>
    <metric>redclsd9</metric>
    <metric>bluclsd1</metric>
    <metric>bluclsd2</metric>
    <metric>bluclsd3</metric>
    <metric>bluclsd4</metric>
    <metric>bluclsd5</metric>
    <metric>bluclsd6</metric>
    <metric>bluclsd7</metric>
    <metric>bluclsd8</metric>
    <metric>bluclsd9</metric>
    <metric>bluopen1</metric>
    <metric>bluopen2</metric>
    <metric>bluopen3</metric>
    <metric>bluopen4</metric>
    <metric>bluopen5</metric>
    <metric>bluopen6</metric>
    <metric>bluopen7</metric>
    <metric>bluopen8</metric>
    <metric>bluopen9</metric>
    <steppedValueSet variable="replication" first="1" step="1" last="20"/>
    <enumeratedValueSet variable="max-capacity-pct">
      <value value="0.2"/>
      <value value="0.1"/>
      <value value="0.05"/>
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pct-ach">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info-source">
      <value value="&quot;perfect&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-achiev-thresh">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-schools?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="choice-basis">
      <value value="&quot;mix&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-%-sim-wanted">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="internal-choice?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perfect-mobility?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="external-mobility-thresh">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="school-effects?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-close?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-attempted?">
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="new_attempted" repetitions="1" runMetricsEveryTick="false">
    <setup>random-seed replication
setup</setup>
    <go>go</go>
    <timeLimit ticks="50"/>
    <metric>replication</metric>
    <metric>nbrschools</metric>
    <metric>fracnew</metric>
    <metric>dstma</metric>
    <metric>dstenroll</metric>
    <metric>gini</metric>
    <metric>pct-leaving</metric>
    <metric>pct-moving</metric>
    <metric>pct-satisfied</metric>
    <metric>maxenroll</metric>
    <metric>minenroll</metric>
    <metric>fracq1leav</metric>
    <metric>srvva_m</metric>
    <metric>srvva_sd</metric>
    <metric>srvva_n</metric>
    <metric>clsdva_m</metric>
    <metric>clsdva_sd</metric>
    <metric>clsdva_n</metric>
    <metric>top5va</metric>
    <metric>btm5va</metric>
    <metric>top5ma</metric>
    <metric>btm5ma</metric>
    <metric>redclsd1</metric>
    <metric>redclsd2</metric>
    <metric>redclsd3</metric>
    <metric>redclsd4</metric>
    <metric>redclsd5</metric>
    <metric>redclsd6</metric>
    <metric>redclsd7</metric>
    <metric>redclsd8</metric>
    <metric>redclsd9</metric>
    <metric>bluclsd1</metric>
    <metric>bluclsd2</metric>
    <metric>bluclsd3</metric>
    <metric>bluclsd4</metric>
    <metric>bluclsd5</metric>
    <metric>bluclsd6</metric>
    <metric>bluclsd7</metric>
    <metric>bluclsd8</metric>
    <metric>bluclsd9</metric>
    <metric>bluopen1</metric>
    <metric>bluopen2</metric>
    <metric>bluopen3</metric>
    <metric>bluopen4</metric>
    <metric>bluopen5</metric>
    <metric>bluopen6</metric>
    <metric>bluopen7</metric>
    <metric>bluopen8</metric>
    <metric>bluopen9</metric>
    <steppedValueSet variable="replication" first="1" step="1" last="20"/>
    <enumeratedValueSet variable="max-capacity-pct">
      <value value="0.1"/>
      <value value="0.05"/>
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pct-ach">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="info-source">
      <value value="&quot;perfect&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-achiev-thresh">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-schools?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="choice-basis">
      <value value="&quot;mix&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mean-%-sim-wanted">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="internal-choice?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perfect-mobility?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="external-mobility-thresh">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="school-effects?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-close?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="new-attempted?">
      <value value="1"/>
      <value value="3"/>
      <value value="5"/>
      <value value="7"/>
      <value value="9"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
