;;;  INTERFACE FIXES (plots redraw when changed, pick one turtle to follow)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Variable and Breed declarations ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

globals
[
  ;; lists used to create the various turtles
  shape-names       ;; list that holds the names of the non-sick shapes a student's turtle can have
  colors            ;; list that holds the colors used for students' turtles
  color-names       ;; list that holds the names of the colors used for students' turtles
  used-shape-colors ;; list that holds the shape-color pairs that are already being used

  ;; state variables for the model.  These are only set during SETUP and Re-Start, in order to
  ;; keep things from breaking by throwing a switch while the model runs
  food-for-individuals  ;; do patches have food for each individual, in essence letting everyone act in parallel universes
  patches-with-food  ;;a list with x,y coordinates of patches with food.  Used for data saving

  clock              ;;used to synch when saving, and for plots
  clock-replay       ;;used by the replay function
  replaying?         ;;a flag to indicate if the model is replaying or not
  going?             ;;a flag to indicate if the model is going or not
  saving?            ;;a flag to indicate if the model is doing periodic autosaves or not
  save-file          ;;file to which data is saved

  visual-state       ;;a list that says whether the turtles, patche, best are visible
  dead-memory        ;;a list retaining the steps-memory of turtles that leave the simulation

  data-list          ;;contains everything... setup, patch distribution, turtle movements
  new-food-counter   ;;counter for number of times new food has been generated
  re-run-counter     ;;counter for number of times the part-sim has been run
  run-which?         ;;the currently viewed run
  food-which?        ;;the currently used food arrangement
  data-which?        ;;the currently viewed set of data
  replay-landscape?  ;;for replay - in the original run, was landscape visible?
  replay-turtles?    ;;for replay - in the original run, were the turtles visible?
  replay-best?       ;;for replay - in the original run, was there a trail behind the turtle with the most food?

  ;; misc
  max-possible-codes ;; total number of possible unique shape/color combinations
]

turtles-own
[
  base-shape   ;; original shape of a turtle
  step-size    ;; the amount that a turtle will go forward in the current direction
  food-stored  ;; the amount of food stored by the turtle
  food-locations ;; patches with food for the turtle
  food-values  ;; how much food is available at each patch?
  food-here?   ;; is there food in the current location?

  moved?   ;; a variable to limit turtles to one move each clock tick

  steps         ;;total number of steps taken
  steps-memory  ;; a list with the current position of the turtle.  used for data saving
  played-steps  ; a list with all the steps replayed so far.  used for replay

  turning-memory          ;; a measure of the turning of the turtle's path

  user-id  ;; unique id, input by the client when they log in, to identify each student turtle
           ;; androids generate one for the purposes of the save feature
]

breeds
[
  androids  ;; created by the CREATE ANDROIDS button; not controlled by anyone
  students  ;; created and controlled by the clients
]


patches-own
[
  food      ;; the amount of food available on the patch
  track     ;; is the patch showing the track of a passing turtle?
  eaten     ;; how many turtles have eaten from the patch (useful for parallel universes)
]

;;;;;;;;;;;;;;;;;;;;;
;; Setup Functions ;;
;;;;;;;;;;;;;;;;;;;;;

to startup
  hubnet-set-client-interface "COMPUTER" [ "foraging-client.nlogo" ]
  hubnet-reset
  setup
end


;; give the user some information about what the setup button does so they can
;; know whether they want to proceed before actually doing the setup
to setup-prompt
  if user-yes-or-no? ("The SETUP button should only be used when starting "
              + "over with a new group (such as a new set of students) since "
              + "all data is lost.  Use the RE-RUN button for continuing with "
              + "an existing group."
              + "\n\nDo you really want to setup the model?")
  [
    user-message "Before closing this dialog, please do the following:"
                 + "\n  -Have everyone that is currently logged in, log off and "
                 + "then kick all remianing clients with the HubNet Console."
    setup
  ]
end


;; Initializes the display, and creates a list that contains the names of the shapes
;; used by turtles in this activity.  Also initializes the data lists.
to setup
  clear-patches
  clear-turtles
  clear-output
  setup-vars
  grow-landscape
  re-run
  set saving? save?
  if saving?
  [ save-prompt
  ]
end



to grow-landscape
  ask patches
  [ set pcolor black
    set food 0
    set track 0
  ]
  if Special-Start? = "None"
  [ ask random-n-of patch-number patches [ set food 1]
    repeat (patch-size - 1)
    [ ask patches with [ food > 0 ] [ ask neighbors4 [set food 1] ]
    ]
  ]
  if Special-Start? = "Central Food"
  [ ask patch 0 0 [ set food 1]
    repeat 2
    [ ask patches with [ food > 0 ] [ ask neighbors4 [set food 1] ]
    ]
    ask patches with [(abs pxcor = round (screen-edge-x / 2)) and (abs pycor = round (screen-edge-y / 2))] [set food 1]
    repeat (patch-size - 1)
    [ ask patches with [ food > 0 ] [ ask neighbors4 [set food 1] ]
    ]
  ]
  if landscape?
  [ ask patches with [ food > 0]
    [ set pcolor red]
  ]
  set patches-with-food values-from patches with [food > 0] [(list pxcor pycor food)]
  set new-food-counter new-food-counter + 1
  set food-which? new-food-counter
end

to new-food
  grow-landscape
  re-run
end

;; initialize global variables
to setup-vars
  set shape-names ["wide wedge" "square" "car" "thin wedge" "big boat" "pickup truck"
                   "nu" "uu" "circle" "butterfly" "wolf" "sheep" "lobster" "monster"
                   "moose" "bear" "teddy bear"]
  set colors      [ white   gray   brown   yellow   green   lime   turquoise
                    cyan   sky   blue   violet orange magenta pink]
  set color-names ["white" "gray" "brown" "yellow" "green" "lime" "turquoise"
                   "cyan" "sky" "blue" "violet" "orange" "magenta" "pink"]
  set max-possible-codes (length colors * length shape-names)
  set used-shape-colors []
  set save-file false
  set data-list [["setup"]]
  show "setup-vars"
  show "length " + length data-list
  show data-list
  set new-food-counter -1
  set re-run-counter -1
end

;; initialize the plot
to setup-plot
  clear-all-plots
end


to re-run
  ;what is the overall mode for this run?
  set food-for-individuals own-food
  set clock 0

  ;set all the button flags to false
  set replaying? false
  set going? false

  ;;restore patches
  ask patches
  [ set eaten 0
    set track 0
    ;check to see if they're supposed to have food
    if member? (list pxcor pycor) map [remove-item 2 ?] patches-with-food
    [ set food item 2 item (position (list pxcor pycor) map [remove-item 2 ?] patches-with-food) patches-with-food
    ]
  ]
  if food-for-individuals
  [ ask turtles
    [ set food-locations map [list item 0 ? item 1 ?] patches-with-food
      set food-values map [ item 2 ? ] patches-with-food
    ]
  ]
  ask turtles
  [ if Special-Start? = "None"
    [ setxy (item 0 item 0 steps-memory) (item 1 item 0 steps-memory) ]
    if Special-Start? = "Central Food"
    [ setxy 0 0 ]
    set food-stored 0
    set steps 0
    forage
    set moved? false
    ;;turtles save position data
    set steps-memory (list (list xcor ycor food-here? clock))
    set played-steps (list (list xcor ycor))
    set turning-memory [100]
  ]
  ask students
  [ hubnet-send user-id "Located at:" ("(" + pxcor + "," + pycor + ")")
    hubnet-send user-id "Food here?" (ifelse-value food-here? ["Yes"]["No"])
    hubnet-send user-id "Food gathered" food-stored
    hubnet-send user-id "Steps" steps
  ]

  setup-plot
  if count turtles > 0
  [ update-graphics]

  ;manage data for data-list, etc.
  set re-run-counter re-run-counter + 1
  set run-which? re-run-counter
  set data-list lput (list "run" run-which? "food" food-which? food-for-individuals patches-with-food) data-list
  show "re-run"
  show "length " + length data-list
  show data-list
  set data-which? (length data-list - 1)
  set visual-state (list (list clock landscape? turtles? best?))
  set dead-memory []
end


;; creates turtles that wander at random
to create-androids
  create-custom-androids number
  [
    ;;set constants for this turtle
    set color gray
    set heading (random-int-or-float 4) * 90
    set base-shape "android"
    set shape base-shape
    set step-size 1
    set user-id "" + random 999999999

    ;;setup for movement
    set steps 0
    set moved? false
    if Special-Start? = "None"
    [ setxy (random-int-or-float screen-size-x) (random-int-or-float screen-size-y) ]
    if Special-Start? = "Central Food"
    [ setxy 0 0 ]

    ;;setup for display
    set hidden? not turtles?

    ;;setup food
    if food-for-individuals
    [ set food-locations map [list item 0 ? item 1 ?] patches-with-food
      set food-values map [ item 2 ? ] patches-with-food
    ]
    set food-stored 0
    forage

    ;;turtles save position data
    set steps-memory (list (list xcor ycor food-here? clock))
    set played-steps (list (list xcor ycor))
    set turning-memory [100]
  ]
end




;;;;;;;;;;;;;;;;;;;;;;;
;; Runtime Functions ;;
;;;;;;;;;;;;;;;;;;;;;;;

to go-flags
  if replaying?
  [ stop
  ]
  if not going?
  [ set going? true
    if saving? != save?
    [ set saving? save?
      if saving?
      [ save-prompt
      ]
    ]
    set data-list lput (list "positions" visual-state values-from turtles [(list user-id shape color steps-memory)] dead-memory) data-list
    show "go-flags"
    show "length " + length data-list
    show data-list
  ]
  go
end

to go
  every 0.1
  [
    set clock precision (clock + .1) 1
    ask turtles
    [ set moved? false
    ]
    if ((landscape? != item 1 last visual-state) or (turtles? != item 2 last visual-state) or (best? != item 3 last visual-state))
    [ set visual-state lput (list clock landscape? turtles? best?) visual-state
    ]

    ;;allow the androids to wander around the graphics window
    androids-wander
    ;; get commands and data from the clients
    listen-clients

    if count turtles > 0
    [ ifelse best?
      [ ask max-one-of turtles [food-stored]
        [ set track-of patch-here 100]
        ask patches
        [ set track track - 2]
      ]
      [ ask patches with [track > 0]
        [ set track 0]
      ]

      update-graphics
      do-plots
    ]
  ]

;  every 10
;  [
    set data-list replace-item (length data-list - 1) data-list (list "positions" visual-state values-from turtles [(list user-id shape color steps-memory)] dead-memory)
    show "go"
    show "length " + length data-list
    show data-list
;  ]

  every 30
  [ if saving?
    [ save-data
;      show "saving"
    ]
  ]
end

to update-graphics
  ifelse landscape?
  [ ask patches
    [ ifelse food > 0
      [ ifelse track > 0
        [ set pcolor scale-color orange track 0 100]
        [ ifelse food-for-individuals
          [ set pcolor scale-color red eaten count turtles (0 - .3 * count turtles)
          ]
          [ set pcolor red
          ]
        ]
      ]
      [ ifelse track > 0
        [ set pcolor scale-color yellow track 0 100]
        [ set pcolor black]
      ]
    ]
  ]
  [ ask patches
    [ ifelse track > 0
      [ set pcolor scale-color yellow track 0 100]
      [ set pcolor black]
    ]
  ]
  ask turtles [ set hidden? not turtles?]
end

;; controls the motion of the androids
to androids-wander
  every android-delay
  [
    ask androids with [not moved?]
    [
      rt (random-int-or-float 8) * 45
      if going?
      [ jump-nowrap 1
        set moved? true
        forage
        set steps-memory lput (list xcor ycor food-here? clock) steps-memory
        set played-steps lput (list xcor ycor) played-steps
        set turning-memory lput (100 * turning (last-items played-steps turn-steps) turn-steps) turning-memory
      ]
    ]
  ]
end

to forage
  locals [this-patch]
;  show "foraging"
  ifelse food-for-individuals
  [ set this-patch list pxcor-of patch-here pycor-of patch-here
    ifelse  member? this-patch food-locations
    [ set food-here? true
      set food-stored food-stored + 1
      set food-values replace-item (position this-patch food-locations) food-values (item (position this-patch food-locations) food-values - 1)
      if item (position this-patch food-locations) food-values = 0
      [ set food-values remove-item (position this-patch food-locations) food-values
        set food-locations remove this-patch food-locations
      ]
      set eaten-of patch-here eaten-of patch-here + 1
    ]
    [ set food-here? false
    ]
  ]
  [ ifelse food-of patch-here > 0
    [ set food-here? true
      set food-stored food-stored + 1
      set food-of patch-here food-of patch-here - 1
    ]
    [ set food-here? false
    ]
  ]
end

to do-plots
  set-current-plot "Food Collected"
  if plot-setting = "Food - Total"
  [ set-current-plot-pen "Total" plot sum values-from turtles [food-stored]
  ]
  if plot-setting = "Food - Stats"
  [ set-current-plot-pen "Average" plot mean values-from turtles [food-stored]
    set-current-plot-pen "Most" plot value-from max-one-of turtles [food-stored] [food-stored]
    set-current-plot-pen "Least" plot value-from min-one-of turtles [food-stored] [food-stored]
  ]
  if plot-setting = "Food - Individuals"
  [
  ]
  set-current-plot "Data Histogram"
  if histogram-setting = "Food"
  [ set-current-plot-pen "Food"
    if max values-from turtles [food-stored] > plot-x-max
    [ set-plot-x-range 0 (max values-from turtles [food-stored] + 5)
    ]
    histogram-from turtles [food-stored]
  ]
  if histogram-setting = "Turning"
  [ set-current-plot-pen "Turning"
    set-plot-x-range 0 101
    histogram-from turtles [last turning-memory]
  ]

end





;calculates a turning coefficient for a final interval of a list
;interval is a positive number greater than 2 (anything less reports 0)
;xylist is a list of positions [x1 y1]
to-report turning [xylist interval]
  locals [steps-list d-list]
  set steps-list xylist

  ;if not enough steps have been taken yet for ANY turning calculation
  if length steps-list <= 2
  [ report 0
  ]
  ;build a list of the delta positions
  set d-list (map [list (item 0 ?1 - item 0 ?2) (item 1 ?1 - item 1 ?2)] (but-first steps-list) (but-last steps-list))

  report sqrt ((mean map [item 0 ?] d-list) ^ 2 + (mean map [item 1 ?] d-list) ^ 2)
end












;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; Code for interacting with the clients
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to login
  if going? or replaying?
  [ stop
  ]
  listen-clients
end

;; determines which client sent a command, and what the command was
to listen-clients
  while [ hubnet-message-waiting? ]
  [
    hubnet-fetch-message
    ifelse hubnet-enter-message?
    [ create-new-student ]
    [
      ifelse hubnet-exit-message?
      [ remove-student ]
      [ execute-command hubnet-message-tag ]
    ]
  ]
end


;; NetLogo knows what each student turtle is supposed to be
;; doing based on the tag sent by the node:
;; step-size - set the turtle's step-size
;; Up    - make the turtle move up by step-size
;; Down  - make the turtle move down by step-size
;; Right - make the turtle move right by step-size
;; Left  - make the turtle move left by step-size
;; Get a Different Turtle - change the turtle's shape and color
to execute-command [command]
;  if command = "step-size"
;  [
;    ask students with [user-id = hubnet-message-source]
;    [ set step-size hubnet-message ]
;    stop
;  ]
  if going?
  [ if command = "Up"
    [ execute-move 0 stop ]
    if command = "Up-Right"
    [ execute-move 45 stop ]
    if command = "Right"
    [ execute-move 90 stop ]
    if command = "Down-Right"
    [ execute-move 135 stop ]
    if command = "Down"
    [ execute-move 180 stop ]
    if command = "Down-Left"
    [ execute-move 225 stop ]
    if command = "Left"
    [ execute-move 270 stop ]
    if command = "Up-Left"
    [ execute-move 315 stop ]
  ]
  if command = "Change Appearance"
  [ execute-change-turtle stop ]
end

;; Create a turtle, set its shape, color, and position
;; and tell the node what its turtle looks like and where it is
to create-new-student
  create-custom-students 1
  [
    ;;set constants for this turtle
    set user-id hubnet-message-source
    set-unique-shape-and-color
    set step-size 1

    ;;setup for movement
    set steps 0
    set moved? false
    if Special-Start? = "None"
    [ setxy (random-int-or-float screen-size-x) (random-int-or-float screen-size-y) ]
    if Special-Start? = "Central Food"
    [ setxy 0 0 ]

    ;;setup for display
    set hidden? not turtles?

    ;;setup food
    if food-for-individuals
    [ set food-locations map [list item 0 ? item 1 ?] patches-with-food
      set food-values map [ item 2 ? ] patches-with-food
    ]
    set food-stored 0
    forage

    ;;turtles save position data
    set steps-memory (list (list xcor ycor food-here? clock))
    set played-steps (list (list xcor ycor))
    set turning-memory [100]

    send-info-to-clients

;    set hidden? not turtles?
;    setup-student-vars
    ;; we want to make sure that the clients all have the same plot ranges,
    ;; so when somebody logs in, set the plot ranges to themselves so that
    ;; everybody will have the same size plots.
;    set-plot-y-range plot-y-min plot-y-max
;    set-plot-x-range plot-x-min plot-x-max
  ]
end

;; sets the turtle variables to appropriate initial values
to setup-student-vars  ;; turtle procedure
  set user-id hubnet-message-source
  set-unique-shape-and-color
  if Special-Start? = "None"
  [ setxy random-int-or-float screen-size-x random-int-or-float screen-size-y
  ]
  if Special-Start? = "Central Food"
  [ setxy 0 0
  ]
  set heading 0
  set step-size 1
  set steps 0
  set turning-memory [100]
  set moved? false
  set food-stored 0
  if food-for-individuals
  [ set food-locations map [list item 0 ? item 1 ?] patches-with-food
    set food-values map [ item 2 ? ] patches-with-food
  ]
  set food-here? (food-of patch-here > 0)
end

;; pick a base-shape and color for the turtle
to set-unique-shape-and-color
  locals [code]
  set code random-int-or-float max-possible-codes
  while [member? code used-shape-colors and count students < max-possible-codes]
  [
    set code random-int-or-float max-possible-codes
  ]
  set used-shape-colors (lput code used-shape-colors)
  set base-shape item (code mod length shape-names) shape-names
  set shape base-shape
  set color item (code / length shape-names) colors
end

;; report the string version of the turtle's color
to-report color-string [color-value]
  report item (position color-value colors) color-names
end

;; sends the appropriate monitor information back to the client
to send-info-to-clients
  hubnet-send user-id "You are a:" (color-string color) + " " + base-shape
  hubnet-send user-id "Located at:" ("(" + pxcor + "," + pycor + ")")
  hubnet-send user-id "Food here?" (ifelse-value food-here? ["Yes"]["No"])
  hubnet-send user-id "Food gathered" food-stored
  hubnet-send user-id "Steps" steps
end

;; Kill the turtle, release its shape and color
to remove-student
  ask students with [user-id = hubnet-message-source]
  [
    set used-shape-colors remove my-code used-shape-colors
    set dead-memory lput (list (list user-id shape color steps-memory)) dead-memory
    ask patches
    [ if (member? (list pxcor pycor) map [remove-item 2 ?] patches-with-food) and not (member? (list pxcor pycor) food-locations-of myself)
      [ set eaten eaten - 1
      ]
    ]
    die
  ]
end

;; translates a student turtle's shape and color into a code
to-report my-code
  report (position base-shape shape-names) + (length shape-names) * (position color colors)
end

;; Cause the students to move forward step-size in new-heading's heading
to execute-move [new-heading]
  ask students with [(user-id = hubnet-message-source) and (not moved?)]
  [
    set heading new-heading
    ;; don't allow students to wrap around the screen
    ;; so use jump-nowrap
    jump-nowrap 1
    set moved? true
    forage
    set steps-memory lput (list xcor ycor food-here? clock) steps-memory
    set played-steps lput (list xcor ycor) played-steps
    set turning-memory lput (100 * turning (last-items played-steps turn-steps) turn-steps) turning-memory

    hubnet-send user-id "Located at:" ("(" + pxcor + "," + pycor + ")")
    hubnet-send user-id "Food here?" (ifelse-value food-here? ["Yes"]["No"])
    hubnet-send user-id "Food gathered" food-stored
    hubnet-send user-id "Steps" steps
  ]
end

to execute-change-turtle
  ask students with [user-id = hubnet-message-source]
  [
    set used-shape-colors remove my-code used-shape-colors
    show-turtle
    set-unique-shape-and-color
    hubnet-send user-id "You are a:" (color-string color) + " " + base-shape
  ]
end









;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;               SAVING DATA
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to save-prompt
  locals [option new-file]
  ifelse is-string? save-file
  [ set option user-choice ("The current save file is: \n\n"
      + save-file + "\n\n"
      + "Is this OK?") ["OK" "NO"]
  ]
  [ set option "NO"
  ]
  if option = "OK"
  [ if save-file = ""
    [ set option "NO"
    ]
  ]
  if option = "NO"
  [ set new-file user-choose-new-file
    ifelse is-string? new-file
    [ set save-file new-file
    ]
    [ set option "CANCEL"
    ]
  ]
  if option = "CANCEL"
  [ user-message "Change save file cancelled"
    set save? false
  ]
end

to save-data
  ifelse is-string? save-file
  [ if file-exists? save-file
    [ file-delete save-file
    ]
    file-open save-file
    file-write data-list
    file-close
  ]
  [ save-prompt
  ]
end










;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;               LOADING DATA
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to load-data-prompt
  locals [new-file]
  set new-file user-choose-file
  if is-string? new-file
  [ load-data new-file
    replay-initialize
  ]
end

to load-data [from-where?]
  ifelse file-exists? from-where?
  [ file-open from-where?
    set data-list file-read
  ]
  [ user-message "That file doesn't exist.\n\nLoad cancelled."
  ]
  file-close

  set data-which? 1   ;;needs to be one, because every ODD item of data-list has patch data
  set re-run-counter max map [item 1 ?] filter [first ? = "run"] data-list
  set new-food-counter max map [item 3 ?] filter [first ? = "run"] data-list

  replay-get-data
  replay-initialize
  update-graphics
end






;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;               REPLAYING DATA
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to replay-restart
  replay-initialize
end

to replay-initialize
  set clock-replay 0
  set replaying? true
  wait .5
  ask patches
  [ set eaten 0
    set track 0
    set food 0
    if member? (list pxcor pycor) map [remove-item 2 ?] patches-with-food
    [ set food item 2 item (position (list pxcor pycor) map [remove-item 2 ?] patches-with-food) patches-with-food
    ]
  ]
  if food-for-individuals
  [ ask turtles
    [ set food-locations map [list item 0 ? item 1 ?] patches-with-food
      set food-values map [ item 2 ? ] patches-with-food
    ]
  ]
  ask turtles
  [ set steps 0
    set food-stored 0
    setxy (item 0 item 0 steps-memory) (item 1 item 0 steps-memory)
    set played-steps (list (list xcor ycor))
    set turning-memory [100]
    forage
  ]
  set clock max values-from turtles [item 3 last steps-memory]

  memory-visuals
  setup-plot
end

to replay
  if going?
  [ set going? false
  ]
  if not replaying?
  [ replay-initialize
  ]

;  every 0.1
;  [
    set clock-replay precision (clock-replay + .1) 1
    memory-visuals

    ask turtles
    [ memory-step
      forage
    ]

    ask students
    [ hubnet-send user-id "Located at:" ("(" + pxcor + "," + pycor + ")")
      hubnet-send user-id "Food here?" (ifelse-value food-here? ["Yes"]["No"])
      hubnet-send user-id "Food gathered" food-stored
      hubnet-send user-id "Steps" steps
    ]

    if count turtles > 0
    [ ifelse best?
      [ ask max-one-of turtles [food-stored]
        [ set track-of patch-here 100]
        ask patches
        [ set track track - 2]
      ]
      [ ask patches with [track > 0]
        [ set track 0]
      ]

      update-graphics
      do-plots
    ]
;  ]

 if clock-replay = clock
  [ set replaying? false
    stop
  ]

end

to memory-visuals
  locals [recall]
  set recall filter [item 0 ? = clock-replay ] item 1 item (data-which? + 1) data-list
  if length recall > 0
  [ set recall item 0 recall
    set replay-landscape? item 1 recall
    set replay-turtles? item 2 recall
    set replay-best? item 3 recall
  ]
end

;;TURTLES Procedure
to memory-step
  locals [recall]
  set recall filter [item 3 ? = clock-replay] steps-memory
  if length recall > 0
  [ set recall item 0 recall
    setxy (item 0 recall) (item 1 recall)
    set played-steps lput (list xcor ycor) played-steps
    set turning-memory lput (100 * turning (last-items played-steps turn-steps) turn-steps) turning-memory
    set steps steps + 1
  ]
end

to replay-skip-forward
  ifelse not (data-which? + 2 >= length data-list)
  [ set data-which? data-which? + 2
    replay-get-data
    replay-initialize
    update-graphics
  ]
  [ user-message "last run"
  ]
end

to replay-skip-back
  ifelse not (data-which? - 2 <= 0)
  [ set data-which? data-which? - 2
    replay-get-data
    replay-initialize
    update-graphics
  ]
  [ user-message "first run"
  ]
end

to replay-get-data
  locals [temp index turtle-data]
  set run-which? item 1 item data-which? data-list
  set food-which? item 3 item data-which? data-list
  set food-for-individuals item 4 item data-which? data-list
  set patches-with-food item 5 item data-which? data-list
  set index 0
  set turtle-data sentence (item 2 item (data-which? + 1) data-list) (item 3 item (data-which? + 1) data-list)
  repeat length turtle-data
  [ set temp item index turtle-data
    if not any? turtles with [user-id = item 0 temp]
    [ create-custom-androids 1
      [ set user-id item 0 temp
        set hidden? not turtles?
      ]
    ]
    ask turtles with [user-id = item 0 temp]
    [ set base-shape item 1 temp
      set shape base-shape
      set color item 2 temp
      set steps-memory item 3 temp
      show user-id
      show steps-memory
    ]
    set index index + 1
  ]
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;           UTILITY PROCEDURES
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;turtles jump without wrapping
to jump-nowrap [how-far?]
  locals [new-xcor new-ycor]
  set new-xcor how-far? * dx + xcor
  set new-ycor how-far? * dy + ycor
  ; check: hitting left or right wall?
  while [((abs new-xcor) > screen-edge-x) or ((abs new-ycor) > screen-edge-y)]
  [ if ((abs new-xcor) > screen-edge-x)
    [ ifelse how-far? > 0
      [ set how-far? abs ((screen-edge-x - abs xcor) / sin heading)
      ]
      [ set how-far? -1 * abs ((screen-edge-x - abs xcor) / sin heading)
      ]
      set new-ycor how-far? * dy + ycor
    ]
    if ((abs new-ycor) > screen-edge-y)
    [ ifelse how-far? > 0
      [ set how-far? abs ((screen-edge-y - abs ycor) / cos heading)
      ]
      [ set how-far? -1 * abs ((screen-edge-y - abs ycor) / cos heading)
      ]
    ]
    set new-xcor how-far? * dx + xcor
    set new-ycor how-far? * dy + ycor
  ]
  jump how-far?
end

to-report last-items [some-list num-items]
  ifelse length some-list <= num-items
  [ report some-list ]
  [ report last-items but-first some-list num-items ]
end


; *** NetLogo Model Copyright Notice ***
;
; This activity and associated models and materials was created as part of the projects:
; PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN CLASSROOMS and
; INTEGRATED SIMULATION AND MODELING ENVIRONMENT.
; These projects gratefully acknowledge the support of the
; National Science Foundation (REPP & ROLE programs) -- grant numbers
; REC #9814682 and REC-0126227.
;
; Copyright 2002 by Uri Wilensky & Walter Stroup. Updated 2002. All rights reserved.
;
; Permission to use, modify or redistribute this model is hereby granted,
; provided that both of the following requirements are followed:
; a) this copyright notice is included.
; b) this model will not be redistributed for profit without permission
;    from the copyright holders.
; Contact the copyright holders for appropriate licenses for redistribution
; for profit.
;
; To refer to this model in academic publications, please use:
; Wilensky, U. & Stroup, W. (2002).  NetLogo HubNet Disease model.
; http://ccl.northwestern.edu/netlogo/models/HubNetDisease.
; Center for Connected Learning and Computer-Based Modeling,
; Northwestern University, Evanston, IL.
;
; *** End of NetLogo Model Copyright Notice ***
@#$#@#$#@
GRAPHICS-WINDOW
125
70
482
448
15
15
11.2
1
10
1
1
1
0

CC-WINDOW
5
463
2358
558
Command Center

BUTTON
5
415
121
448
Setup
setup-prompt
NIL
1
T
OBSERVER
T
NIL

BUTTON
3
44
118
77
Go
go-flags
T
1
T
OBSERVER
T
NIL

BUTTON
1003
338
1132
371
Create Androids
create-androids
NIL
1
T
OBSERVER
T
NIL

PLOT
487
60
786
235
Food Collected
time
food
0.0
100.0
0.0
10.0
true
false
PENS
"Total" 1.0 0 -16777216 true
"Average" 1.0 0 -16776961 true
"Most" 1.0 0 -65536 true
"Least" 1.0 0 -13074171 true

SLIDER
1003
406
1132
439
android-delay
android-delay
0.0
10.0
0.0
0.1
1
NIL

SLIDER
1003
372
1132
405
number
number
1
200
100
1
1
NIL

MONITOR
1768
382
1826
431
turtles
count turtles
0
1

SLIDER
4
356
119
389
patch-number
patch-number
1
50
10
1
1
NIL

SLIDER
4
320
119
353
patch-size
patch-size
1
4
3
1
1
NIL

SWITCH
131
36
246
69
landscape?
landscape?
0
1
-1000

SWITCH
247
36
362
69
turtles?
turtles?
0
1
-1000

BUTTON
1439
63
1571
178
NIL
__hubnet-client
NIL
1
T
OBSERVER
T
NIL

BUTTON
3
173
119
206
Restore
re-run
NIL
1
T
OBSERVER
T
NIL

PLOT
488
289
787
449
Data Histogram
Data
# of turtles
0.0
30.0
0.0
5.0
true
false
PENS
"food" 1.0 1 -16777216 true
"Turning" 1.0 1 -16777216 true

SWITCH
363
36
478
69
best?
best?
1
1
-1000

TEXTBOX
286
11
376
29
SHOW...

TEXTBOX
2259
238
2349
266
screen 3 placeholder

SWITCH
4
244
120
277
own-food
own-food
0
1
-1000

BUTTON
928
10
1004
59
CHANGE ->
save-prompt
NIL
1
T
OBSERVER
T
NIL

MONITOR
1006
10
1576
59
autosave file
save-file
3
1

BUTTON
790
116
921
149
REPLAY
replay
T
1
T
OBSERVER
T
NIL

BUTTON
790
82
921
115
REPLAY one tick
replay
NIL
1
T
OBSERVER
T
NIL

SWITCH
928
62
1044
95
save?
save?
1
1
-1000

BUTTON
3
208
119
241
New Food
new-food
NIL
1
T
OBSERVER
T
NIL

BUTTON
3
10
118
43
LOGIN
login
T
1
T
OBSERVER
T
NIL

BUTTON
790
150
921
183
RE-START REPLAY
replay-restart
NIL
1
T
OBSERVER
T
NIL

BUTTON
791
334
921
367
LOAD DATA
load-data-prompt
NIL
1
T
OBSERVER
T
NIL

SLIDER
488
255
617
288
turn-steps
turn-steps
3
20
5
1
1
NIL

CHOOSER
625
14
786
59
plot-setting
plot-setting
"Food - Total" "Food - Stats"
1

CHOOSER
649
243
787
288
histogram-setting
histogram-setting
"Food" "Turning"
1

CHOOSER
4
104
118
149
Special-Start?
Special-Start?
"None" "Central Food"
0

BUTTON
1667
154
1764
187
check data
foreach data-list [print ?]
NIL
1
T
OBSERVER
T
NIL

BUTTON
790
187
853
220
<<
replay-skip-back
NIL
1
T
OBSERVER
T
NIL

BUTTON
858
187
921
220
>>
replay-skip-forward
NIL
1
T
OBSERVER
T
NIL

MONITOR
791
224
853
273
Run
run-which?
3
1

MONITOR
859
224
921
273
Food
food-which?
3
1

MONITOR
791
276
920
325
Own Food?
food-for-individuals
3
1

@#$#@#$#@
Have a mode in which each patch has a bit of food for each turtle.  That way they can be foraging in parallel.
Plants regrow.  Toggle.
Movement cost.  Toggle.
Speed constraint.  Toggle.
save-world every second

save-data (build file, tack on each second's data to the end of the file)

Fix plots (switch on / off in middle of run.)

Fix restart

Histogram - auto adjust x-range y-range for values outside


p2p -
have see / no see mode.  Teacher can toggle individuals.






CREDITS AND REFERENCES
----------------------
This activity and associated models and materials was created as part of the projects:
PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN CLASSROOMS and INTEGRATED SIMULATION AND MODELING ENVIRONMENT. These projects gratefully acknowledge the support of the National Science Foundation (REPP & ROLE programs) -- grant numbers REC #9814682 and REC-0126227.

Copyright 2002 by Uri Wilensky & Walter Stroup. All rights reserved.

Permission to use, modify or redistribute this model is hereby granted, provided that both of the following requirements are followed:
a) this copyright notice is included.
b) this model will not be redistributed for profit without permission from the copyright holders.
Contact the copyright holders for appropriate licenses for redistribution for profit.

To refer to this model in academic publications, please use: Wilensky, U. & Stroup, W. (2002). NetLogo HubNet Disease model. http://ccl.northwestern.edu/netlogo/models/HubNetDisease. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.
@#$#@#$#@
default
false
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

android
false
0
Rectangle -7566196 true true 105 74 210 239
Polygon -7566196 true true 104 78 34 129 47 148 114 89
Polygon -7566196 true true 198 81 274 108 258 142 192 104
Polygon -7566196 true true 115 239 115 289 133 289 133 237
Polygon -7566196 true true 176 235 176 287 192 287 192 234
Rectangle -7566196 true true 119 12 194 73
Rectangle -16777216 true false 129 22 147 36
Rectangle -16777216 true false 164 23 184 37
Rectangle -16777216 true false 151 113 163 125
Rectangle -16777216 true false 153 142 164 154
Rectangle -16777216 true false 154 171 166 184

bear
false
0
Rectangle -7566196 true true 106 35 181 92
Circle -7566196 true true 110 17 18
Circle -7566196 true true 128 17 19
Rectangle -7566196 true true 80 58 111 89
Rectangle -7566196 true true 98 95 101 95
Rectangle -7566196 true true 92 93 192 104
Rectangle -7566196 true true 83 101 199 114
Rectangle -7566196 true true 78 107 205 130
Rectangle -7566196 true true 74 122 209 240
Rectangle -7566196 true true 77 236 204 249
Rectangle -7566196 true true 106 89 180 104
Rectangle -7566196 true true 80 247 198 258
Rectangle -7566196 true true 85 255 108 281
Rectangle -7566196 true true 169 252 195 283
Rectangle -7566196 true true 158 276 171 283
Rectangle -7566196 true true 74 276 90 281
Circle -7566196 true true 188 201 35
Circle -16777216 true false 111 40 13
Rectangle -7566196 true true 51 163 87 184
Rectangle -7566196 true true 45 166 53 169
Rectangle -7566196 true true 42 172 52 173
Rectangle -7566196 true true 38 178 53 183
Circle -7566196 true true 72 62 20

big boat
false
0
Polygon -6524078 true false 1 196 43 296 193 296 297 194
Rectangle -1 true false 135 14 149 194
Polygon -7566196 true true 151 14 173 18 193 30 211 48 239 88 251 118 271 170 271 184 253 176 227 170 199 172 177 180 161 190 165 160 169 122 165 78
Polygon -7566196 true true 133 36 115 50 77 86 47 122 7 152 33 156 57 164 77 178 91 188
Rectangle -7566196 true true 30 206 234 220
Rectangle -7566196 true true 52 224 234 236
Rectangle -7566196 true true 78 240 234 250

butterfly
false
0
Polygon -16777216 true false 151 76 138 91 138 284 150 296 162 286 162 91
Polygon -7566196 true true 164 106 184 79 205 61 236 48 259 53 279 86 287 119 289 158 278 177 256 182 164 181
Polygon -7566196 true true 136 110 119 82 110 71 85 61 59 48 36 56 17 88 6 115 2 147 15 178 134 178
Polygon -7566196 true true 46 181 28 227 50 255 77 273 112 283 135 274 135 180
Polygon -7566196 true true 165 185 254 184 272 224 255 251 236 267 191 283 164 276
Line -7566196 true 167 47 159 82
Line -7566196 true 136 47 145 81
Circle -7566196 true true 165 45 8
Circle -7566196 true true 134 45 6
Circle -7566196 true true 133 44 7
Circle -7566196 true true 133 43 8

car
false
15
Circle -1 false true 185 55 60
Circle -1 false true 183 186 61
Polygon -1 true true 214 52 214 22 182 26 162 38 144 74 138 102 100 120 99 161 102 201 118 246 152 267 190 275 210 251 187 240 178 200 204 182 215 181 214 118 193 112 182 98 181 72 198 52

circle
false
0
Circle -7566196 true true 0 0 300

horse
false
0
Polygon -7566196 true true 226 121 90 121 60 136 61 181 106 195 210 195 255 181 255 135
Rectangle -7566196 true true 61 180 75 268
Rectangle -7566196 true true 89 187 104 275
Rectangle -7566196 true true 210 186 225 269
Rectangle -7566196 true true 241 178 254 275
Polygon -7566196 true true 62 138 60 107 23 107 17 102 18 85 24 82 54 79 66 63 87 64 94 128
Circle -16777216 true false 63 72 12
Polygon -7566196 true true 226 120 278 138 284 185 265 188 260 142
Polygon -7566196 true true 65 65 70 50
Polygon -7566196 true true 65 67 74 46 79 65 93 49 88 73 65 67

lobster
false
0
Polygon -7566196 true true 105 106 122 238 100 259 100 276 118 275 150 240 180 275 197 275 197 258 174 238 196 105 178 77 123 77 105 106
Polygon -7566196 true true 112 103 84 78 105 60 94 14 85 57 78 19 67 59 76 83 110 118
Polygon -7566196 true true 192 120 228 85 241 57 231 22 223 59 217 17 205 61 216 79 192 108
Rectangle -7566196 true true 71 125 117 133
Rectangle -7566196 true true 73 149 119 157
Rectangle -7566196 true true 78 178 123 187
Rectangle -7566196 true true 183 131 219 138
Rectangle -7566196 true true 180 152 216 160
Rectangle -7566196 true true 173 176 217 184
Rectangle -7566196 true true 127 56 136 82
Rectangle -7566196 true true 160 55 169 81

monster
false
0
Rectangle -7566196 true true 77 100 213 245
Rectangle -7566196 true true 189 243 213 273
Rectangle -7566196 true true 78 242 102 271
Rectangle -7566196 true true 59 119 83 239
Rectangle -7566196 true true 203 118 225 239
Rectangle -7566196 true true 225 123 264 158
Rectangle -7566196 true true 262 124 272 131
Rectangle -7566196 true true 263 133 273 140
Rectangle -7566196 true true 263 145 271 156
Rectangle -7566196 true true 19 122 61 156
Rectangle -7566196 true true 9 125 19 130
Rectangle -7566196 true true 11 135 20 140
Rectangle -7566196 true true 9 146 20 151
Rectangle -7566196 true true 89 79 198 101
Rectangle -7566196 true true 112 35 176 82
Rectangle -16777216 true false 122 41 136 53
Rectangle -16777216 true false 149 39 167 53
Circle -1 true false 82 118 117
Polygon -16777216 true false 122 62 132 77 157 77 168 62
Polygon -1 true false 140 63 135 72 127 62
Polygon -1 true false 145 61 151 70 159 62
Polygon -7566196 true true 123 17 115 34 131 34
Polygon -7566196 true true 165 15 149 33 172 34

moose
false
0
Polygon -7566196 true true 226 121 90 121 60 136 61 181 106 195 210 195 255 181 255 135
Rectangle -7566196 true true 61 180 75 268
Rectangle -7566196 true true 89 187 104 275
Rectangle -7566196 true true 210 186 225 269
Rectangle -7566196 true true 241 178 254 275
Polygon -7566196 true true 62 138 60 107 23 107 17 102 18 85 24 82 54 79 66 63 87 64 94 128
Circle -16777216 true false 63 72 12
Polygon -7566196 true true 226 120 278 138 284 185 265 188 260 142
Polygon -7566196 true true 65 65 70 50
Polygon -7566196 true true 68 64 60 49 17 49 7 41 6 12 22 40 38 40 35 14 49 39 66 39 64 16 78 66 68 64
Polygon -7566196 true true 76 64 97 17 95 38 111 38 122 16 121 38 136 38 152 11 151 38 144 47 97 47 86 66

nu
false
0
Rectangle -7566196 true true 16 31 60 285
Rectangle -7566196 true true 120 31 164 285
Rectangle -7566196 true true 182 31 226 285
Rectangle -7566196 true true 256 31 298 285
Rectangle -7566196 true true 214 241 274 285
Polygon -7566196 true true 60 31 118 209 120 281 60 105
Rectangle -7566196 true true 110 211 140 249

pickup truck
false
0
Polygon -7566196 true true 285 208 285 178 279 164 261 144 229 132 217 132 213 106 199 84 171 68 149 68 129 68 129 148 1 148 1 156 19 164 19 222 285 222 283 174 283 176
Circle -16777216 true false 40 185 71
Circle -16777216 true false 192 191 66
Circle -7566196 true true 195 194 59
Circle -7566196 true true 43 188 64
Polygon -16777216 true false 197 94 149 94 157 128 209 128 205 112 203 102 197 94
Polygon -7566196 true true 21 142 139 142 139 136 13 136

sheep
false
14
Rectangle -1 true false 90 75 270 225
Circle -1 true false 15 75 150
Rectangle -16777216 true true 81 225 134 286
Rectangle -16777216 true true 180 225 238 285
Circle -16777216 true true 1 88 92

sick android
false
0
Rectangle -7566196 true true 105 74 210 239
Polygon -7566196 true true 104 78 34 129 47 148 114 89
Polygon -7566196 true true 198 81 274 108 258 142 192 104
Polygon -7566196 true true 115 239 115 289 133 289 133 237
Polygon -7566196 true true 176 235 176 287 192 287 192 234
Rectangle -7566196 true true 119 12 194 73
Rectangle -16777216 true false 129 22 147 36
Rectangle -16777216 true false 164 23 184 37
Rectangle -16777216 true false 151 113 163 125
Rectangle -16777216 true false 153 142 164 154
Rectangle -16777216 true false 154 171 166 184
Circle -65536 true false 4 125 112

sick bear
false
0
Rectangle -7566196 true true 106 35 181 92
Circle -7566196 true true 110 17 18
Circle -7566196 true true 128 17 19
Rectangle -7566196 true true 80 58 111 89
Rectangle -7566196 true true 98 95 101 95
Rectangle -7566196 true true 92 93 192 104
Rectangle -7566196 true true 83 101 199 114
Rectangle -7566196 true true 78 107 205 130
Rectangle -7566196 true true 74 122 209 240
Rectangle -7566196 true true 77 236 204 249
Rectangle -7566196 true true 106 89 180 104
Rectangle -7566196 true true 80 247 198 258
Rectangle -7566196 true true 85 255 108 281
Rectangle -7566196 true true 169 252 195 283
Rectangle -7566196 true true 158 276 171 283
Rectangle -7566196 true true 74 276 90 281
Circle -7566196 true true 188 201 35
Circle -16777216 true false 111 40 13
Rectangle -7566196 true true 51 163 87 184
Rectangle -7566196 true true 45 166 53 169
Rectangle -7566196 true true 42 172 52 173
Rectangle -7566196 true true 38 178 53 183
Circle -7566196 true true 72 62 20
Circle -65536 true false 57 88 136

sick big boat
false
0
Polygon -6524078 true false 1 196 43 296 193 296 297 194
Rectangle -1 true false 135 14 149 194
Polygon -7566196 true true 151 14 173 18 193 30 211 48 239 88 251 118 271 170 271 184 253 176 227 170 199 172 177 180 161 190 165 160 169 122 165 78
Polygon -7566196 true true 133 36 115 50 77 86 47 122 7 152 33 156 57 164 77 178 91 188
Rectangle -7566196 true true 30 206 234 220
Rectangle -7566196 true true 52 224 234 236
Rectangle -7566196 true true 78 240 234 250
Circle -65536 true false 1 134 123

sick butterfly
false
0
Polygon -16777216 true false 151 76 138 91 138 284 150 296 162 286 162 91
Polygon -7566196 true true 164 106 184 79 205 61 236 48 259 53 279 86 287 119 289 158 278 177 256 182 164 181
Polygon -7566196 true true 136 110 119 82 110 71 85 61 59 48 36 56 17 88 6 115 2 147 15 178 134 178
Polygon -7566196 true true 46 181 28 227 50 255 77 273 112 283 135 274 135 180
Polygon -7566196 true true 165 185 254 184 272 224 255 251 236 267 191 283 164 276
Line -7566196 true 167 47 159 82
Line -7566196 true 136 47 145 81
Circle -7566196 true true 165 45 8
Circle -7566196 true true 134 45 6
Circle -7566196 true true 133 44 7
Circle -7566196 true true 133 43 8
Circle -65536 true false 167 99 128

sick car
false
15
Circle -1 false true 185 55 60
Circle -1 false true 183 186 61
Polygon -1 true true 214 52 214 22 182 26 162 38 144 74 138 102 100 120 99 161 102 201 118 246 152 267 190 275 210 251 187 240 178 200 204 182 215 181 214 118 193 112 182 98 181 72 198 52
Circle -65536 true false 19 167 82

sick circle
false
0
Circle -7566196 true true 35 35 230
Circle -65536 true false 101 104 98

sick lobster
false
0
Polygon -7566196 true true 105 106 122 238 100 259 100 276 118 275 150 240 180 275 197 275 197 258 174 238 196 105 178 77 123 77 105 106
Polygon -7566196 true true 112 103 84 78 105 60 94 14 85 57 78 19 67 59 76 83 110 118
Polygon -7566196 true true 192 120 228 85 241 57 231 22 223 59 217 17 205 61 216 79 192 108
Rectangle -7566196 true true 71 125 117 133
Rectangle -7566196 true true 73 149 119 157
Rectangle -7566196 true true 78 178 123 187
Rectangle -7566196 true true 183 131 219 138
Rectangle -7566196 true true 180 152 216 160
Rectangle -7566196 true true 173 176 217 184
Rectangle -7566196 true true 127 56 136 82
Rectangle -7566196 true true 160 55 169 81
Circle -65536 true false 90 95 118

sick monster
false
0
Rectangle -7566196 true true 77 100 213 245
Rectangle -7566196 true true 189 243 213 273
Rectangle -7566196 true true 78 242 102 271
Rectangle -7566196 true true 59 119 83 239
Rectangle -7566196 true true 203 118 225 239
Rectangle -7566196 true true 225 123 264 158
Rectangle -7566196 true true 262 124 272 131
Rectangle -7566196 true true 263 133 273 140
Rectangle -7566196 true true 263 145 271 156
Rectangle -7566196 true true 19 122 61 156
Rectangle -7566196 true true 9 125 19 130
Rectangle -7566196 true true 11 135 20 140
Rectangle -7566196 true true 9 146 20 151
Rectangle -7566196 true true 89 79 198 101
Rectangle -7566196 true true 112 35 176 82
Rectangle -16777216 true false 122 41 136 53
Rectangle -16777216 true false 149 39 167 53
Circle -1 true false 82 118 117
Polygon -16777216 true false 122 62 132 77 157 77 168 62
Polygon -1 true false 140 63 135 72 127 62
Polygon -1 true false 145 61 151 70 159 62
Polygon -7566196 true true 123 17 115 34 131 34
Polygon -7566196 true true 165 15 149 33 172 34
Circle -65536 true false 77 102 140

sick moose
false
0
Polygon -7566196 true true 226 121 90 121 60 136 61 181 106 195 210 195 255 181 255 135
Rectangle -7566196 true true 61 180 75 268
Rectangle -7566196 true true 89 187 104 275
Rectangle -7566196 true true 210 186 225 269
Rectangle -7566196 true true 241 178 254 275
Polygon -7566196 true true 62 138 60 107 23 107 17 102 18 85 24 82 54 79 66 63 87 64 94 128
Circle -16777216 true false 63 72 12
Polygon -7566196 true true 226 120 278 138 284 185 265 188 260 142
Polygon -7566196 true true 65 65 70 50
Polygon -7566196 true true 68 64 60 49 17 49 7 41 6 12 22 40 38 40 35 14 49 39 66 39 64 16 78 66 68 64
Polygon -7566196 true true 76 64 97 17 95 38 111 38 122 16 121 38 136 38 152 11 151 38 144 47 97 47 86 66
Circle -65536 true false 79 87 115

sick nu
false
0
Rectangle -7566196 true true 16 31 60 285
Rectangle -7566196 true true 120 31 164 285
Rectangle -7566196 true true 182 31 226 285
Rectangle -7566196 true true 256 31 298 285
Rectangle -7566196 true true 214 241 274 285
Polygon -7566196 true true 60 31 118 209 120 281 60 105
Rectangle -7566196 true true 110 211 140 249
Circle -65536 true false 110 147 121

sick pickup truck
false
0
Polygon -7566196 true true 285 208 285 178 279 164 261 144 229 132 217 132 213 106 199 84 171 68 149 68 129 68 129 148 1 148 1 156 19 164 19 222 285 222 283 174 283 176
Circle -16777216 true false 40 185 71
Circle -16777216 true false 192 191 66
Circle -7566196 true true 195 194 59
Circle -7566196 true true 43 188 64
Polygon -16777216 true false 197 94 149 94 157 128 209 128 205 112 203 102 197 94
Polygon -7566196 true true 21 142 139 142 139 136 13 136
Circle -65536 true false 22 111 66

sick sheep
false
14
Rectangle -1 true false 90 75 270 225
Circle -1 true false 15 75 150
Rectangle -16777216 true true 81 225 134 286
Rectangle -16777216 true true 180 225 238 285
Circle -16777216 true true 1 88 92
Circle -65536 true false 112 46 144

sick square
false
0
Rectangle -7566196 true true 45 45 255 255
Circle -65536 true false 100 97 102

sick teddy bear
false
0
Circle -7566196 true true 110 21 81
Circle -7566196 true true 97 7 39
Circle -7566196 true true 171 5 39
Polygon -7566196 true true 133 88 95 117 95 225 119 247 188 248 215 224 215 116 170 91
Circle -7566196 true true 134 238 34
Polygon -7566196 true true 197 113 249 88 261 91 268 106 262 116 205 139 197 113
Polygon -7566196 true true 115 116 66 90 54 93 45 110 50 117 103 145 115 116
Polygon -7566196 true true 104 204 54 233 54 244 63 257 71 256 117 227
Polygon -7566196 true true 194 228 240 255 248 254 260 238 257 231 204 207 194 228
Circle -1 true false 124 41 20
Circle -1 true false 158 42 20
Line -16777216 false 128 80 151 69
Line -16777216 false 151 69 174 83
Polygon -65536 true false 151 208 111 173 132 153 151 169 171 154 189 169

sick thin wedge
false
0
Polygon -7566196 true true 133 20 70 252 127 148 177 245
Circle -65536 true false 165 140 87

sick uu
false
0
Rectangle -7566196 true true 58 44 104 226
Rectangle -7566196 true true 88 178 194 224
Rectangle -7566196 true true 180 44 222 224
Rectangle -7566196 true true 122 74 168 284
Rectangle -7566196 true true 124 240 250 286
Rectangle -7566196 true true 240 76 284 286
Circle -65536 true false 43 208 93

sick wide wedge
false
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250
Circle -65536 true false 202 65 90

sick wolf
false
0
Rectangle -7566196 true true 15 105 105 165
Rectangle -7566196 true true 45 90 105 105
Polygon -7566196 true true 60 90 83 44 104 90
Polygon -16777216 true false 67 90 82 59 97 89
Rectangle -1 true false 48 93 59 105
Rectangle -16777216 true false 51 96 55 101
Rectangle -16777216 true false 0 121 15 135
Rectangle -16777216 true false 15 136 60 151
Polygon -1 true false 15 136 23 149 31 136
Polygon -1 true false 30 151 37 136 43 151
Rectangle -7566196 true true 105 120 263 195
Rectangle -7566196 true true 108 195 259 201
Rectangle -7566196 true true 114 201 252 210
Rectangle -7566196 true true 120 210 243 214
Rectangle -7566196 true true 115 114 255 120
Rectangle -7566196 true true 128 108 248 114
Rectangle -7566196 true true 150 105 225 108
Rectangle -7566196 true true 132 214 155 270
Rectangle -7566196 true true 110 260 132 270
Rectangle -7566196 true true 210 214 232 270
Rectangle -7566196 true true 189 260 210 270
Line -7566196 true 263 127 281 155
Line -7566196 true 281 155 281 192
Circle -65536 true false 130 106 106

square
false
0
Rectangle -7566196 true true 48 27 253 222

teddy bear
false
0
Circle -7566196 true true 110 21 81
Circle -7566196 true true 97 7 39
Circle -7566196 true true 171 5 39
Polygon -7566196 true true 133 88 95 117 95 225 119 247 188 248 215 224 215 116 170 91
Circle -7566196 true true 134 238 34
Polygon -7566196 true true 197 113 249 88 261 91 268 106 262 116 205 139 197 113
Polygon -7566196 true true 115 116 66 90 54 93 45 110 50 117 103 145 115 116
Polygon -7566196 true true 104 204 54 233 54 244 63 257 71 256 117 227
Polygon -7566196 true true 194 228 240 255 248 254 260 238 257 231 204 207 194 228
Circle -1 true false 124 41 20
Circle -1 true false 158 42 20
Line -16777216 false 127 75 150 85
Line -16777216 false 151 85 177 72
Polygon -1 true false 152 204 115 167 131 150 150 168 168 152 184 167

thin wedge
false
0
Polygon -7566196 true true 133 20 70 252 127 148 177 245

uu
false
0
Rectangle -7566196 true true 58 44 104 226
Rectangle -7566196 true true 88 178 194 224
Rectangle -7566196 true true 180 44 222 224
Rectangle -7566196 true true 122 74 168 284
Rectangle -7566196 true true 124 240 250 286
Rectangle -7566196 true true 240 76 284 286

wide wedge
false
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

wolf
false
0
Rectangle -7566196 true true 15 105 105 165
Rectangle -7566196 true true 45 90 105 105
Polygon -7566196 true true 60 90 83 44 104 90
Polygon -16777216 true false 67 90 82 59 97 89
Rectangle -1 true false 48 93 59 105
Rectangle -16777216 true false 51 96 55 101
Rectangle -16777216 true false 0 121 15 135
Rectangle -16777216 true false 15 136 60 151
Polygon -1 true false 15 136 23 149 31 136
Polygon -1 true false 30 151 37 136 43 151
Rectangle -7566196 true true 105 120 263 195
Rectangle -7566196 true true 108 195 259 201
Rectangle -7566196 true true 114 201 252 210
Rectangle -7566196 true true 120 210 243 214
Rectangle -7566196 true true 115 114 255 120
Rectangle -7566196 true true 128 108 248 114
Rectangle -7566196 true true 150 105 225 108
Rectangle -7566196 true true 132 214 155 270
Rectangle -7566196 true true 110 260 132 270
Rectangle -7566196 true true 210 214 232 270
Rectangle -7566196 true true 189 260 210 270
Line -7566196 true 263 127 281 155
Line -7566196 true 281 155 281 192

@#$#@#$#@
NetLogo 2.1beta4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
