; SHORT TERM MEMORY VOTER BEHAVIOR SIMULATION
; written by Michael Kuyumcu (m.kuyumcu@noemanetz.de)
; Idea developed by Howard Garner in one of his columns in Scientific American
; April 2004 - Version 1.0

patches-own [Opinion]
globals [colors   days   minimum    maximum    voters]



to go
  ; This command checks if there are still more than one parties. If not, the simulation stops
  ; If so, the neighbors on the patches exchange opinions which are graphically displayed.

  set minimum min values-from patches [opinion]
  set maximum max values-from patches [opinion]
  if minimum = maximum [user-message "Now democracy has removed itself from power."  stop]

  exchange-opinions
  plot-opinions

  set days days + 1
end



to plot-opinions
  ; Here we display the percentages of the people voting for a particular party
  ; in different colors
  locals [percentage   votes]

  foreach n-values parties [?]
          [set-current-plot-pen "Party " + (? + 1)
           set-plot-pen-color item ? colors
           set votes count patches with [opinion = ?]
           set percentage (100 * votes) / voters
           plot percentage
          ]


end



to exchange-opinions
  ; This command lets the voters on the patches go and talk to their neighbors
  ; and adopt their political opinion - on a daily basis, without remembering
  ; their own opinion.
  locals [neighborset]

  ask patches
    [set opinion opinion-of random-one-of neighbors4
     set pcolor item opinion colors]

end



to setup
  locals [distribution   total    accumulated    chance  ]

  clear-all
  set colors [0 18 25 36 45 53 68 77 82 93 108 117 124 135]                   ; color codes for 14 parties
  set days 0                                                                  ; zero days have passed

  set voters screen-size-x * screen-size-y                                    ; the total number of voters


  ifelse initial-voters-distribution = "Equal market shares"                  ; if there is no initial voters' bias
     [ask patches [set opinion (random parties)                               ; each party has an equal followership
                   set pcolor item opinion colors]]                           ; the patch colors represent elected party

     [set distribution make-list user-input "Bracketless list of percentages:"  ; User enters percentages
      set total precision sum distribution 2                                  ; Add them up and round to two decimals
      if total != 100 [user-message "Percentages must add up to 100."  stop]  ; not really 100 percent correct
      if length distribution != parties [user-message "Please enter " + parties + " values, one for each party."  stop]


     ; Now we have a valid distribution of party market shares (voter percentages) and can create random
     ; political opinions for each patch. An individual patch represents an individual voter, and its color reflects
     ; the respective voter's political opinion.

     set distribution sort distribution        ; we sort in order to make accumulated probabilities feasible
     set accumulated []                        ; in this list we accumulate party market shares for our distribution
     set total 0                               ; new sum for the accumulation or market shares
     foreach distribution [set total (total + ?)
                           set accumulated sentence accumulated total]

     ask patches [set chance random-float 100.0                   ; this value determines which party the patch votes for.
                  set opinion (which-party chance accumulated)    ; now the voter has got an own opinion
                  set pcolor item opinion colors]]                ; looks up the value and gives back the political opinion
end



to-report which-party [float  accuset]
  ; This reporter takes a floating point value in the range of 0-99.9999 and determines
  ; according to the accumulated party market shares which party will be elected by the
  ; patch that holds this particular value

  foreach n-values parties [?]
          [if float < item ? accuset [report ?]]

end



to-report make-list [var]
  ; Interpret user defined string as list
  ; If the string passed does not begin with or end in a [ and ],
  ; these characters are inserted

  locals [newlist]

  set newlist var
  if first newlist != "[" [set newlist "[" + newlist]
  if last newlist != "]" [set newlist newlist + "]"]

  set newlist read-from-string newlist
  report newlist
end
@#$#@#$#@
GRAPHICS-WINDOW
430
10
797
398
25
25
7.0
1
10
1
1
1

CC-WINDOW
430
405
798
556
Command Center

BUTTON
223
103
421
136
Start Simulation
go
T
1
T
OBSERVER
T

SLIDER
12
56
211
89
Parties
Parties
2
14
3
1
1
NIL

PLOT
13
261
403
555
Market-share
Days
Voters in %
0.0
365.0
0.0
100.0
true
true
PENS
"Party 1" 1.0 0 -16777216 true
"Party 2" 1.0 0 -16777216 true
"Party 3" 1.0 0 -16777216 true
"Party 4" 1.0 0 -16777216 true
"Party 5" 1.0 0 -16777216 true
"Party 6" 1.0 0 -16777216 true
"Party 7" 1.0 0 -16777216 true
"Party 8" 1.0 0 -16777216 true
"Party 9" 1.0 0 -16777216 true
"Party 10" 1.0 0 -16777216 true
"Party 11" 1.0 0 -16777216 true
"Party 12" 1.0 0 -16777216 true
"Party 13" 1.0 0 -16777216 true
"Party 14" 1.0 0 -16777216 true

CHOICE
13
103
210
148
Initial-voters-Distribution
Initial-voters-Distribution
"Equal market shares" "Custom Market Shares..."
1

TEXTBOX
16
11
297
53
Short term memory and voter behavior simulation\n(Idea by Howard Gardner)

MONITOR
12
199
210
248
NIL
Days
0
1

BUTTON
222
56
421
89
NIL
Setup
NIL
1
T
OBSERVER
T

@#$#@#$#@
WHAT IS IT?
-----------
Have you ever been so disappointed by a politician of your favorite party that you switched your political opinion and elected another partie's candidate? Have you ever talked with a friend or a neighbor and after the talk adopted her or his general political opinion - or so much of it that you voted differently? Just for how long do you remember political facts? One day? One month? One year? Even longer? Congratulations to your long-term memory!

Anyhow, the average German voter remembers important political facts and governmental decisions for about 3 months. If she or he is politically interested, make it six months. Hardly ever any longer. Let's think this idea a little bit further. What would happen if a voter changed her or his opinion almost instantly - say, from day to day. Imagine, each and every voter goes for a talk to one of her or his 4 neighbors and after the talk adopts their political opinion - every day. Could you predict the outcome of such a mass behavior? What could be an emergent system behavior of such a short-term-memory population?

This idea, together with a sketch of how to program it, was first presented by Martin Gardner in one of the issues Scientific American. I just have forgotten when that was... But you see, this exactly is the issue.


HOW TO USE IT
-------------
Use the party slider to determine how many political parties there should be. It's not telling you how many guests to invite to your next celebration.

The choice selector beneath lets you pick one of two alternatives for the initial voters distribution, either each party has equal market shares, or you define a space-delimited list of percentages (integer or real numbers) for each party, for instance, you select four parties and enter their percentages (market shares) as "10 20 50 20". That would mean that party 1 is voted for by 10 % of the population, party 2 by 20 %, and so on.

After these choices click on the "Setup" button. The colors on the patches now represent political opinions. There are as many colors as there are political opinions. Then click on "Start Simulation". The voters living on the patches will begin adopting the political opinion of one of their four direct neighbors. The result of such an daily exchange is then displayed as a series of new patch images.

THINGS TO NOTICE
----------------
Give the model a little time, especially if you have a large number of patches and parties. Over time, notice what happens to the initial random distribution of opinions. And please bear with me - this is my first NetLogo model.

EXTENDING THE MODEL
-------------------
Ideas:
- Let the voters on the patches have an individual memory time. Some change opinions quickly, some need more or more frequent exposure to different ideas to change their mind. Sometimes, you just have to hammer home your point with one of your colleagues, haven't you?
- New parties could be set up by discontented individuals or groups of people. Introduce a control that tells the simulation how often to introduce new political parties into the system and how many people minimum and maximum will have that initial opinion. How many blocks of voters should the new opinion be split upon? Will they live side by side or spread across the whole patch area?
@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

ant
true
0
Polygon -7566196 true true 136 61 129 46 144 30 119 45 124 60 114 82 97 37 132 10 93 36 111 84 127 105 172 105 189 84 208 35 171 11 202 35 204 37 186 82 177 60 180 44 159 32 170 44 165 60
Polygon -7566196 true true 150 95 135 103 139 117 125 149 137 180 135 196 150 204 166 195 161 180 174 150 158 116 164 102
Polygon -7566196 true true 149 186 128 197 114 232 134 270 149 282 166 270 185 232 171 195 149 186 149 186
Polygon -7566196 true true 225 66 230 107 159 122 161 127 234 111 236 106
Polygon -7566196 true true 78 58 99 116 139 123 137 128 95 119
Polygon -7566196 true true 48 103 90 147 129 147 130 151 86 151
Polygon -7566196 true true 65 224 92 171 134 160 135 164 95 175
Polygon -7566196 true true 235 222 210 170 163 162 161 166 208 174
Polygon -7566196 true true 249 107 211 147 168 147 168 150 213 150

arrow
true
0
Polygon -7566196 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

bee
true
0
Polygon -256 true false 152 149 77 163 67 195 67 211 74 234 85 252 100 264 116 276 134 286 151 300 167 285 182 278 206 260 220 242 226 218 226 195 222 166
Polygon -16777216 true false 150 149 128 151 114 151 98 145 80 122 80 103 81 83 95 67 117 58 141 54 151 53 177 55 195 66 207 82 211 94 211 116 204 139 189 149 171 152
Polygon -7566196 true true 151 54 119 59 96 60 81 50 78 39 87 25 103 18 115 23 121 13 150 1 180 14 189 23 197 17 210 19 222 30 222 44 212 57 192 58
Polygon -16777216 true false 70 185 74 171 223 172 224 186
Polygon -16777216 true false 67 211 71 226 224 226 225 211 67 211
Polygon -16777216 true false 91 257 106 269 195 269 211 255
Line -1 false 144 100 70 87
Line -1 false 70 87 45 87
Line -1 false 45 86 26 97
Line -1 false 26 96 22 115
Line -1 false 22 115 25 130
Line -1 false 26 131 37 141
Line -1 false 37 141 55 144
Line -1 false 55 143 143 101
Line -1 false 141 100 227 138
Line -1 false 227 138 241 137
Line -1 false 241 137 249 129
Line -1 false 249 129 254 110
Line -1 false 253 108 248 97
Line -1 false 249 95 235 82
Line -1 false 235 82 144 100

bird1
false
0
Polygon -7566196 true true 2 6 2 39 270 298 297 298 299 271 187 160 279 75 276 22 100 67 31 0

bird2
false
0
Polygon -7566196 true true 2 4 33 4 298 270 298 298 272 298 155 184 117 289 61 295 61 105 0 43

boat1
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 33 230 157 182 150 169 151 157 156
Polygon -7566196 true true 149 55 88 143 103 139 111 136 117 139 126 145 130 147 139 147 146 146 149 55

boat2
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 157 54 175 79 174 96 185 102 178 112 194 124 196 131 190 139 192 146 211 151 216 154 157 154
Polygon -7566196 true true 150 74 146 91 139 99 143 114 141 123 137 126 131 129 132 139 142 136 126 142 119 147 148 147

boat3
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 37 172 45 188 59 202 79 217 109 220 130 218 147 204 156 158 156 161 142 170 123 170 102 169 88 165 62
Polygon -7566196 true true 149 66 142 78 139 96 141 111 146 139 148 147 110 147 113 131 118 106 126 71

box
true
0
Polygon -7566196 true true 45 255 255 255 255 45 45 45

butterfly1
true
0
Polygon -16777216 true false 151 76 138 91 138 284 150 296 162 286 162 91
Polygon -7566196 true true 164 106 184 79 205 61 236 48 259 53 279 86 287 119 289 158 278 177 256 182 164 181
Polygon -7566196 true true 136 110 119 82 110 71 85 61 59 48 36 56 17 88 6 115 2 147 15 178 134 178
Polygon -7566196 true true 46 181 28 227 50 255 77 273 112 283 135 274 135 180
Polygon -7566196 true true 165 185 254 184 272 224 255 251 236 267 191 283 164 276
Line -7566196 true 167 47 159 82
Line -7566196 true 136 47 145 81
Circle -7566196 true true 165 45 8
Circle -7566196 true true 134 45 6
Circle -7566196 true true 133 44 7
Circle -7566196 true true 133 43 8

circle
false
0
Circle -7566196 true true 35 35 230

person
false
0
Circle -7566196 true true 155 20 63
Rectangle -7566196 true true 158 79 217 164
Polygon -7566196 true true 158 81 110 129 131 143 158 109 165 110
Polygon -7566196 true true 216 83 267 123 248 143 215 107
Polygon -7566196 true true 167 163 145 234 183 234 183 163
Polygon -7566196 true true 195 163 195 233 227 233 206 159

sheep
false
15
Rectangle -1 true true 90 75 270 225
Circle -1 true true 15 75 150
Rectangle -16777216 true false 81 225 134 286
Rectangle -16777216 true false 180 225 238 285
Circle -16777216 true false 1 88 92

spacecraft
true
0
Polygon -7566196 true true 150 0 180 135 255 255 225 240 150 180 75 240 45 255 120 135

thin-arrow
true
0
Polygon -7566196 true true 150 0 0 150 120 150 120 293 180 293 180 150 300 150

truck-down
false
0
Polygon -7566196 true true 225 30 225 270 120 270 105 210 60 180 45 30 105 60 105 30
Polygon -8716033 true false 195 75 195 120 240 120 240 75
Polygon -8716033 true false 195 225 195 180 240 180 240 225

truck-left
false
0
Polygon -7566196 true true 120 135 225 135 225 210 75 210 75 165 105 165
Polygon -8716033 true false 90 210 105 225 120 210
Polygon -8716033 true false 180 210 195 225 210 210

truck-right
false
0
Polygon -7566196 true true 180 135 75 135 75 210 225 210 225 165 195 165
Polygon -8716033 true false 210 210 195 225 180 210
Polygon -8716033 true false 120 210 105 225 90 210

turtle
true
0
Polygon -7566196 true true 138 75 162 75 165 105 225 105 225 142 195 135 195 187 225 195 225 225 195 217 195 202 105 202 105 217 75 225 75 195 105 187 105 135 75 142 75 105 135 105

wolf
false
0
Rectangle -7566196 true true 15 105 105 165
Rectangle -7566196 true true 45 90 105 105
Polygon -7566196 true true 60 90 83 44 104 90
Polygon -16777216 true false 67 90 82 59 97 89
Rectangle -1 true false 48 93 59 105
Rectangle -16777216 true false 51 96 55 101
Rectangle -16777216 true false 0 121 15 135
Rectangle -16777216 true false 15 136 60 151
Polygon -1 true false 15 136 23 149 31 136
Polygon -1 true false 30 151 37 136 43 151
Rectangle -7566196 true true 105 120 263 195
Rectangle -7566196 true true 108 195 259 201
Rectangle -7566196 true true 114 201 252 210
Rectangle -7566196 true true 120 210 243 214
Rectangle -7566196 true true 115 114 255 120
Rectangle -7566196 true true 128 108 248 114
Rectangle -7566196 true true 150 105 225 108
Rectangle -7566196 true true 132 214 155 270
Rectangle -7566196 true true 110 260 132 270
Rectangle -7566196 true true 210 214 232 270
Rectangle -7566196 true true 189 260 210 270
Line -7566196 true 263 127 281 155
Line -7566196 true 281 155 281 192

wolf-left
false
3
Polygon -6524078 true true 117 97 91 74 66 74 60 85 36 85 38 92 44 97 62 97 81 117 84 134 92 147 109 152 136 144 174 144 174 103 143 103 134 97
Polygon -6524078 true true 87 80 79 55 76 79
Polygon -6524078 true true 81 75 70 58 73 82
Polygon -6524078 true true 99 131 76 152 76 163 96 182 104 182 109 173 102 167 99 173 87 159 104 140
Polygon -6524078 true true 107 138 107 186 98 190 99 196 112 196 115 190
Polygon -6524078 true true 116 140 114 189 105 137
Rectangle -6524078 true true 109 150 114 192
Rectangle -6524078 true true 111 143 116 191
Polygon -6524078 true true 168 106 184 98 205 98 218 115 218 137 186 164 196 176 195 194 178 195 178 183 188 183 169 164 173 144
Polygon -6524078 true true 207 140 200 163 206 175 207 192 193 189 192 177 198 176 185 150
Polygon -6524078 true true 214 134 203 168 192 148
Polygon -6524078 true true 204 151 203 176 193 148
Polygon -6524078 true true 207 103 221 98 236 101 243 115 243 128 256 142 239 143 233 133 225 115 214 114

wolf-right
false
3
Polygon -6524078 true true 170 127 200 93 231 93 237 103 262 103 261 113 253 119 231 119 215 143 213 160 208 173 189 187 169 190 154 190 126 180 106 171 72 171 73 126 122 126 144 123 159 123
Polygon -6524078 true true 201 99 214 69 215 99
Polygon -6524078 true true 207 98 223 71 220 101
Polygon -6524078 true true 184 172 189 234 203 238 203 246 187 247 180 239 171 180
Polygon -6524078 true true 197 174 204 220 218 224 219 234 201 232 195 225 179 179
Polygon -6524078 true true 78 167 95 187 95 208 79 220 92 234 98 235 100 249 81 246 76 241 61 212 65 195 52 170 45 150 44 128 55 121 69 121 81 135
Polygon -6524078 true true 48 143 58 141
Polygon -6524078 true true 46 136 68 137
Polygon -6524078 true true 45 129 35 142 37 159 53 192 47 210 62 238 80 237
Line -16777216 false 74 237 59 213
Line -16777216 false 59 213 59 212
Line -16777216 false 58 211 67 192
Polygon -6524078 true true 38 138 66 149
Polygon -6524078 true true 46 128 33 120 21 118 11 123 3 138 5 160 13 178 9 192 0 199 20 196 25 179 24 161 25 148 45 140
Polygon -6524078 true true 67 122 96 126 63 144

@#$#@#$#@
NetLogo 2.0.0
@#$#@#$#@
need-to-manually-make-preview-for-this-model
@#$#@#$#@
@#$#@#$#@
