globals [number concentration]              ;; global variables are the numbe of cells and concentration
breeds [cells]                              ;; let's call them cells instead of turtles
cells-own [state ticks]                     ;; each cell contain its current set ("young" or "mature")
                                            ;; and "internal" clock

to setup
  clear-all
  set-default-shape cells "circle"            ;; define cells as circles
  set number initial_concentration * 100.0    ;; initial number of cells from given conc. (in %)
  create-custom-cells number [                ;; create initial population of mature cells
                                 set ticks 0.0
                                 set state "mature"
                                 set color red
                                 random-pos
                             ]
  setup-plot
end


to move-cells
  locals [dt]
  set dt 1                                                    ;; time step
  ask cells [
                fd random-float 1.0                           ;; move in random direction
                if ticks >= (delay * dt) and state = "young"  ;; after some delay cells become mature
                [
                   set state "mature"
                   set color red                              ;; mature cells are red
                ]
                set ticks ticks + dt                          ;; time increment
              ]
  cells-die                                                   ;; call cells-die procedure
  set number (count cells with [state = "mature"])            ;; count the number of mature cells
  cells-are-born                                              ;; call cells-are-born procedure
  compute-concentration
  do-plot                                                     ;; plot concentration
end


to cells-die         ;; cells die in proportion with decay constant alpha
  ask random-n-of (int (alpha * number)) cells with [state = "mature"]
  [
     die
  ]
end


to cells-are-born    ;; cells are produced depending on the number
  locals [n]
  set n int (prod number)
  create-custom-cells n  [                           ;; generate cells from production function
                           set color green           ;; young cells are green
                           set state "young"
                           set ticks 0.0             ;; internal clock initialization
                           setxy (- screen-edge-x) 0 ;; cells are produced in the left side of the window
                           set heading (random 180)  ;; moving from left to right
                         ]
end


to compute-concentration  ;; compute concentrarion of blood cells
  set concentration (count cells with [state = "mature"]) / (initial_concentration * 100)
end

to random-pos        ;; setup cells in random positions moving in random directions
   setxy (random-float 2 * screen-edge-x) (random-float 2 * screen-edge-y)
   set heading (random 360)
end


to-report prod [n]   ;; production function of blood cells from Mackey-Glass (1977)
  locals [x]
  set x n / 100.0    ;; convert from number to concentration
  report (100 * (0.2 * x) / (1 + x ^ 10))
end


to do-plot           ;; do the plot
  set-current-plot "Concentration of Blood Cells"
  set-current-plot-pen "mature"
  plot concentration
end


to setup-plot        ;; set up plotting
  set-current-plot "Concentration of Blood Cells"
  set-plot-x-range 0 600
  set-plot-y-range ymin ymax
end


@#$#@#$#@
GRAPHICS-WINDOW
464
157
651
365
15
15
5.71
1
10
1
1
1
0
1
1
1

CC-WINDOW
5
379
660
474
Command Center
0

BUTTON
228
39
368
72
SETUP
setup
NIL
1
T
OBSERVER
T
NIL

BUTTON
395
40
534
73
START / STOP
move-cells
T
1
T
OBSERVER
T
NIL

PLOT
140
154
445
344
Concentration of Blood Cells
Time (days)
Concentration
0.0
100.0
0.0
1.0
true
false
PENS
"mature" 1.0 0 -2674135 false

SLIDER
306
99
460
132
delay
delay
0.0
100
6.0
1
1
days

SLIDER
475
99
631
132
alpha
alpha
0.01
0.5
0.03
0.01
1
NIL

SLIDER
137
98
292
131
initial_concentration
initial_concentration
0.2
5.0
0.5
0.1
1
NIL

SLIDER
28
306
120
339
ymin
ymin
0
10
0.0
0.1
1
NIL

SLIDER
28
154
120
187
ymax
ymax
0
10
1.8
0.1
1
NIL

@#$#@#$#@
WHAT IS IT?
-----------

This is a simulation of the control mechanism for the production
of white blood cells based on Mackey-Glass (1977).  Blood cells
have a certain half-life but new replacements are produced
continuosly. It takes about four days for a new cell to mature
so there is a delay in the dynamics governing the number of
mature blood cells. The goal of any control system is to keep
a certain quantity at a constant level. However, in real
systems the control mechanism is not activated inmediately but
only after a certain delay corresponding to the period of maduration
of the blood cells. The resulting dynamics is characterized by
oscillations that for certain delays may turn chaotic.

This simulation
pretends to ilustrate this process where an initial population of
blood cells are generated and new cells are produced in each time
step depending of the concentration of mature cells. The "young"
cells eventually are old enough to be mature and some of them die
in proportion with a decay constant.  The model also ilustrate the
effect of a delayed mixed feedback in the dynamics of biological
systems.


HOW IT WORKS
------------

This simulation is an individual based model (IBM) version of the classic
model of Mackey-Glass (1977) for phisiological control. The original
model is formulated as a delay differential equation (DDE) containing a term
corresponding to the production of new blood cells, P(x) and a decay term
(alpha) proportional to the number of mature cells in circulation. The
simulation was developed using the following procedure:

- Generate inital population of cells - Each cell contain two parameters:
  an internal clock (ticks) initialized as zero and the initial state
  of the cells (young or mature). The initialized cells are located randomly
  in the graphics windows and in each time step the cells "move" in random
  directions.

- In each time step the internal clock of each cell increases until it
  reachs the state of maturity where the cell changes from "young" to
  "mature". The time it takes to reach maturity is given by the delay
  parameter (in days).

- In each time step we  have to types of cells. Mature cells
  and young cells. The production of new cells are determined by the
  level of mature cells in circulation. For instance, if the total
  amount of mature cells is high the production of new cells is low.
  On the other hand, if the total amount of mature cells is low the
  production mechanism is high. In any case the model define a production
  function given by P(x) = (0.2 x)/(1 + x^10) which is the same used
  in the Mackey-Glass delay differential equation model.  Since the argument
  in P(x) is a concentration the NetLogo codes works out the calculation
  of concentration by dividing the number of cells in each time step
  by an arbitrary normalization factor (100) that in general could be
  calibrated with experimental data. The cell production mechanism is
  represented by the procedure "cells-are-born". Also, and like the
  original Mackey-Glass, the model contains a decay constant (alpha) that
  correspond to the amount of cells dying in each time step represented
  by the procedure "cells-die".


HOW TO USE IT
-------------

Button SETUP - Initialize the simulation by cleaning the plot region and the graphics section.

Button START/STOP - Start or stop the simulation. During the pause some of the parameters of the simulation can be modified

Slider initial_concentration - The initial concentration of mature blood cells in arbitrary units.

Slider delay - The period of maduration of the "young" cells in units of days.

Slider alpha - This is a decay constant that determines how many mature cells are going to die in each time step.

Slider ymin - Set the lower limit in the y-xis of the plot.

Slider ymax - Set the upper limit in the y-axis of the plot.

The graphics window shows the population of young blood cells (GREEN) and the population of mature cells (RED) in each time step. The young cells are produced in the left side of the graphics window.

THINGS TO NOTICE
----------------

If the initial concentration of blood cells is very low (0.2) the production of blood cells increases dramatically in a short period of time. On the other hand, if the
initial concentration is relatively high (2.0) the production decreases. This process
can be seen in the plot and also by the proportion of RED and GREEN cells in the graphics window.

As in the delay differential equation (DDE) model an increase in the delay parameter implies a transition from periodic oscillations to chaotic dynamics. However, there are certain windows of periodic oscillations.

The simulation is very sensitive to the decay parameter (alpha) if high values are selected the population dies inmediately.


THINGS TO TRY
-------------

Watch the dynamics of the simulation by moving back and forth the "delay" slider.
In this case we are looking at a more complicated version of the model where
we introduce a time dependent modulation in the delay parameter. Something similar
may be tried with the decay parameter but in this case the variations have to
be smaller.

EXTENDING THE MODEL
-------------------

Along the lines of the previous "THINGS TO TRY" section an interesting modification
could be that the delay parameter or the decay parameter varies periodically or quasi-periodically as a function of time.

Since the model pretends to "solve" a DDE the present model may be calibrated so
that the numerical values of the concentrations are fully consistent with standard
numerical solutions of DDEs using Euler or Runge-Kutta methods.

CREDITS AND REFERENCES
----------------------

[1] Mackey, M.C., and Glass, L. 1977. Oscillation and chaos in physiological control systems. Science 197: 287-89.

[2] Glass, L., and Mackey, M.C. 1988. From Clocks to Chaos. New Jersey: Princeton University Press

@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

ant
true
0
Polygon -7500403 true true 136 61 129 46 144 30 119 45 124 60 114 82 97 37 132 10 93 36 111 84 127 105 172 105 189 84 208 35 171 11 202 35 204 37 186 82 177 60 180 44 159 32 170 44 165 60
Polygon -7500403 true true 150 95 135 103 139 117 125 149 137 180 135 196 150 204 166 195 161 180 174 150 158 116 164 102
Polygon -7500403 true true 149 186 128 197 114 232 134 270 149 282 166 270 185 232 171 195 149 186
Polygon -7500403 true true 225 66 230 107 159 122 161 127 234 111 236 106
Polygon -7500403 true true 78 58 99 116 139 123 137 128 95 119
Polygon -7500403 true true 48 103 90 147 129 147 130 151 86 151
Polygon -7500403 true true 65 224 92 171 134 160 135 164 95 175
Polygon -7500403 true true 235 222 210 170 163 162 161 166 208 174
Polygon -7500403 true true 249 107 211 147 168 147 168 150 213 150

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

bee
true
0
Polygon -1184463 true false 152 149 77 163 67 195 67 211 74 234 85 252 100 264 116 276 134 286 151 300 167 285 182 278 206 260 220 242 226 218 226 195 222 166
Polygon -16777216 true false 150 149 128 151 114 151 98 145 80 122 80 103 81 83 95 67 117 58 141 54 151 53 177 55 195 66 207 82 211 94 211 116 204 139 189 149 171 152
Polygon -7500403 true true 151 54 119 59 96 60 81 50 78 39 87 25 103 18 115 23 121 13 150 1 180 14 189 23 197 17 210 19 222 30 222 44 212 57 192 58
Polygon -16777216 true false 70 185 74 171 223 172 224 186
Polygon -16777216 true false 67 211 71 226 224 226 225 211 67 211
Polygon -16777216 true false 91 257 106 269 195 269 211 255
Line -1 false 144 100 70 87
Line -1 false 70 87 45 87
Line -1 false 45 86 26 97
Line -1 false 26 96 22 115
Line -1 false 22 115 25 130
Line -1 false 26 131 37 141
Line -1 false 37 141 55 144
Line -1 false 55 143 143 101
Line -1 false 141 100 227 138
Line -1 false 227 138 241 137
Line -1 false 241 137 249 129
Line -1 false 249 129 254 110
Line -1 false 253 108 248 97
Line -1 false 249 95 235 82
Line -1 false 235 82 144 100

bird1
false
0
Polygon -7500403 true true 2 6 2 39 270 298 297 298 299 271 187 160 279 75 276 22 100 67 31 0

bird2
false
0
Polygon -7500403 true true 2 4 33 4 298 270 298 298 272 298 155 184 117 289 61 295 61 105 0 43

boat1
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6459832 true false 150 32 157 162
Polygon -13345367 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7500403 true true 158 33 230 157 182 150 169 151 157 156
Polygon -7500403 true true 149 55 88 143 103 139 111 136 117 139 126 145 130 147 139 147 146 146 149 55

boat2
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6459832 true false 150 32 157 162
Polygon -13345367 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7500403 true true 157 54 175 79 174 96 185 102 178 112 194 124 196 131 190 139 192 146 211 151 216 154 157 154
Polygon -7500403 true true 150 74 146 91 139 99 143 114 141 123 137 126 131 129 132 139 142 136 126 142 119 147 148 147

boat3
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6459832 true false 150 32 157 162
Polygon -13345367 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7500403 true true 158 37 172 45 188 59 202 79 217 109 220 130 218 147 204 156 158 156 161 142 170 123 170 102 169 88 165 62
Polygon -7500403 true true 149 66 142 78 139 96 141 111 146 139 148 147 110 147 113 131 118 106 126 71

box
true
0
Polygon -7500403 true true 45 255 255 255 255 45 45 45

butterfly1
true
0
Polygon -16777216 true false 151 76 138 91 138 284 150 296 162 286 162 91
Polygon -7500403 true true 164 106 184 79 205 61 236 48 259 53 279 86 287 119 289 158 278 177 256 182 164 181
Polygon -7500403 true true 136 110 119 82 110 71 85 61 59 48 36 56 17 88 6 115 2 147 15 178 134 178
Polygon -7500403 true true 46 181 28 227 50 255 77 273 112 283 135 274 135 180
Polygon -7500403 true true 165 185 254 184 272 224 255 251 236 267 191 283 164 276
Line -7500403 true 167 47 159 82
Line -7500403 true 136 47 145 81
Circle -7500403 true true 165 45 8
Circle -7500403 true true 134 45 6
Circle -7500403 true true 133 44 7
Circle -7500403 true true 133 43 8

circle
false
0
Circle -7500403 true true 35 35 230

person
false
0
Circle -7500403 true true 155 20 63
Rectangle -7500403 true true 158 79 217 164
Polygon -7500403 true true 158 81 110 129 131 143 158 109 165 110
Polygon -7500403 true true 216 83 267 123 248 143 215 107
Polygon -7500403 true true 167 163 145 234 183 234 183 163
Polygon -7500403 true true 195 163 195 233 227 233 206 159

sheep
false
15
Rectangle -1 true true 90 75 270 225
Circle -1 true true 15 75 150
Rectangle -16777216 true false 81 225 134 286
Rectangle -16777216 true false 180 225 238 285
Circle -16777216 true false 1 88 92

spacecraft
true
0
Polygon -7500403 true true 150 0 180 135 255 255 225 240 150 180 75 240 45 255 120 135

thin-arrow
true
0
Polygon -7500403 true true 150 0 0 150 120 150 120 293 180 293 180 150 300 150

truck-down
false
0
Polygon -7500403 true true 225 30 225 270 120 270 105 210 60 180 45 30 105 60 105 30
Polygon -8630108 true false 195 75 195 120 240 120 240 75
Polygon -8630108 true false 195 225 195 180 240 180 240 225

truck-left
false
0
Polygon -7500403 true true 120 135 225 135 225 210 75 210 75 165 105 165
Polygon -8630108 true false 90 210 105 225 120 210
Polygon -8630108 true false 180 210 195 225 210 210

truck-right
false
0
Polygon -7500403 true true 180 135 75 135 75 210 225 210 225 165 195 165
Polygon -8630108 true false 210 210 195 225 180 210
Polygon -8630108 true false 120 210 105 225 90 210

turtle
true
0
Polygon -7500403 true true 138 75 162 75 165 105 225 105 225 142 195 135 195 187 225 195 225 225 195 217 195 202 105 202 105 217 75 225 75 195 105 187 105 135 75 142 75 105 135 105

wolf
false
0
Rectangle -7500403 true true 15 105 105 165
Rectangle -7500403 true true 45 90 105 105
Polygon -7500403 true true 60 90 83 44 104 90
Polygon -16777216 true false 67 90 82 59 97 89
Rectangle -1 true false 48 93 59 105
Rectangle -16777216 true false 51 96 55 101
Rectangle -16777216 true false 0 121 15 135
Rectangle -16777216 true false 15 136 60 151
Polygon -1 true false 15 136 23 149 31 136
Polygon -1 true false 30 151 37 136 43 151
Rectangle -7500403 true true 105 120 263 195
Rectangle -7500403 true true 108 195 259 201
Rectangle -7500403 true true 114 201 252 210
Rectangle -7500403 true true 120 210 243 214
Rectangle -7500403 true true 115 114 255 120
Rectangle -7500403 true true 128 108 248 114
Rectangle -7500403 true true 150 105 225 108
Rectangle -7500403 true true 132 214 155 270
Rectangle -7500403 true true 110 260 132 270
Rectangle -7500403 true true 210 214 232 270
Rectangle -7500403 true true 189 260 210 270
Line -7500403 true 263 127 281 155
Line -7500403 true 281 155 281 192

wolf-left
false
3
Polygon -6459832 true true 117 97 91 74 66 74 60 85 36 85 38 92 44 97 62 97 81 117 84 134 92 147 109 152 136 144 174 144 174 103 143 103 134 97
Polygon -6459832 true true 87 80 79 55 76 79
Polygon -6459832 true true 81 75 70 58 73 82
Polygon -6459832 true true 99 131 76 152 76 163 96 182 104 182 109 173 102 167 99 173 87 159 104 140
Polygon -6459832 true true 107 138 107 186 98 190 99 196 112 196 115 190
Polygon -6459832 true true 116 140 114 189 105 137
Rectangle -6459832 true true 109 150 114 192
Rectangle -6459832 true true 111 143 116 191
Polygon -6459832 true true 168 106 184 98 205 98 218 115 218 137 186 164 196 176 195 194 178 195 178 183 188 183 169 164 173 144
Polygon -6459832 true true 207 140 200 163 206 175 207 192 193 189 192 177 198 176 185 150
Polygon -6459832 true true 214 134 203 168 192 148
Polygon -6459832 true true 204 151 203 176 193 148
Polygon -6459832 true true 207 103 221 98 236 101 243 115 243 128 256 142 239 143 233 133 225 115 214 114

wolf-right
false
3
Polygon -6459832 true true 170 127 200 93 231 93 237 103 262 103 261 113 253 119 231 119 215 143 213 160 208 173 189 187 169 190 154 190 126 180 106 171 72 171 73 126 122 126 144 123 159 123
Polygon -6459832 true true 201 99 214 69 215 99
Polygon -6459832 true true 207 98 223 71 220 101
Polygon -6459832 true true 184 172 189 234 203 238 203 246 187 247 180 239 171 180
Polygon -6459832 true true 197 174 204 220 218 224 219 234 201 232 195 225 179 179
Polygon -6459832 true true 78 167 95 187 95 208 79 220 92 234 98 235 100 249 81 246 76 241 61 212 65 195 52 170 45 150 44 128 55 121 69 121 81 135
Polygon -6459832 true true 48 143 58 141
Polygon -6459832 true true 46 136 68 137
Polygon -6459832 true true 45 129 35 142 37 159 53 192 47 210 62 238 80 237
Line -16777216 false 74 237 59 213
Line -16777216 false 59 213 59 212
Line -16777216 false 58 211 67 192
Polygon -6459832 true true 38 138 66 149
Polygon -6459832 true true 46 128 33 120 21 118 11 123 3 138 5 160 13 178 9 192 0 199 20 196 25 179 24 161 25 148 45 140
Polygon -6459832 true true 67 122 96 126 63 144

@#$#@#$#@
NetLogo 3.0pre5
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
