globals [
  how-many-substrates?
  time-cycles
  RCA ;; rate constant for acylation phase
  RCD ;; rate constant for deacylation phase
      ;; these are global variable, set up if the substrate is changed and copied to the enzymes-own
      ;; variables of Ka and Kd. Actually RCD/Kd are currently identical for both substrates but added
      ;; as variables to make it easier to add other substrates at any potential additions to the model
  burst-time ;; time cycle at which enzyme is added
]

breeds [
  enzyme    ;; chymotrypsin
  substrate ;; p-nitrophenyl acetate in the original burst expt.
  product-1 ;; the first product released (p-nitrophenol in the case of pNPA as the substrate).
            ;; This is the product that's detected by the spectrophotometer and recorded in the plot
  product-2
]

turtles-own [
  partner
]

enzyme-own [
  Ka ;; rate constant of acylation of enzyme (cleavage and release of product-1
  Kd ;; rate constant of deacylation of enzyme (release of product-2
     ;; N.B. these constants are associated with the enzyme rather than the substrate as
     ;; after acylation the substrate will have died but the Kd value will still be needed
]

to startup
  set how-many-enzymes? 50
  set which-substrate? "pNPA" ;; start with pNPA as the substrate
  change-substrate            ;; and put appropriate info in the output box
end

to setup
  ca
  set time-cycles 0
  set how-many-substrates? 500
  change-substrate  ;; check to see if different substrate required and do it if so
  add-substrate how-many-substrates?
end

to go
  ifelse  ( hide-substrate? = true )
    [
      ask substrate with [ partner = nobody ] [ set hidden? true ]
      ask substrate with [ partner != nobody ] [ set hidden? false ]
    ]
    [ ask substrate with [ partner = nobody ] [ set hidden? false ] ]

  ask turtles [ move ]
  ask enzyme [ catalyse ]
  do-plot
  if ( ( count substrate ) = 0 ) [ stop ] ;; no point continuing if substrate finished
  set time-cycles time-cycles + 1
  if ( ( ( count enzyme ) > 1 ) and ( time-cycles = ( burst-time + 10 ) ) ) [ ;; the burst is the absorbance change which occurs immediately after the
                                             ;; enzyme is added. This is measured 10 time cycles after enzyme addition
                                             ;; to give the enzyme a chance to do something. 10 cycles is rather arbitray
                                             ;; but gives reasonable results. If the model runs at anything near full speed
                                             ;; the burst looks more or less instantaneous, as it would in a laboratory
                                             ;; experiment using a standard spectrophotometer
    output-print ""
    output-print ""
    output-type "Burst size: " + ( count product-1 ) ;; print burst size to output box
  ]
  if ( ( count product-1 ) > 299 ) [ stop ] ;; stop the model if product-1 is about to overflow the y-axis to keep the graph pretty
end

to add-substrate [ amount ]
  cct amount [
    set partner nobody ;; not bound to anyone
    set breed substrate
    set shape "substrate"
    set xcor -17 + random 34
    set ycor -17 + random 34

  ]
end

to move
  if ( partner = nobody ) [ ;; enzymes with substrate bound are kept static for ease of study.
                            ;; A similar idea is used in the enzyme kinetics model in the library
    set heading random 360
    fd 1
  ]
end

to add-enzyme

  set-current-plot "absorbance"
  set-plot-x-range ( time-cycles - 100 ) ( time-cycles + 1000 ) ;; reset x-axis renge depending on time of enzyme addition - keeps it pretty!
  cct how-many-enzymes? [
    set partner nobody ;; no substrate bound
    set breed enzyme
    set shape "enzyme"
    set xcor -17 + random 34
    set ycor -17 + random 34
    set Ka RCA ;; set up rate constants based on the values depending on the chosen substrate
    set Kd RCD

  ]
  set burst-time time-cycles ;; note time of enzyme addition
end

to catalyse
  ifelse ( partner = nobody ) ;; no substrate bound ...
  [
    set partner random-one-of ( substrate-here ) ;; ... so try to find one
    if ( partner = nobody ) [ stop ] ;; no luck!
    if ( ( partner-of partner ) != nobody ) [ ;; found one - bind it
      set partner nobody
      stop
    ]
    set partner-of partner self
  ]

  [
    ifelse ( breed-of partner = substrate )
    [
      if ( random-float 1000 < Ka ) [ ;; susbtrate is bound so acylate enzyme at a speed dependent on Ka
        ask partner [ die ] ;; substrate gone
        let this-enzyme who ;; note which turtle this enzyme is
        ask patch-here [
          sprout 1 [            ;; produce product-1 ...
            set partner nobody  ;; ... which is released from enzyme ...
            set breed product-1
            set shape "product-1"
          ]
          sprout 1 [            ;; ... and product-2 ...
            set partner ( turtle this-enzyme ) ;; ... which is still bound to the enzyme
            set ( partner-of partner ) self
            set breed product-2
            set shape "product-2"
          ]
        ]

      ]
    ]

    [
      if ( random-float 1000 < Kd ) [      ;; bound ligand wasn't substrate so it must be product-2 so
        set ( partner-of partner ) nobody  ;; release at a rate dependent on Kd
        set partner nobody
      ]
    ]
  ]
end

to do-plot

  set-current-plot "absorbance"
  set-current-plot-pen "product-1"
  plot count product-1
  set-current-plot-pen "enzyme"
  plot count enzyme

end

to change-substrate

      ifelse ( which-substrate? = "pNPA" )
    [
      set RCA 800
      set RCD 5
    ]

    [
      set RCA 3
      set RCD 5
    ]
  ifelse ( which-substrate? = "pNPA" )
   [
     output-type "Chosen substrate: "
     output-print  ""
     output-type "p-nitrophenyl acetate"
     output-print  ""
     output-print  ""
     output-type "Low stability means that"
     output-print  ""
     output-type "acylation phase is easy"
     output-print  ""
     output-type "and fast"
     output-print ""

   ]

   [
     output-type "Chosen substrate: "
     output-print  ""
     output-type "generic peptide"
     output-print  ""
     output-print  ""
     output-type "High stability means that"
     output-print  ""
     output-type "acylation phase is relatively"
     output-print  ""
     output-type "difficult and slow"
     output-print ""

   ]

   output-print ""
   output-type "Ka: " + RCA
   output-print ""
   output-type "Kd: " + RCD
   output-print ""
   output-print ""
   output-type "The Kd value is assumed to be"
   output-print ""
   output-type "the same for both substrates"

end
@#$#@#$#@
GRAPHICS-WINDOW
303
10
733
461
17
17
12.0
1
10
1
1
1
0

CC-WINDOW
5
475
1000
570
Command Center

BUTTON
36
46
100
79
Setup
setup
NIL
1
T
OBSERVER
T
NIL

BUTTON
128
47
191
80
Go
go
T
1
T
OBSERVER
T
NIL

PLOT
17
96
217
246
Absorbance
Time
Absorbance
0.0
1000.0
0.0
300.0
true
true
PENS
"Product-1" 1.0 0 -11352576 true
"enzyme" 1.0 0 -65536 true

SLIDER
32
259
204
292
how-many-enzymes?
how-many-enzymes?
0
100
50
1
1
NIL

BUTTON
75
303
177
336
Add enzyme
add-enzyme
NIL
1
T
OBSERVER
T
NIL

CHOOSER
794
74
932
119
Which-substrate?
Which-substrate?
"pNPA" "Peptide"
0

SWITCH
47
397
190
430
hide-substrate?
hide-substrate?
1
1
-1000

OUTPUT
751
133
991
438

@#$#@#$#@
WHAT IS IT?
-----------
This is a simulation of Hartley's "burst" experiment which provided evidence for the biphasic (ping-pong) nature of the catalytic reaction of chymotrypsin and the other serine proteases. Chymotrypsin catalyses the hydrolysis of peptide bonds in proteins using the following biphasic mechanism:

	E-OH + R-CO-NH-R' --> E-CO-R + R'-NH2 (Acylation phase)
	E-CO-R + H2O --> E-OH + R-COOH  (Deacylation phase)

Using a normal substrate the first phase is slower than the second phase as it involves the cleavage of a very stable peptide (amide) bond. Hartley's experiment made use of an artificial substrate, p-nitrophenyl acetate (pNPA). The bond broken by the enzyme with this substrate is the very unstable phenolic ester bond and this reverses the rate balance between the two phases so that the acylation phase is faster than the deacylation phase.

On adding enzyme to a solution of pNPA every enzyme would very rapidly undergo the acylation phase, releasing one molecule of the product of that reaction (product 1) which is a yellow-coloured paranitrophenol, whose absorbance can be measured on a spectrophotometer. This produces a burst of colour whose absorbance is directly proportional to the enzyme concentration. The enzymes can only react with further substrates by releasing the second product which will take place at the much slower rate of the deacylation phase. The result of this is that on first addition of the reaction product 1 is generated, and absorbance due to it is observed, at the rate of the acylation phase. This occurs until all enzyme molecules have been acylated. Further generation of product 1 is dependent on the regeneration of free enzyme which occurs at the rate of the deacylation phase. There is an effective "separation" of the two phases showing a biphasic graph.

If a "normal" substrate is used, in which the acylation phase is slower than the deacylation phase, this biphasic effect will not be seen. The initial release of product 1 would be at the rate of the slow acylation phase. The acylated enzyme would then be relatively rapidly regenerated by deacyltion but this would not be observed directly as it is absorbance due to product 1 which is being observed. The regenerated enzyme can react with another substrate and generated another product at the rate of the acylation phase. The graph would show a single phase at the rate of the acylation phase.

HOW IT WORKS
------------
Uses some of the basic ideas of the enzyme kinetics module in the library. More details are commented in the procedures page.


HOW TO USE IT
-------------
By default the model starts with p-nitrophenyl acetate (pNPA) as the substrate and the number of enzyme molecules to be added set to fifty. These can be changed by using the chooser button and the slider. I suggest that you leave at the default setting to start with. The output box, to the right of the screen lists some basic information about the chosen substrate, which will be changed, if you alter the substrate, after you press the Setup button.

Press the setup button. This will add 500 substrate molecules to the model. They'll appear as cyan coloured double blobs. You can hide them using the hide-substrate? switch, but this will not come into effect until you press the Go button.

Press Go. Nothing much will happen as there is no enzyme present. If you look carefully at the graph window you'll see the line moving along the bottom of the graph. Press the Add enzyme button. This immediately adds the requested number of enzyme molecules to the reaction mixture. Look at the graph. The red line, which represents the amount of enzyme mixture, rises immediately at the point of addition and then stays unchanged. The green line, the amount of product 1, almost immediately rises to the same level as the enzyme graph (the initial burst) and then continues rising more slowly ( the rate of deacylation. The size of the burst will be printed at the bottom of the output window. Compare this to the amount of enzyme used.

If you look at the graphics window you'll be able to see the enzyme's (red squares), product 1 molecules (small yellow circles) and product 2 molecules (small blue squares). You can slow the reaction down using the slider at the top left of the graphics window, and hide the substrate, if it's too obtrusive, using the hide button.

Change to the other substrate (a generic peptide), press Setup and repeat the above excersize. Compare the results with the different substrates.

THINGS TO NOTICE
----------------



THINGS TO TRY
-------------
Try varying the amount of enzyme added and look at the size of the burst.

Try using only one enzyme molecule so that you can concentrate on it. Run the graphic fairly slowly, using the slider, and hide the substrates. You'll be able to see the speed of binding to and release from, the enzyme of the substrate and the two products. Substrate bound to the enzyme is visible even when the hide-substrate button is on. Compare these binding/release activities using the different substrates.

EXTENDING THE MODEL
-------------------
It would be easy to add more substrate variations with differing Ka/Kd values or perhaps introduce slider to let the user vary Ka/Kd values themselves.

You could set up a calculation of the rate of product 1 generation and compare these with Ka/Kd values.

NETLOGO FEATURES
----------------


RELATED MODELS
--------------
Enzyme Kinetics in the modules library


CREDITS AND REFERENCES
----------------------
Copyright: Dr. P. L. Birch - University of Paisley

Permission is granted to copy, distribute and adapt this model for any non-comercial use as long as this copyright notice is maintained.

A Web version is available at:

http://www-biol.paisley.ac.uk/courses/mechenz/serprot/burst.html
@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7566196 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7566196 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7566196 true true 150 285 285 225 285 75 150 135
Polygon -7566196 true true 150 135 15 75 150 15 285 75
Polygon -7566196 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7566196 true true 96 182 108
Circle -7566196 true true 110 127 80
Circle -7566196 true true 110 75 80
Line -7566196 true 150 100 80 30
Line -7566196 true 150 100 220 30

butterfly
true
0
Polygon -7566196 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7566196 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7566196 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7566196 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7566196 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7566196 true true 47 195 58
Circle -7566196 true true 195 195 58

circle
false
0
Circle -7566196 true true 30 30 240

circle 2
false
0
Circle -7566196 true true 16 16 270
Circle -16777216 true false 46 46 210

cow
false
0
Polygon -7566196 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7566196 true true 73 210 86 251 62 249 48 208
Polygon -7566196 true true 25 114 16 195 9 204 23 213 25 200 39 123

enzyme
false
0
Rectangle -65536 true false 0 0 300 300

face happy
false
0
Circle -7566196 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7566196 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7566196 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7566196 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7566196 true true 60 15 75 300
Polygon -7566196 true true 90 150 270 90 90 30
Line -7566196 true 75 135 90 135
Line -7566196 true 75 45 90 45

flower
false
0
Polygon -11352576 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7566196 true true 85 132 38
Circle -7566196 true true 130 147 38
Circle -7566196 true true 192 85 38
Circle -7566196 true true 85 40 38
Circle -7566196 true true 177 40 38
Circle -7566196 true true 177 132 38
Circle -7566196 true true 70 85 38
Circle -7566196 true true 130 25 38
Circle -7566196 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -11352576 true false 189 233 219 188 249 173 279 188 234 218
Polygon -11352576 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7566196 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7566196 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7566196 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7566196 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7566196 true 150 0 150 300

pentagon
false
0
Polygon -7566196 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7566196 true true 110 5 80
Polygon -7566196 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7566196 true true 127 79 172 94
Polygon -7566196 true true 195 90 240 150 225 180 165 105
Polygon -7566196 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7566196 true true 135 90 165 300
Polygon -7566196 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7566196 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7566196 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7566196 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7566196 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7566196 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7566196 true true 135 90 120 45 150 15 180 45 165 90

product-1
false
0
Circle -256 true false 86 86 127

product-2
false
0
Rectangle -16745473 true false 90 90 210 210

square
false
0
Rectangle -7566196 true true 30 30 270 270

square 2
false
0
Rectangle -7566196 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7566196 true true 60 270 150 0 240 270 15 105 285 105
Polygon -7566196 true true 75 120 105 210 195 210 225 120 150 75

substrate
true
0
Rectangle -16711681 true false 15 90 135 210
Circle -16711681 true false 161 86 127
Rectangle -16711681 true false 135 135 165 165

target
false
0
Circle -7566196 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7566196 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7566196 true true 120 120 60

tree
false
0
Circle -7566196 true true 118 3 94
Rectangle -6524078 true false 120 195 180 300
Circle -7566196 true true 65 21 108
Circle -7566196 true true 116 41 127
Circle -7566196 true true 45 90 120
Circle -7566196 true true 104 74 152

triangle
false
0
Polygon -7566196 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7566196 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7566196 true true 4 45 195 187
Polygon -7566196 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7566196 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7566196 false true 24 174 42
Circle -7566196 false true 144 174 42
Circle -7566196 false true 234 174 42

turtle
true
0
Polygon -11352576 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -11352576 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -11352576 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -11352576 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -11352576 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7566196 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7566196 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7566196 true 150 285 150 15
Line -7566196 true 15 150 285 150
Circle -7566196 true true 120 120 60
Line -7566196 true 216 40 79 269
Line -7566196 true 40 84 269 221
Line -7566196 true 40 216 269 79
Line -7566196 true 84 40 221 269

x
false
0
Polygon -7566196 true true 270 75 225 30 30 225 75 270
Polygon -7566196 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 2.1.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
