;attributes of the simulation
breeds [eb hormone] ;eb is an 'energy body' (energy-producing organelle), such as a mitochondrion
patches-own [temperature]
turtles-own [activity]
globals [total_temp NORM_TEMP RADIUS_OF_ACTIVATION HEAT_LOSS]

;get things ready
to setup

  set NORM_TEMP 35  ;nominal 'normal' temperature
  set RADIUS_OF_ACTIVATION 2  ;activation radius for hormone (minimum distance from energy body to activate)
  set HEAT_LOSS .1  ;rate of heat loss from each patch to the environment

  set-default-shape eb "circle"
  set-default-shape hormone "carbon-ring"

  ct
  clear-all-plots
  clear-patches

  create-eb Energy_Bodies   ;generic 'energy bodies' that don't move
  ask eb   ;place energy bodies at random
  	[set color green set xcor (random screen-size-x) set ycor (random screen-size-y)]
  ask patches
	  [set temperature Initial_Temperature]   ;initialize to uniform temperature

end

; the main execution loop...
to tick
  metabolize
  do-background-and-plot
  release-hormone
end


; this procedure calls both the energy-body agents (which are static) and the hormone agents (which move)
to metabolize
  ; energy bodies are activated by hormones on patches within RADIUS_OF_ACTIVATION units of body
  ask eb
    [if (any? hormone-on patches in-radius RADIUS_OF_ACTIVATION)
      [set temperature (temperature + Hormone_Activity)
       set color white]
    ]

  ask hormone
    [set activity activity - 1
     if activity < 0 [die]]
end

; hormones are released when the average temperature falls below the 'normal' temperature,
;   in proportion to the difference between these two temperatures
to release-hormone
  let FACTOR 2   ;constant of proportionality
  let cold_level ( NORM_TEMP - get-average-temperature )
  if cold_level < NORM_TEMP   ;using a normal distribution with mean at cold_level*FACTOR and s.d. at cold_level/4
    [create-custom-hormone (random-normal (cold_level * FACTOR) (cold_level / 4))
      [set xcor (random screen-size-x) set ycor (random screen-size-y)
       set color white set activity Hormone_Longevity]
    ]

   ask hormone [disperse]

end

to disperse
  rt random 20
  lt random 20
  forward ((random 2) + (random 2))
end

to do-background-and-plot
  ;100 percent of a patch's 'temperature' is distributed equally among its neighbors
  diffuse temperature 1

  ;external heat loss of HEAT_LOSS degrees per tick
  ask patches
   [set temperature (temperature - HEAT_LOSS)]

  ask eb [set color green]

  color-cells

  set-current-plot "temperature vs. time"
  plot get-average-temperature
  set-current-plot "hormone level vs. time"
  plot count hormone
end

;color patches so that they are red when too "hot" (temp > 'normal') and blue when too "cold" (temp < 'normal')
to color-cells
  ask patches
    [ ifelse temperature >= NORM_TEMP
      [set pcolor (scale-color red temperature NORM_TEMP 50)]
      [set pcolor (scale-color blue temperature NORM_TEMP 20)]
    ]
end

;compute average temperature across all patches
to-report get-average-temperature
  set total_temp sum values-from patches [temperature]
  report (total_temp / (screen-size-x * screen-size-y))
end


@#$#@#$#@
GRAPHICS-WINDOW
405
142
820
578
13
13
15.0
1
10
1
1
1
0

CC-WINDOW
5
592
829
687
Command Center

BUTTON
176
14
242
47
NIL
setup
NIL
1
T
OBSERVER
T
NIL

BUTTON
579
14
642
47
go
tick
T
1
T
OBSERVER
T
NIL

SLIDER
26
62
401
95
Energy_Bodies
Energy_Bodies
10
200
45
5
1
NIL

SLIDER
422
62
797
95
Hormone_Activity
Hormone_Activity
0
20
6
1
1
units

SLIDER
93
106
335
139
Initial_Temperature
Initial_Temperature
30
40
35.0
0.1
1
degrees C

PLOT
20
367
390
565
temperature vs. time
ticks
average temperature
0.0
10.0
30.0
40.0
true
false
PENS
"default" 1.0 0 -65536 true

SLIDER
422
95
798
128
Hormone_Longevity
Hormone_Longevity
0
100
28
1
1
ticks

PLOT
20
180
391
364
hormone level vs. time
time
number of molecules
0.0
10.0
0.0
10.0
true
false

@#$#@#$#@
WHAT IS IT?
-----------

This is a simple molecular model of feedback in homeostasis of an organism.  In this model, the background field represents a cell or tissue in which various energy-producing bodies, or 'energy bodies' are embedded.  The cell/tissue is contantly losing heat to some cold external environment.  When the tissue becomes too cold, hormones are produced which stimulate the production of heat in the energy bodies. The energy bodies can been seen as particular kinds of cells in muscle tissue, or as mitochondria in a single cell.  Loss of heat from the cell or tissue is balanced by production of heat by the energy bodies, according to the following feedback process:

cold --> production of hormones --> stimulation of energy bodies --> heat production --> cessation of hormone production

The modeled feedback process is considerably simpler than that found in real homeostasis, which often involves more than one hormone in the feedback regulation, as in the case of thyroxine-thyrotropin feedback for temperature regulation in humans.  Nevertheless, the model accurately depicts the cyclic nature of homeostatic regulation.


HOW IT WORKS
------------

Patches represent elements of the background field (a cell, or tissue).  There are two kinds of agents, 'energy bodies' which do not move and are represented by green circles; and 'hormone' molecules which drift through the field and are represented by white carbon rings.  Hormones have two properties, a longevity (the number of ticks they are active following creation) and an activation level, which is the amount of heat they stimulate the energy body to produce.  It is assumed that only the proximity of the hormone is required to stimulate an energy body; otherwise, there is no limit on the production of energy.

Note that the color of each patch is scaled according to temperature.  Temperatures at the 'ideal' temperature of 35 (a value set in the code) are a neutral black; temperatures above the ideal are scaled to be increasingly red, while temperatures below the ideal are scaled by to increasingly blue.

The field starts out with each patch having a uniform value of temperature, given by Initial_Temperature.  The field is constantly losing heat (for simplicity, taken to be the same as temperature; for you physicists, the field can be taken to have a specific heat of 1, which is not terribly far from the truth for most aqueous tissues), at a rate of .1 degree per tick of time.  As the average temperature falls below the ideal temperature, hormones are produced in a number proportional to the difference between the ideal temperature and the average temperature.  This can be seen:  as the field begins to grow blue, more and more hormone molecules are produced.

When a hormone molecule passes within one patch of an energy body, the energy body produces a quantity of heat in that patch given by the Hormone_Activity slider.  This heat is quickly diffused to surrounding patches.  Activation of an energy body has the appearance of a 'bloom' around the green body, while the body itself flashes white when activated.  A body is often activated several times by a passing hormone molecule.

As more heat is diffused from the energy bodies, average temperature rises and the production of hormone slows down (and may stop).


HOW TO USE IT
-------------

The main use of the model is to explore how the parameters of the model influence the temperature cycle.  For instance, how should parameters be set in order to minimize temperature fluctuation?  The following sliders can be adjusted:

- Initial_Temperature:  Sets the initial temperature of patches.
- Energy_Bodies:  Sets the number of energy bodies created by 'setup'.  The more energy bodies, the more heat a given amount of hormone will create.  (We have assumed that hormone lifespan is independent of activation frequency).
- Hormone_Activity:  The number of units by which temperature of a patch is increased, when a hormone molecule gets within radius 1 of an energy body.  Note that a molecule may activate the same patch more than once.
- Hormone_Longevity:  The number of ticks a hormone molecule persists after creation.

The two graphs show the number of hormone molecules as a function of time, and the average temperature as a function of time.


THINGS TO NOTICE
----------------

Although it might seem that longer-lasting hormones would be most beneficial, it turns out that these induce the greatest temperature swings.  Short-lived hormones are the most responsive to temperature fluctuations.  Similarly, super-active hormones create bursts of heat that tend to increase rather than decrease the range of fluctuation.  However, too few energy bodies, or too little hormone activity, tends to result in constant hormone production without ever reaching ideal heat.  (In fact, too few energy bodies can result in the tissue 'freezing', while too many result in a state of frequent overheating.)


THINGS TO TRY
-------------

Define a given temperature range as 'normal'.  What combinations of parameters keep the tissue or cell within this normal range?  What determines the period (frequency) of temperature oscillation?  Are there any parameter ranges that are always unhealthy, i.e. never stay within the normal range?  What ranges are best for tissue with few energy bodies?  With many?

Look up thyrotropin feedback on the internet.  How well does the NetLogo model capture real thyrotropin feedback in homeostasis of humans?  What elements have been left out?  What aspects of the NetLogo model may be problematic or incorrect from the perspective of a biologist?


EXTENDING THE MODEL
-------------------

A number of simplifying assumptions were made which could be revised or changed:
- normal temperature is 35 degrees
- temperature is decreasing uniformly in each patch by .1 degree per tick
- the hormone's 'radius of activation' is just 2 units (from the center of an energy body)

These values are given as constants (globals) and can be changed in code, or associated with new sliders.

Also, the longevity of hormone is an absolute amount of time, but could be easily changed to mean the number of activations.

A more realistic model involving two hormones -- one for activation and one for deactivation -- could be created by adding another hormone 'breed' and modifying the 'metabolize' procedure.

Hormone production could be localized in another kind of body (such as a ribosome), rather than spontaneously appearing.


NETLOGO FEATURES
----------------

This model makes use of NetLogo's agentset capabilities.  "values-from patches..." is used to calculate the average temperature of patches, while "any? hormone-on patches in-radius..." is used to determine whether any hormone molecules are present within a given radius of an energy body.


CREDITS AND REFERENCES
----------------------

This model was written by Mathew Davies through the NSF-sponsored GK-12 program at the School of Engineering and Applied Sciences at Columbia University, for use in 8th-grade science classrooms at I.S. 143 (Eleanor Roosevelt intermediate school, Washington Heights) in Manhattan, New York in the fall of 2004.  The author may be contacted at the email address:
mpd2002@columbia.edu

This simulation, along with other technology-based classroom resources, may be found at the website
http://tip.columbia.edu

@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7566196 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7566196 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7566196 true true 150 285 285 225 285 75 150 135
Polygon -7566196 true true 150 135 15 75 150 15 285 75
Polygon -7566196 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7566196 true true 96 182 108
Circle -7566196 true true 110 127 80
Circle -7566196 true true 110 75 80
Line -7566196 true 150 100 80 30
Line -7566196 true 150 100 220 30

butterfly
true
0
Polygon -7566196 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7566196 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7566196 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7566196 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7566196 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7566196 true true 47 195 58
Circle -7566196 true true 195 195 58

carbon-ring
true
0
Circle -7566196 true true 116 11 67
Circle -7566196 true true 26 176 67
Circle -7566196 true true 206 176 67
Circle -7566196 false true 45 45 210
Circle -7566196 true true 26 58 67
Circle -7566196 true true 206 58 67
Circle -7566196 true true 116 221 67

circle
false
0
Circle -7566196 true true 30 30 240

circle 2
false
0
Circle -7566196 true true 16 16 270
Circle -16777216 true false 46 46 210

cow
false
0
Polygon -7566196 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7566196 true true 73 210 86 251 62 249 48 208
Polygon -7566196 true true 25 114 16 195 9 204 23 213 25 200 39 123

face happy
false
0
Circle -7566196 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7566196 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7566196 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7566196 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7566196 true true 60 15 75 300
Polygon -7566196 true true 90 150 270 90 90 30
Line -7566196 true 75 135 90 135
Line -7566196 true 75 45 90 45

flower
false
0
Polygon -11352576 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7566196 true true 85 132 38
Circle -7566196 true true 130 147 38
Circle -7566196 true true 192 85 38
Circle -7566196 true true 85 40 38
Circle -7566196 true true 177 40 38
Circle -7566196 true true 177 132 38
Circle -7566196 true true 70 85 38
Circle -7566196 true true 130 25 38
Circle -7566196 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -11352576 true false 189 233 219 188 249 173 279 188 234 218
Polygon -11352576 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7566196 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7566196 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7566196 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7566196 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7566196 true 150 0 150 300

orbit 6
true
0
Circle -7566196 true true 116 11 67
Circle -7566196 true true 26 176 67
Circle -7566196 true true 206 176 67
Circle -7566196 false true 45 45 210
Circle -7566196 true true 26 58 67
Circle -7566196 true true 206 58 67
Circle -7566196 true true 116 221 67

pentagon
false
0
Polygon -7566196 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7566196 true true 110 5 80
Polygon -7566196 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7566196 true true 127 79 172 94
Polygon -7566196 true true 195 90 240 150 225 180 165 105
Polygon -7566196 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7566196 true true 135 90 165 300
Polygon -7566196 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7566196 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7566196 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7566196 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7566196 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7566196 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7566196 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7566196 true true 30 30 270 270

square 2
false
0
Rectangle -7566196 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7566196 true true 60 270 150 0 240 270 15 105 285 105
Polygon -7566196 true true 75 120 105 210 195 210 225 120 150 75

target
false
0
Circle -7566196 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7566196 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7566196 true true 120 120 60

tree
false
0
Circle -7566196 true true 118 3 94
Rectangle -6524078 true false 120 195 180 300
Circle -7566196 true true 65 21 108
Circle -7566196 true true 116 41 127
Circle -7566196 true true 45 90 120
Circle -7566196 true true 104 74 152

triangle
false
0
Polygon -7566196 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7566196 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7566196 true true 4 45 195 187
Polygon -7566196 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7566196 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7566196 false true 24 174 42
Circle -7566196 false true 144 174 42
Circle -7566196 false true 234 174 42

turtle
true
0
Polygon -11352576 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -11352576 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -11352576 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -11352576 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -11352576 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7566196 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7566196 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7566196 true 150 285 150 15
Line -7566196 true 15 150 285 150
Circle -7566196 true true 120 120 60
Line -7566196 true 216 40 79 269
Line -7566196 true 40 84 269 221
Line -7566196 true 40 216 269 79
Line -7566196 true 84 40 221 269

worm
true
0
Polygon -6524078 true false 135 75 120 120 120 165 135 195 165 225 180 255 180 285 165 300 195 285 210 225 195 195 180 165 180 120 165 75 135 75
Circle -7566196 true true 120 30 58
Rectangle -1 true false 120 30 135 45
Rectangle -1 true false 165 30 180 45
Polygon -16777216 false false 148 90 148 167 194 242 152 168

x
false
0
Polygon -7566196 true true 270 75 225 30 30 225 75 270
Polygon -7566196 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 2.1.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
