globals [

  totalatp ;; maintained number of ATP molecules
  totalglycogen
  degrade? ;; TRUE if model is in glycogen breakdown mode, FALSE in synthesis mode

]

turtles-own [

  age ;; used to mark natural loss of cAMP, glucose and phosphorylated enzymes
  partner ;; marks binding between turtles
  substrate ;; marks binding of substrate to enzyme
  how-active ;; marks degree of activity of an enzyme which, together with a random number, decides on whether a reaction will occur
  active ;; TRUE for an active enzyme
  life-exp ;; number of time cycles that a molecule survives in a particular state

]



breeds [
  insulin
  glucagon
  ATP
  receptor
  cyclase
  cAMP ;; cyclic AMP
  prot-kinase ;; protein kinase
  phos-kinase ;; phosphorylase kinase
  phosphorylase
  glucose
  glycogen
  synthase
  ]


phosphorylase-own [

  bound-time ;; limit to number of time cycles that enzyme is bound to glycogen

]

synthase-own [

  bound-time

]

to startup

  set direction? "glycogen breakdown" ;; defaults to glycogen breakdown mode ...
  set insulins 0 ;; ... and no hormones
  set glucagons 0


end

to setup

  initialise-constants
  ca
  ask patches with [( pycor = 10 )]  [ set pcolor brown ] ;; cell membrane
  ask patches with [ ( pycor  > 10 ) ] [ set pcolor 4 ] ;; colour of extracellular fluid
  add-ATP totalatp
  add-prot-kinase 100 ;; protein kinase
  add-phos-kinase 200 ;;phosphorylase kinase
  add-phosphorylase 400
  add-glycogen 50
  add-cyclase 7

end

to initialise-constants

set degrade? true

end

to go

  set totalatp 500
  change-direction ;; check on "direction?" chooser and change mode if required
  if ( count ATP < totalatp ) [ add-ATP 1 ] ;; maintain constant ATP concentration
  maintain-hormones ;; set hormone levels to values on sliders

  hide-turtles ;; check switches and hide turtles as required
  ask turtles [ move ]
  make-cAMP   ;; generation of cAMP by cyclase
  ask cAMP [ grow-old ] ;; mimics loss of cAMP as result of phosphodiesterase action
  if ( degrade? = true ) [  ;; in glycogen breakdown mode, glucose is generated by the model.
    ask glucose [ grow-old ] ;; This "aging" process mimics the loss of glucose either by its breakdown in the cell
  ]                          ;; or its export into the blood stream
  ask receptor [ form-hormone-complex ]
  ask prot-kinase [ bind-cAMP ]
  ask prot-kinase  [ phosphorylate ]
  ask phos-kinase [ phosphorylate ]
  ask phos-kinase [ maintain-enzymes ] ;; phosphorylated enzymes are dephosphorylated by protein phosphatase
  ask phosphorylase [ maintain-enzymes ] ;; which action is mimicked here
  ask phosphorylase [make-glucose] ;; actions on phosphorylase will only occur in breakdown mode and on
  ask synthase [ make-glycogen ]   ;; synthase in synthesis mode. The mode doesn't nedd to be checked as the "wrong"
  ask synthase [ maintain-enzymes ] ;; turtles are deleted in switching modes
  if ( ( degrade? = false ) and ( feed? = true ) ) [ feed ] ;; supplies glucose to the cell in synthesise mode
                                                            ;; mimicking glucose supply from the blood stream
  do-plots
end

to hide-turtles

  ifelse ( hide-ATP? = true )
    [ ask ATP [ set hidden? true ] ]
    [ ask ATP [ set hidden? false ] ]
  ifelse ( hide-cAMP? = true )
    [ ask cAMP [ set hidden? true ] ]
    [ ask cAMP [ set hidden? false ] ]
  ifelse (hide-protein-kinase? = true)
    [ ask prot-kinase [ set hidden? true ] ]
    [ ask prot-kinase [ set hidden? false ] ]
  ifelse ( hide-phosphorylase-kinase? = true )
    [ ask phos-kinase [ set hidden? true ] ]
    [ ask phos-kinase [ set hidden? false ] ]
  ifelse ( hide-phosphorylase? = true )
    [ ask phosphorylase [ set hidden? true ] ]
    [ ask phosphorylase [ set hidden? false ] ]
  ifelse ( hide-glucose? = true )
    [ ask glucose [ set hidden? true ] ]
    [ ask glucose [ set hidden? false ] ]
  ifelse ( hide-synthase? = true )
    [ ask synthase [ set hidden? true ] ]
    [ ask synthase [ set hidden? false ] ]
  ifelse ( hide-glycogen? = true )
    [ ask glycogen [ set hidden? true ] ]
    [ ask glycogen [ set hidden? false ] ]
end


to move

  if partner = nobody [ ;; move turtles if they're not bound to anything ...
    if ((breed != cyclase) and (breed != receptor)) [ ;; except for those that are bound to the membrane
      set heading random (360)
      if ((pycor-of (patch-ahead 1) = 10) or (pycor-of (patch-ahead 1) =  screen-edge-y )) [set heading heading + 180]
      fd 1
    ]
  ]


  if ((partner != nobody) and (breed = prot-kinase))  [  ;; only prot-kinase would have cAMP partner and both should
    without-interruption [                               ;; move together
    set heading random (360)

    if ((pycor-of (patch-ahead 1) = 10) or (pycor-of (patch-ahead 1) =  screen-edge-y )) [set heading heading + 180]
    let temphead heading
    ask partner [set heading temphead]
    fd 1
    ask  partner [ fd 1 ]
    ]
  ]

end

to add-ATP [ amount ]

    cct amount [
          set partner nobody
          set breed ATP
          set shape "ATP"
          set xcor -10
          set heading random 360 ;; spread the ATP
          fd random 50           ;; around a bit
          if ( ycor > 9 ) [      ;; and recover any that have escaped
            set heading 180      ;; outside the cell!
            fd 10
          ]

        ]
end

to add-prot-kinase [ amount ]

  cct amount [
    set partner nobody
    set breed prot-kinase
    set shape "enzyme"
    set xcor -10
    set ycor 0
    set color 63
    set life-exp 100
  ]

end

to add-phos-kinase [ amount ]

  cct amount [
    set partner nobody
    set breed phos-kinase
    set shape "enzyme"
    set xcor -10
    set ycor 0
    set color 83
    set active false
    set life-exp 100
    set degrade? true
  ]

end

to add-phosphorylase [ amount ]

  cct amount [
    set partner nobody
    set breed phosphorylase
    set shape "enzyme"
    set xcor -10
    set ycor 0
    set color 133
    set active false
    set life-exp 100
   ]

end

to add-synthase [ amount ]

  cct amount [
    set partner nobody
    set breed synthase
    set shape "enzyme"
    set xcor -10
    set ycor 0
    set color 107
    set active true
    set life-exp 1000
    set degrade? false
   ]

end

to add-cyclase [ amount ]

    ;; the receptor-cyclase complex comprises a grey patch replacing the brown colour of the membrane
    ;; and two turtles, the receptor outside the cell and the cyclase inside it.

  ask patches with [ ( pycor = 10 ) and ((remainder pxcor 5) = 0 ) ] [ set pcolor grey ]
  ask patches with [ ( pycor = 11 ) and ((remainder pxcor 5) = 0 ) ]
    [ sprout-receptor 1
      [ set partner nobody
       set color grey
       set shape "receptor"
       ]
    ]
  ask patches with [ ( pycor = 9 ) and ( ( remainder pxcor 5 ) = 0 ) ]
    [ sprout-cyclase 1
      [ set partner nobody
       set color grey
       set shape "cyclase"
       set how-active 50
      ]
    ]
end

to make-cAMP
  without-interruption [
  ask cyclase [
    if ( ( count ATP-here > 0 ) and ( how-active > random ( 500 ) ) )
      [

        ask ATP-here [ die ]
        ask patch-here [ sprout-cAMP 1 [
        set partner nobody
        set shape "cAMP"
        set color yellow ] ]

        ]

    ]
    ]
end

to grow-old

  if ( partner = nobody ) [
    set age age + 1
    if ( age > ( 100 + random 10 ) ) [ die ]
  ]

end

to maintain-hormones

  if ( count insulin < insulins ) [
        cct 1 [
          set partner nobody
          set breed insulin
          set shape "insulin"
          set xcor 0
          set ycor 16

        ]
  ]
  if ( count insulin > insulins ) [
    ask one-of insulin  [ die ]
   ]

  if ( count glucagon < glucagons ) [
        cct 1 [
          set partner nobody
          set breed glucagon
          set shape "glucagon"
          set xcor 0
          set ycor 16

        ]
  ]
  if ( count glucagon > glucagons ) [
    ask one-of glucagon [ die ]
   ]
end

to form-hormone-complex

  ifelse ( partner != nobody ) [ ;; hormone already bound. Nothing to do except to make it fall
    set age age + 1              ;; off again if it's outstayed its welcome
    if age > 600 + random ( 100 ) [
      set ( partner-of partner ) nobody
      set partner nobody
    ]
  ]

  [ set partner random-one-of ( other-turtles-here ) ;; is there anybody there?
  if partner = nobody [                              ;; no - so ...
    let thisx pxcor
    ask cyclase with [ xcor = thisx ] [              ;; tell linked cyclase to
      set color grey                                 ;; to colour itself grey
      set how-active 20 ]                            ;; and have a low activity level
      stop ]
  set age 0
  set ( partner-of partner ) self

  if ( breed-of partner = insulin ) [
     let thisx pxcor
     ask cyclase with [ xcor = thisx ] [              ;; insulin inhibits so
       set color red                                  ;; change the colour
       set how-active 0 ]                             ;; and make inactive
  ]
  if ( breed-of partner = glucagon ) [
     let thisx pxcor
     ask cyclase with [ xcor = thisx ] [              ;; glucagon has opposite effect
       set color cyan
       set how-active 500 ]
  ]
  ]

end

to do-plots

  set-current-plot "Molecular Ratios"
  clear-plot

  set-current-plot-pen "cAMP"
  plotxy 1 (count cAMP)
  set-current-plot-pen "Active-PK"
  plotxy 3 (count prot-kinase with [partner != nobody])
  set-current-plot-pen "Active PhosK"
  plotxy 5 (count phos-kinase with [active = true])
  set-current-plot-pen "Active Phosph"
  plotxy 7 (count phosphorylase with [active = true])
  set-current-plot-pen "Glucose"
  plotxy 9 (count glucose )
  set-current-plot-pen  "Synthase"
  plotxy 11 (count synthase with [active = true ] )

  set-current-plot "Enzymes"
  set-current-plot-pen "synthase"
  plot (count synthase with [ active = true ] )
  set-current-plot-pen "Phosphorylase"
  plot (count phosphorylase with [ active = true ] )

  set-current-plot "glucose"
  plot count glucose


end

to bind-cAMP


  ifelse ( partner = nobody ) [
    if  ( 40 < random 100 )  [ stop ] ;; binding ability adjustment
    set partner random-one-of ( cAMP-here ) ;; any cAMP there?
    if partner = nobody [ stop ]            ;; no, so don't do anything
    if ( ( partner-of partner ) != nobody ) [ ;; yes, but it's already bound
      set partner nobody                      ;; and bigamy is illegal
      stop
    ]
    set ( partner-of partner ) self           ;; yes, so hang on to it
    set active true                           ;; activate the enzyme
    set color 67                              ;; and change its colour to indicate activity
    set age 0
    ]

    [ set age age + 1                         ;; there's one bound already
     if ( age > ( 40 + random 4 ) ) [         ;; so see if it's been there too long
       set active false                       ;; and get rid of it if it has
       set color 63
       if ( ycor-of partner > 9 ) [
         set (ycor-of partner) 9
       ]
       set ( partner-of partner ) nobody
       set partner nobody
     ]
    ]

end

to phosphorylate

  if ( breed = prot-kinase )
    [ set substrate random-one-of ( turtles-here )

      if ( ( ( breed-of substrate ) = phos-kinase ) and ( active = true ) ) [  ;; phosphorylate only if protein kinase has cAMP bound
        if ( 30 < random 100 ) [ stop ]
        ask substrate [
          set active true ;; phosphorylation activates phosphorylase kinase
          set age 0
         ]
      ]
      if ( ( ( breed-of substrate ) = synthase ) and ( active = true ) ) [
        ask substrate [
          set active false  ;; phosphorylation deactivates glycogen synthase
          set age 0
         ]
      ]
     set substrate nobody
   ]
   if ( breed = phos-kinase ) [
      if ( 40 < random 100 ) [ stop ]
      set substrate random-one-of ( phosphorylase-here )
    ]
  if ( ( substrate != nobody ) and ( active = true ) )  [ ;; phosphorylate only if protein kinase hase cAMP bound
    ask substrate [
      set active true  ;; phosphorylation activates glycogen phosphorylase
      set age 0
    ]
    set substrate nobody
   ]



end

to maintain-enzymes

    ;; phosphorylated enzymes are dephosphorylated by a protein phosphatase. This is not included as a
    ;; turtle, to simplify the model. This procedure mimics its effect

  set age age + 1
  if (age > (life-exp + random life-exp / 10)) [
    ifelse ( breed = synthase )
      [ set active true ]
      [ set active false ]
  ]
  if (breed = phos-kinase) [
    ifelse (active = true)
      [ set color 87 ]
      [ set color 83 ]
  ]
  if ( breed = phosphorylase ) [
    ifelse (active = true)
      [ set color 137 ]
      [ set color 133 ]
  ]
  if ( breed = synthase ) [
    ifelse ( active = true )
      [ set color 17 ]
      [ set color 13 ]
  ]

end

to make-glucose

  if ( active = false ) [
    stop
    set bound-time 0 ]
  ifelse ( partner != nobody ) ;; only works if bound to glycogen. Nothing else binds to phosphorylase
    [ ask patch-here [ sprout-glucose 1 [
        set shape "glucose"
        set partner nobody
        set age 70

      ] ]
      set bound-time bound-time + 1 ;; stop the enzyme from being permanently bound to glycogen
      if (bound-time > 10) [
        set partner nobody
        set bound-time 0]

    ]

    [ set partner random-one-of ( glycogen-here ) ;; not bound to glycogen so let's see if there's one here
     if partner = nobody [ stop ]
     set bound-time 0


  ]
end

to make-glycogen

    ;; synthase doesn't actually make glycogen by increasing the number of glycogen turtles. Its
    ;; action is simply seen as a reduction in the amount of glucose present

  if ( active = false ) [
    stop
    set bound-time 0 ]

  if ( partner = nobody ) [
    set partner random-one-of ( glycogen-here ) ;; synthase only works if bound to glycogen, so look for one
    if partner = nobody [ stop ]
    set bound-time 0
  ]

  if ( ( breed-of partner ) = glycogen ) [
    set substrate random-one-of ( glucose-here )
    if ( substrate != nobody ) [
      ask substrate [ die ]  ;; glucose disappears as it's added to glycogen
      set substrate nobody
    ]

    set bound-time bound-time + 1  ;; don't let the enzyme stay bound for ever
    if ( bound-time > 5 ) [
      set partner nobody
      set bound-time 0
    ]
  ]

end

to add-glycogen [ amount ]

  cct amount [

    set breed glycogen
    set shape "glycogen"
    set ycor ( -17 + random 20 )
    set xcor ( -17 + random 34 )
    set color white
    set size 2
  ]

end

to change-direction

    ;; change from glycogen breakdown to glycogen synthesis mode if requested
    ;; via the chooser. Appropriate enzymes are added and unwanted ones removed

  if ( ( direction? = "glycogen synthesis" ) and ( degrade? = true ) ) [

    add-synthase 400
    ask phos-kinase [die]
    ask phosphorylase [die]
    set degrade? false
  ]

  if ( (direction? = "glycogen breakdown" ) and ( degrade? = false ) ) [


    add-phos-kinase 200
    add-phosphorylase 400
    ask synthase [die]
    set degrade? true
  ]

end

to feed

  cct 5 [
    set xcor 0
    set ycor 0
    set breed glucose
    set shape "glucose"
    set partner nobody
    set age 0
  ]

end
@#$#@#$#@
GRAPHICS-WINDOW
217
10
577
391
17
17
10.0
1
10
1
1
1
0

CC-WINDOW
5
480
972
575
Command Center

BUTTON
17
10
74
43
NIL
setup
NIL
1
T
OBSERVER
T
NIL

BUTTON
77
10
132
43
NIL
go
T
1
T
OBSERVER
T
NIL

SWITCH
18
52
119
85
hide-ATP?
hide-ATP?
0
1
-1000

PLOT
579
11
792
392
Molecular Ratios
time
cAMP conc
0.0
11.0
0.0
1000.0
false
false
PENS
"cAMP" 1.0 1 -26317 true
"Active-PK" 1.0 1 -6684928 true
"Active PhosK" 1.0 1 -13369345 true
"Active Phosph" 1.0 1 -65332 true
"Glucose" 1.0 1 -8716033 true
"synthase" 1.0 1 -65434 true

MONITOR
199
404
279
453
cAMP
count cAMP
3
1

SLIDER
18
318
155
351
insulins
insulins
0
20
20
1
1
NIL

SLIDER
18
351
156
384
glucagons
glucagons
0
20
0
1
1
NIL

MONITOR
279
404
337
453
PKinase
count prot-kinase with [partner != nobody]
3
1

MONITOR
329
404
387
453
PhosKin
count phos-kinase with [active = true]
3
1

MONITOR
387
404
483
453
Phosphorylase
count phosphorylase with [active = true]
3
1

SWITCH
18
84
126
117
hide-cAMP?
hide-cAMP?
0
1
-1000

SWITCH
18
117
165
150
hide-protein-kinase?
hide-protein-kinase?
0
1
-1000

SWITCH
18
150
201
183
hide-phosphorylase-kinase?
hide-phosphorylase-kinase?
0
1
-1000

SWITCH
18
183
171
216
hide-phosphorylase?
hide-phosphorylase?
0
1
-1000

PLOT
793
212
963
368
Enzymes
time
Synthase present
0.0
10.0
0.0
1.0
true
false
PENS
"Synthase" 1.0 0 -39322 true
"Phosphorylase" 1.0 0 -3407668 true

MONITOR
482
404
541
453
Glucose
count glucose
3
1

PLOT
793
42
963
200
Glucose
time
glucose
0.0
10.0
0.0
10.0
true
false
PENS
"Glucose" 1.0 0 -8716033 true

SWITCH
18
215
137
248
hide-glucose?
hide-glucose?
0
1
-1000

MONITOR
542
404
608
453
Synthase
count synthase with [ active = true ]
3
1

CHOOSER
19
421
165
466
direction?
direction?
"glycogen breakdown" "glycogen synthesis"
1

SWITCH
18
247
142
280
hide-synthase?
hide-synthase?
0
1
-1000

SWITCH
19
388
109
421
feed?
feed?
1
1
-1000

SWITCH
18
279
142
312
hide-glycogen?
hide-glycogen?
0
1
-1000

@#$#@#$#@
WHAT IS IT?
-----------
This model demonstrates the control of glycogen degradation to glucose, or its biosynthesis from glucose, in liver cells. It is designed as a teaching/learning tool rather than an accurate model of the biochemical events.

Glycogen is a polysaccharide that is used to store the body's glucose supplies. Its metabolism is controlled in the liver by two hormones, insulin and glucagon, that are produced by the pancreas and passed to the liver by the blood stream. Insulin stimulates the liver to make glycogen from glucose which will enter the cells from the blood stream (this glucose will ultimately come from the diet). Glucagon stimulates the liver to break down stored glycogen to glucose. Some of this can be used to produce energy within the liver cell but most of it will be passed out into the blood stream to maintain correct blood sugar levels.

Neither of these hormones enters the liver cell. Instead they bind to a receptor molecule on the outside of the cell membrane. The receptor is linked to an enzyme, adenylate cyclase, on the inside of the cell. This enzyme is able to create a compound called cyclic AMP (cAMP) from adenosine triphosphate (ATP). Glucagon, via the link from the receptor, activates this enzyme, while insulin inhibits it, so glucagon will cause cAMP to be produced more rapidly and insulin will slow down its production. cAMP is destroyed in the cell by another enzyme called phosphodiesterase, so its concentration will depend on the balance between the rate at which the cyclase creates it and the phosphodiesterase destroys it.

cAMP can bind to an enzyme called protein kinase. In doing so it activates it. cAMP is not permanently bound. In the fullness of time it will fall off and the enzyme will lose its activity again. As glucagon increases the amount of cAMP it will increase the number of active protein kinase enzymes, while insulin has the opposite effect.

Protein kinase can add a phosphate group to (phosphorylate) an enzyme. It can actually work on two enzymes that concern us here: glycogen synthase and phosphorylase kinase. These phosphate groups can be removed by another enzyme called protein phosphatase. The proportion of phosphorylated enzyme will depend on the balance between the kinase and the phosphatase. Glucagon increases the amount of active protein kinase and therefore increases the proportion of phosphorylated enzyme, while insulin has the opposite effect. Glycogen synthase is the main enzyme involved in making glycogen from glucose and the phosphorylated form of it is inactive. Insulin reduces the amount of inactive, phosphorylated synthase thus increasing generation of glycogen. Glucagon, causing an increase in phosphorylated synthase, will reduce the generation of glycogen. Glycogen stimulates production of glucose from glycogen, so you obviously don't want to be making it at the same time.

Phosphorylase kinase is active in the phosphorylated form, the opposite to the synthase. Its job is to phosphorylate another enzyme, glycogen phosphorylase, which is the main enzyme involved in breaking down glycogen to glucose. Glycogen phsphorylase is again only active in the phosphorylated form and can be dephosphorylated by protein phosphatase. So glucagon by increasing the amount of active phosphorylase kinase also increases the amount of active phosphorylase which increases the amount of glucose produced. Insulin will have the opposite effect.

To summarise:

glucagon --> more cAMP --> more active protein kinase --> more active phosphorylase kinase --> more active phosphorylase --> more glucose (insulin opposite effect)

insulin --> less cAMP --> less active protein kinase --> more active synthase --> more glycogen production (glucagon opposite effect)

These sequences of reactions are known as the "cascade effect" and have the result of greatly amplifying the influence of the enzymes. For instance one glucagon molecule can activate one cyclase enzyme, but that can then produce a number of cAMP molecules. These  can activate a number of protein kinases which can each phosphorylate a number of phosphorylase kinases which can each phosphorylate a number of phosphorylases. Finally each of these can release a large number of glucoses from glycogen.

HOW IT WORKS
------------
This model uses some ideas from the enzyme kinetics module in the library that ships with Netlogo. There are quite a lot of comments in the procedures page that should explain how most of it works.


HOW TO USE IT
-------------

Familiarise yourself with the items on the interface screen.

Main graphics window:

The black area which makes up the major part of this window represents the interior of a liver cell. The lighter coloured, grey, area at the top represents extracellular fluid. The brown bar separating them is the cell membrane. The grey, elliptical, shapes which cross the membrane are the protein complexes containing the hormone receptor and the cyclase enzyme. The slider at the top can be used to adjust the speed of the reactions.

Setup and Go buttons:

Click the setup button to initialise the model. It also clears the graphs. Click the go button to start and click it a second time to stop the model.

Hide switches:

These switches enable you to hide or show different enzymes and compounds on the screen. The object is hidden when the switch is on. It's suggested that you make a lot of use of the hide feature as the screen can be very confusing with everything shown. By hiding everything but one object you can see which colour and shape represents each object. Enzymes have a brighter colour when they are activated.

Hormone sliders:

These let you add insulin or glucagon to the extracellular fluid. At the start they are both set to zero, but can be increased up to 20

Feed switch:

This lets you start the provision of glucose to the cell when glycogen is being synthesise. It doesn't work when you're studying glycogen breakdown

Direction chooser:

Lets you switch between studying control of glycogen breakdown, by phosphorylase, and glycogen synthesis, by synthase. It's set to breakdown by default. These are the two modes of the model.

Monitors:

The row of monitors, below the main graphic window, shows the number of cAMP and glucose molecules and the number of active protein kinase, phosphorylase kinase, phosphorylase and synthase molecules currently in the model.

Graphs

Clicking on the Pens label will display a legend to indicate the meaning of the colours in the graphs. Clicking a second time will hide it again.  The large graph (heading: Molecular Ratios) simply gives you a graphic display of the figures in the monitors. It gives you a good indication of the ratios of the main players in the model. The Glucose graph simply plot the number of glucose molecules currently in the model. The Enzymes graph plots the number of active phosphorylase or synthase enzymes, which one you see depends on the mode that is operating.



THINGS TO NOTICE
----------------

You probably won't get much out of this model by just pressing Setup and Go and watching the pretty coloured dots. You need a more structured approach so I'll make one or two suggestions to start you off and you'll then have a better idea of how to experiment.

Start:

By default the model starts in glycogen breakdown mode with both of the hormone sliders set to zero. Leave them like that. Set all the hide switches to ON except the ones for ATP and cAMP. Click on the Setup button, which will initially turn black, when it's back to its original colour setup is complete. Click the Go button. You should see a large number of yellow symbols in the bottom section of the display. These are ATPs. If you look carefully you'll also see some small circular symbols, also yellow. These are cAMP. Hide the ATP using the switch and you'll see the cAMP more clearly.

The blue hexagonal symbols that you can also see on the screen are glucose molecules. Although you have glucose hidden they do appear initially when they are first generated. Turn off the hide switches for glucose and glycogen and you'll see the glucose molecules being spawned from the glycogen.

Enzyme activation:

Hide the glucose and glycogen again and turn off the hide switch on protein kinase. You'll see a lot of dull green symbols which are protein kinase. A small number of these will be a brighter shade of green and have a cAMP symbol attached to them. These are active enzymes. If you watch carefully you'll see that eventually the cAMP falls off of the kinase, which then becomes inactive. Similarly, loose cAMPs will bind themselves to inactive enzymes and activate them. This will be easier to follow if you slow the model down slightly with the slider at the top of the graphics display.

Turn off the hide on phosphorylase kinase, which will appear as blue symbols. Again, they can be in the inactive (dull blue) or active (bright blue) forms. They are turned from inactive to active by contact with an active, bright green, protein kinase. There will normally be more active phosphorylase kinases than active protein kinases as each of the latter can activae more than one of the former. You'll see this in the figures in the monitors under the graphics screen.

Hide protein kinase and cAMP and unhide phosphorylase. This enzyme is a pinkish colour. Again see the active forms in the bright colour which have been activated by phosphorylase kinase present in a larger number than the active phosphorylase kinase.

Hide phosphorylase kinase and unhide glycogen. You'll see active phosphorylase sticking to the glycogen and generating glucose. If you unhide the glucose you'll see it being produced from the glycogen. Binding of phosphorylase to glycogen is a temporary one. It will eventually fall off and glucose production will stop.

The graphs:

Look at the Molecular Ratios graph. The columns represent the amounts of cAMP, the three enzymes we've just been discussing and glucose. Notice the increasing height as you go from protein kinase to glucose which demonstrates the cascade effect. The Glucose and Enzymes graphs plot the levels of glucose and active phosphorylase against time. Notice how they follow each other very closely.

The hormones:

Hide everything except cAMP. Drag the insulin slider halfway to give a figure of 10. The insulin symbols will appear ( red "I"s) and move around trying to bind to acceptors. When they do the cyclase enzyme on the inside of the membrane will turn red to show that it's been inhibited. If you've slowed the model down previously you'll probably see this better if you turn it up to full speed again. Notice the reduction in the number of cAMPs and the corresponding decrease in active enzymes and glucose. See this in the graphs and the monitors. You'll notice that the insulin molecules do not stay bound for ever. Eventually they will fall off of the receptor which will then give a small burst of cAMP until it binds another insulin. You can adjust the amount of insulin to alter the level of its effects.

Now set insulin to zero and set glucagon to about 10. You'll see the opposite effect to insulin as glucagon activates adenylate cyclase. A lot of glucagon will bring about a large increase in glucose production. The scaling on the graphs will increase as necessary to accommodate this.

Glycogen biosynthesis:

Press the Go button to stop the model and pick "glycogen synthesis" from the direction slider. Set both hormone sliders to zero and turn the "Feed" switch off. Click the Go button. Watch the Enzymes graph, which is now showing the amount of active synthase. It will fall to come to equilibrium with the current situation in the cell. Once it's roughly levelled out (it will always go up and down a bit as all the changes are random) turn on the Feed switch. Glucose is now being supplied to the cell from the "blood stream" and the cells glucose level will rise unless it is stored as glycogen by the active synthase. You'll see the Glucose graph rising - you might also like to see the effect on the display screen by turning of the hide on glucose. Eventually the Glucose graph will level out as the supply of glucose is balanced by the amount being converted to glycogen. Turn off the feed switch and the glucose level will fall.

Slide the insulin slider completely to the right (20) and again wait until the level of active synthase levels out in the Enzymes graph. Turn on Feed again, wait till the Glucose graph levels out and switch off Feed. Slide insulin to zero and glucagon to 20 and repeat the same exercise with the feed button. Compare the results with insulin, glucagon and no hormones.


THINGS TO TRY
-------------

In both modes try using different amounts of insulin or glycogen and compare the results. In the model there are only seven receptors but, because hormones bind by weak bonds, seven insulins will not permanently inhibit cyclase, or seven glucagons permanently activate it. The more hormone you have the closer you are to saturating the receptor. You might also like to add glucagon and insulin at the same time to see how they compete with each other for binding.

Make use of the hide switches to examine different enzymes and look at the change in active enzymes as a result of the hormones.

EXTENDING THE MODEL
-------------------
This section could give some ideas of things to add or change in the procedures tab to make the model more complicated, detailed, accurate, etc.


NETLOGO FEATURES
----------------
This section could point out any especially interesting or unusual features of NetLogo that the model makes use of, particularly in the Procedures tab.  It might also point out places where workarounds were needed because of missing features.


RELATED MODELS
--------------
This section could give the names of models in the NetLogo Models Library or elsewhere which are of related interest.


CREDITS AND REFERENCES
----------------------
Copyright: Dr. P. L. Birch - University of Paisley.

Permission is granted to copy, distribute and adapt this model for non-commercial use as long as this copyright notice is maintained.

A Web version is available at:

http://www-biol.paisley.ac.uk/courses/cellsug/glycogen.html
@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7566196 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7566196 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

atp
false
0
Rectangle -256 true false 15 165 285 149
Circle -256 true false 63 123 66
Circle -256 true false 143 124 66
Circle -256 true false 219 125 66

box
false
0
Polygon -7566196 true true 150 285 285 225 285 75 150 135
Polygon -7566196 true true 150 135 15 75 150 15 285 75
Polygon -7566196 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7566196 true true 96 182 108
Circle -7566196 true true 110 127 80
Circle -7566196 true true 110 75 80
Line -7566196 true 150 100 80 30
Line -7566196 true 150 100 220 30

butterfly
true
0
Polygon -7566196 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7566196 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7566196 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7566196 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

camp
false
2
Circle -7566196 false false 55 55 192
Circle -44544 true true 118 64 66
Circle -44544 false true 87 86 128
Circle -44544 false true 85 85 130
Circle -44544 false true 89 88 122

car
false
0
Polygon -7566196 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7566196 true true 47 195 58
Circle -7566196 true true 195 195 58

circle
false
0
Circle -7566196 true true 30 30 240

circle 2
false
0
Circle -7566196 true true 16 16 270
Circle -16777216 true false 46 46 210

cow
false
0
Polygon -7566196 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7566196 true true 73 210 86 251 62 249 48 208
Polygon -7566196 true true 25 114 16 195 9 204 23 213 25 200 39 123

cyclase
false
0
Polygon -7566196 true true 0 0 15 90 75 150 210 150 285 90 300 0

enzyme
false
0
Polygon -7566196 true true 0 105 0 210 300 210 300 105 240 105 210 135 180 135 165 105 135 105 120 135 75 135 45 105

face happy
false
0
Circle -7566196 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7566196 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7566196 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7566196 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7566196 true true 60 15 75 300
Polygon -7566196 true true 90 150 270 90 90 30
Line -7566196 true 75 135 90 135
Line -7566196 true 75 45 90 45

flower
false
0
Polygon -11352576 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7566196 true true 85 132 38
Circle -7566196 true true 130 147 38
Circle -7566196 true true 192 85 38
Circle -7566196 true true 85 40 38
Circle -7566196 true true 177 40 38
Circle -7566196 true true 177 132 38
Circle -7566196 true true 70 85 38
Circle -7566196 true true 130 25 38
Circle -7566196 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -11352576 true false 189 233 219 188 249 173 279 188 234 218
Polygon -11352576 true false 180 255 150 210 105 210 75 240 135 240

glucagon
false
0
Rectangle -16711681 true false 75 0 225 15
Rectangle -16711681 true false 0 75 30 240
Rectangle -16711681 true false 60 285 195 300
Rectangle -16711681 true false 210 150 240 240
Rectangle -16711681 true false 135 150 225 165
Polygon -16711681 true false 0 75 0 60 75 0 75 15 30 75
Polygon -16711681 true false 30 240 60 285 60 300 0 240
Polygon -16711681 true false 240 240 195 300 195 285 210 240

glucose
false
0
Polygon -8716033 true false 0 150 75 30 225 30 300 150 225 270 75 270

glycogen
false
15
Rectangle -7566196 true false 150 30 150 60
Rectangle -1 true true 30 0 45 300
Polygon -1 true true 45 255 195 135 204 145 30 285
Polygon -1 true true 46 175 196 55 205 65 31 205
Polygon -1 true true 48 93 155 13 160 24 33 123
Polygon -1 true true 70 252 210 250 209 236 84 238
Polygon -1 true true 117 207 240 206 237 191 131 193
Polygon -1 true true 65 176 128 175 127 161 79 162
Polygon -1 true true 132 119 195 118 194 104 146 105
Polygon -1 true true 56 98 119 97 118 83 70 84
Polygon -1 true true 106 61 169 60 168 46 120 47
Polygon -1 true true 40 47 83 19 75 4 38 31

house
false
0
Rectangle -7566196 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7566196 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

insulin
false
0
Rectangle -65536 true false 75 0 225 30
Rectangle -65536 true false 75 270 225 300
Rectangle -65536 true false 135 30 165 270

leaf
false
0
Polygon -7566196 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7566196 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7566196 true 150 0 150 300

pentagon
false
0
Polygon -7566196 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7566196 true true 110 5 80
Polygon -7566196 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7566196 true true 127 79 172 94
Polygon -7566196 true true 195 90 240 150 225 180 165 105
Polygon -7566196 true true 105 90 60 150 75 180 135 105

phos-kinase
false
5
Polygon -11352576 true true 0 105 0 210 300 210 300 105 240 105 210 135 180 135 165 105 135 105 120 135 75 135 45 105

plant
false
0
Rectangle -7566196 true true 135 90 165 300
Polygon -7566196 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7566196 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7566196 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7566196 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7566196 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7566196 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7566196 true true 135 90 120 45 150 15 180 45 165 90

prot-kinase
false
5
Polygon -11352576 true true 0 105 0 210 300 210 300 105 240 105 210 135 180 135 165 105 135 105 120 135 75 135 45 105

receptor
false
0
Polygon -7566196 true true 0 300 15 210 75 150 210 150 285 210 300 300

square
false
0
Rectangle -7566196 true true 30 30 270 270

square 2
false
0
Rectangle -7566196 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7566196 true true 60 270 150 0 240 270 15 105 285 105
Polygon -7566196 true true 75 120 105 210 195 210 225 120 150 75

target
false
0
Circle -7566196 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7566196 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7566196 true true 120 120 60

tree
false
0
Circle -7566196 true true 118 3 94
Rectangle -6524078 true false 120 195 180 300
Circle -7566196 true true 65 21 108
Circle -7566196 true true 116 41 127
Circle -7566196 true true 45 90 120
Circle -7566196 true true 104 74 152

triangle
false
0
Polygon -7566196 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7566196 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7566196 true true 4 45 195 187
Polygon -7566196 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7566196 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7566196 false true 24 174 42
Circle -7566196 false true 144 174 42
Circle -7566196 false true 234 174 42

turtle
true
0
Polygon -11352576 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -11352576 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -11352576 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -11352576 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -11352576 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7566196 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7566196 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7566196 true 150 285 150 15
Line -7566196 true 15 150 285 150
Circle -7566196 true true 120 120 60
Line -7566196 true 216 40 79 269
Line -7566196 true 40 84 269 221
Line -7566196 true 40 216 269 79
Line -7566196 true 84 40 221 269

x
false
0
Polygon -7566196 true true 270 75 225 30 30 225 75 270
Polygon -7566196 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 2.1.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
