; NetLogo Model: josephson-cooperative :: Version: 0.4.3 (21 Oct 2003)
; Author: S. Maggi :: NetLogo version: 1.3.1 (for Mac OS X)
; -----------------------------------------------------------------------------

; Global variables:
;    population = turtle population (equal to the width of the graphics window)
;    pi2        = 2 x 3.14159...
;
; Variables belonging to each turtle:
;    tau    = current simulation time
;    phi    = phase difference at time tau
;    phidot = derivative of the phase at time tau

globals     [population pi2]
turtles-own [tau phi phidot]


; Setup of simulation: clears Graphics window, sets some constants and defines
; characteristics of turtle population
to setup
   clear-all

   set pi2    2 * pi
   set plot?  false

; The turtle population is set equal to the total width of the Graphics window
   set population screen-size-x
   create-turtles population

; Turtle setup: the initial coordinates of the turtles are:
; [x = -screen-edge-x, -screen-edge-x + 1, ... +screen-edge-x;  y = 0],
; i.e., the turtles are distributed along the y = 0 axis of the Graphics window
   ask turtles [set tau    0.0
                set phi    phi-0
                set phidot phidot-0
                set color yellow
                set heading 0
                setxy (who - screen-edge-x) 0
               ]
   setup-plot
end


; Default simulation parameters (set by pressing the Default params button)
to default
   set dtau      0.1
   set phi-0     0.0
   set phidot-0  0.0

   set alpha-dc  0.0
   set beta-c    0.1
   set alpha-rf  0.0
   set omega-rf  0.0

   set slowdown  0
   set y-ampl    5
end


; Main simulation loop
to go
   without-interruption [solve-diff-eq
                         if plot? [do-plot]
                         wait (slowdown / 500)
                        ]
end


; Solve the 2nd order differential equation using a finite difference method
to solve-diff-eq
   locals [who-1 who+1 ntc
           tau_n phi_n phi_n+1
           phidot_n phidot_n+1
          ]

   set ntc (dtau / beta-c)

   without-interruption
      [set who-1    who-of    turtle ( (who - 1) mod screen-size-x )
       set who+1    who-of    turtle ( (who + 1) mod screen-size-x )
       set tau_n    tau-of    turtle    who
       set phi_n    phi-of    turtle    who
       set phidot_n phidot-of turtle    who

; this finite-difference method does not work because of numerical instabilities
    ;locals [phi_n-1]
    ;set phi_n-1  phi-of  turtle who-1
    ;set phi_n+1  ( (2 * beta-c + dtau) * phi_n - (beta-c) * phi_n-1 + (dtau ^ 2) * (alpha-dc + alpha-rf * sin (rad-to-deg (tau_n * omega-rf) ) - sin (rad-to-deg phi_n) ) ) / (beta-c + dtau)

; this finite-difference method works!
       set phidot_n+1 (1 - ntc) * phidot_n + ntc * ( alpha-dc + alpha-rf * sin (rad-to-deg (omega-rf * tau_n)) - sin (rad-to-deg (phi_n)) )
       set phi_n+1    (phi_n + phidot_n+1 * dtau)

       ask turtle who+1 [set tau    (tau_n + dtau)
                         set phi    (phi_n+1) mod pi2
                         set phidot (phidot_n+1)
                         set ycor   (y-ampl * phidot)
                        ]
      ]
end


; This procedure converts an angle from radians to degrees (as used by NetLogo).
;   input: 'angle' in radians
;   report: angle converted to degrees
to-report rad-to-deg [angle]
   report angle * 360 / pi2
end

; This procedure sets up the phase-space plot
to setup-plot
   set-current-plot "Phase space"
   auto-plot-on
   set-plot-x-range  -3.2  3.2
   set-plot-y-range  -1.0  1.0
   set-plot-pen-mode  2
   set-plot-pen-color blue
end

to do-plot
   set-current-plot "Phase space"
   plotxy (phi mod pi2 - pi) phidot
; one could also plot the cosine of phi instead of phi
;   plotxy cos (rad-to-deg phi) phidot
end

to reset-plot
   setup-plot
   plot-pen-reset
   set plot? false
end
@#$#@#$#@
GRAPHICS-WINDOW
210
30
621
365
200
150
1.0
1
10
0
0

TEXTBOX
20
20
180
38
Simulation settings:

SLIDER
15
40
185
73
dtau
dtau
0.0020
0.2
0.1
0.0020
1
NIL

SLIDER
15
80
185
113
phi-0
phi-0
0
6.4
0.0
0.2
1
NIL

SLIDER
15
120
185
153
phidot-0
phidot-0
0
6.4
0.0
0.2
1
NIL

TEXTBOX
20
180
180
198
Junction parameters:

SLIDER
15
200
185
233
alpha-dc
alpha-dc
-10
10
0.0
0.1
1
NIL

SLIDER
15
240
185
273
beta-c
beta-c
0.1
2.5
0.1
0.2
1
NIL

SLIDER
15
290
185
323
alpha-rf
alpha-rf
0
10
0.0
0.1
1
NIL

SLIDER
15
330
185
363
omega-rf
omega-rf
0
5
0.0
0.0050
1
NIL

BUTTON
210
385
300
418
Setup
setup
NIL
1
T
OBSERVER

BUTTON
210
425
300
458
Default params
default
NIL
1
T
OBSERVER

BUTTON
310
385
400
418
Start/Stop
go
T
1
T
TURTLE

BUTTON
310
425
400
458
Single step
go
NIL
1
T
TURTLE

SLIDER
420
385
512
418
y-ampl
y-ampl
1
50
5
1
1
x

SLIDER
420
425
512
458
slowdown
slowdown
0
2
0.0
0.1
1
NIL

SWITCH
530
385
620
418
plot?
plot?
1
1
-1000

BUTTON
530
425
620
458
Reset plot
reset-plot
NIL
1
T
OBSERVER

PLOT
645
40
845
190
Phase space
phi
phidot
0.0
100.0
0.0
100.0
true
false

CC-WINDOW
645
385
845
460
Command Center

@#$#@#$#@
ABSTRACT
--------

	NetLogo has been used here to solve a typical numerical problem, namely a non-linear differential equation. In this case the interacting agents are simply the solutions of the equation at previous time steps. The equation considered here describes the behavior of a superconducting Josephson junction, however it should be simple to adapt the program to different differential equations.
A full report of the present project is in preparation and paper and web-based references to it will be added to the documentation as soon as possible [Maggi03].


WHAT IS IT?
-----------

	A Josephson junction is a superconducting electronic device based on the tunneling of Cooper pairs across two weakly coupled superconductors. Besides its current practical applications, the Josephson junction is important from a physical point of view because it has been the first device showing quantum mechanical effects on a macroscopic scale.

	According to quantum mechanics, a single electron has a small but finite probability to tunnel through a potential barrier higher than its kinetic energy. In a Josephson junction, however, also pairs of electrons ("Cooper" pairs) can tunnel through the barrier, usually made by a thin oxide barrier (1-2 nm) sandwiched between two superconducting films. The physical reason is that the two superconductors are so close together that the wavefunctions of the Cooper pairs of the films overlap and the system behaves as a single "weak" superconductor.

	What is observed experimentally is the flow of a current across the junction with no voltage drop (V = 0), at least until the current reaches a "critical" value Ic. When the current is further increased, also single electrons originated by the breaking up of the Cooper pairs begin to tunnel the barrier. Therefore, the potential difference V between the two superconducting films becomes  0 and a state is reached where the junction behaves as a resistance, Rn.
Further details about the basics of the Josephson effect at an undergraduate level can be found in [Langenberg66], [Anderson70].

	The behavior of a Josephson junction can be modeled by a simple equivalent circuit consisting of the parallel connection of a resistance R, a capacitance C and a Josephson supercurrent Ic sin(phi), where phi is the phase difference of the wavefunctions of the Cooper pairs across the junction. The circuit is assumed to be current biased (using a dc and an rf bias) and the voltage V across the junction is proportional to the time derivative of the phase phi. The circuit resistance R is the normal state resistance Rn while C is the capacitance of the two superconducting electrodes separated by the thin oxide barrier.

	This model, known as the resistively shunted Josephson (RSJ) junction model, is accurate enough to gain a basic understanding of the junction behavior. Despite its simplicity, the empirical RSJ model is the limiting case of the complete quantum mechanical treatment of the Josephson effect. The most important aspect left out of the model is the spatial variation of the phase, which is related to the effect of a magnetic field on the junction.
The RSJ model is also able to show more advanced effects such as the chaotic phenomena observed in Josephson junctions.

	The differential equation representing the RSJ model, using the McCumber dimensionless parameters [McCumber68], is

	       d^2 phi   d phi
	beta-c ------- + ----- + sin(phi) = alpha-dc + alpha-rf sin(omega-rf tau) 	(1)
	       d tau^2   d tau

where phi is the phase difference across the junction, tau is the normalized time, beta-c is the damping parameter, alpha-dc and alpha-rf are the dc and rf current bias in units of Ic, and omega-rf is the normalized rf frequency. Eq. (1) is also the equation of motion of a damped pendulum driven by a constant torque plus an oscillatory sinusoidal torque. In this case phi represents the angle of oscillation from the vertical.

	A higher-order differential equation can always be transformed in a set of first-order coupled differential equations. In particular, (1) can be reduced to

	d y1
	----- = y2									(2a)
	d tau

	d y2      1
	----- = ------ [alpha-dc + alpha-rf sin (omega-rf tau) - y2 - sin(y1)]		(2b)
	d tau   beta-c

where y1 = phi and y2 = (d phi / d tau). These equations can easily be solved using standard numerical methods.

	Three simple algorithms have been used to solve Eqs. (2). The first is the basic Euler's method, well known for its simplicity but also for its lack of precision. The second is the second-order Runge-Kutta method: this method has been preferred to the more powerful fourth-order Runge-Kutta method because it is much simpler to implement in NetLogo and gives results precise enough for the present purposes. Both methods have been implemented in the "individual" model described in the next section. Finally, a finite difference method has been used in the "cooperative" model also described below.


HOW IT WORKS
------------

	To show that it is possible to use different approaches to write a NetLogo program, two alternative NetLogo models have been developed. In both cases, the Graphics window shows the time dependence of the derivative of the phase, phidot, which is the physically interesting quantity, being proportional to the voltage across the junction. In addition, a phase space plot, i.e. the dependence of phidot on the phase phi, can be shown (at the expense of simulation speed).

	The "individual" model shows the approach one would take using a standard programming language such as C, Fortran or Basic. The simulation starts with a single turtle. For each simulation step, the equations (2) are solved using either Euler or Runge-Kutta methods, and a new turtle is created whose (x, y) coordinates are proportional to the current simulation time, tau, and to the current value of phidot, respectively. To avoid to have too many living turtles, which would slow down the simulation and clutter the Graphics window, the turtles age and, after a finite time of living, die.

	The "cooperative" model is closer to the "proper" NetLogo approach to programming. In this case the simulation starts with a population of turtles equal to the width of the Graphics window and evenly distributed along the y = 0 axis. The x position of each turtle is kept fixed, while its y position is proportional to phidot, i.e., to the voltage across the junction, calculated using a finite-difference method. With this approach, no new turtles are created during the course of the simulation nor aging turtles die. This leads to a simpler code and speeds considerably up the simulation with respect to the "individual" model.
	In reality, this approach is weakly "cooperative", because the single turtles interact only because the vertical position of the (n+1)-th turtle is calculated knowing that of the n-th turtle. An alternative, truly cooperative approach for this model would be very interesting, and contributions are welcome.


HOW TO USE IT
-------------

	The NetLogo model interface is divided into four main areas: a set of sliders on the left change the simulation setting, while several buttons, sliders and switches on the bottom control how the simulation is run. The Graphics window shows the main result of the simulation together with the plot of the phase-space on the right. In the following all the variables will be in uppercase, to make them stand out of the main text; however in the interface window the variables are in normal lowercase.

	The top three sliders set the simulation settings: the simulation time step DTAU and the values of the initial conditions for the solution of the differential equation, PHI-0 and PHIDOT-0. The four sliders below set the main junction parameters of eq. (1), dc current bias ALPHA-DC, damping parameter BETA-C, rf current bias ALPHA-RF and normalized rf frequency OMEGA-RF.

	The button SETUP sets up the NetLogo model by creating a population of turtles equal to the width of the Graphics window and distributing them on each patch with y = 0. The procedure also clears and sets up the phase-space plot (see below). The button DEFAULT-PARAMS sets the default simulation parameters, useful to start experimenting with the model.

	In the "individual" model, the switch RUNGE-KUTTA? selects the algorithm used to solve the differential equation: when ON, the second-order Runge-Kutta method is used, when OFF the simpler Euler's method is selected. This switch is not present in the "cooperative" model, which uses only a finite-difference method to solve the differential equation.

	The button START/STOP is a forever button used to start and stop the simulation, while the button SINGLE STEP advances the simulation by one time step. The SLOWDOWN slider is used, when necessary, to slow down the simulation in order to better observe the time dipendence of the waveform.

	The Graphics window shows the dependence of PHIDOT, namely the voltage across the junction, on time TAU. Each dot in this window represents a time step and hence leads to the artifact that the waveform widens or shrinks by changing the time step DTAU. In this respect, the Graphics window works more or less like an oscilloscope (sorry, no trigger yet!) To improve the visualization of the waveform, a slider Y-AMPL has been added, that amplifies by the corresponding factor the vertical scale of the waveform.

	On the right of the model window, the phase-space plot of the simulation is shown. This is a plot of the state variables phidot vs. phi and gives a very useful insight of how they are related during the course of the simulation. Since the plot slows down the simulation considerably, it is off by default and can be activated by means of the PLOT? switch. Also, a RESET PLOT button clears the plot and resets the PLOT? switch to its off state.

	To use the model, one must first set the simulation settings and the junction parameters and then click on the SETUP and START/STOP buttons. The variation of one of the parameters during the simulation has an immediate effect on the calculated waveforms except, obviously, for the values of the initial conditions which affect the model only at the beginning of the simulation.


THINGS TO NOTICE AND TRY
------------------------

	Start the model with the default settings: PHI-0 and PHIDOT-0 = 0 and the time interval DTAU = 0.1. The parameters ALPHA-DC, ALPHA-RF and OMEGA-RF are all zero while BETA-C is set to its minimum value of 0.1. The waveform vertical amplification is 5x. In these conditions the junction has very little damping and the external current is zero. The value of SLOWDOWN depends on the speed of the computer used to run the simulation. It is better to set it initially to zero and increase its value until the waveform changes slowly enough to be clearly seen on the screen.

	Press SETUP: a yellow horizontal line should appear in the Graphics window, showing the turtles evenly distributed along the y = 0 axis. Press START/STOP: nothing seems to appear. The normalized voltage across the junction is zero and therefore all the turtles remain at their position on the y = 0 axis.

	Try to increase slowly ALPHA-DC, up to 1.0. No change in the turtle position is visible. A current of Cooper pairs is now tunneling across the junction, but the voltage remains zero because the junction is acting like a single superconductor and the current can flow with no electrical resistance and hence no voltage drop.

	Increase further ALPHA-DC just above 1.0. Small voltage spikes appear, moving relatively fast towards one side of the Graphics window, in a manner similar to an oscilloscope with a slightly incorrect trigger level. Single electrons have started to tunnel across the junction barrier along with the Cooper pairs. For them, the junction is a nonlinear resistance, and hence a finite time-dependent voltage appears across the junction electrodes.
Changing DTAU, the waveform can be made almost still, like adjusting the trigger level on the oscilloscope. The exact value of DTAU depends on the speed of the computer used to run the simulation.

	Increase ALPHA-DC further. The frequency of the spikes increases and their form becomes closer and closer to that of a sine wave. Likewise, also the level of the waveform increases, therefore the average voltage across the junction is increasing. Play with DTAU (and Y-AMPL) to experiment how the image of the waveform changes by changing these parameters.

	Reduce ALPHA-DC to 1.2. Set OMEGA-RF = 0.2 and increase ALPHA-RF slowly from 0.0 to 2.0 observing how the waveform changes because of the applied rf current. It is better to start with a relatively large value of DTAU, around 0.1. On fast machines, set SLOWDOWN to a value that allows to see clearly the resulting waveform (for example, on an 800 MHz Macintosh G3, SLOWDOWN = 0.4 - 0.6 with the phase-space plot off is adequate).
The voltage spikes, evenly spaced at ALPHA-RF = 0, seem to group and the number of spikes in each group is related to the amplitude of the rf bias, ALPHA-RF. Play with ALPHA-DC, ALPHA-RF and OMEGA-RF to observe what happens by changing these parameters.

	Finally, try **exactly** these parameters: ALPHA-DC = 2.1, BETA-C = 0.1, ALPHA-RF = 2.0, and OMEGA-RF = 1.5.
Also, set DTAU = 0.1 and Y-AMPL between 5x and 10x. The waveform is periodic, as is apparent from the phase-space plot. However, it is sufficient to increase ALPHA-DC to 2.2 and above to observe a completely different situation: the resulting waveform loses its periodicity and starts exhibiting chaos.
This is more apparent by looking at the phase-plane plot. In all the above examples, the phase-plane plots at subsequent periods of the rf bias overlap as a result of the existence of a periodic solution, while in this latter case the plot continues to change because of the chaoticity of the solution, ending up to completely filling a large region of the phase-space.
It is not possible to delve more deeply into the subject of chaos, here. The reader interested to a simple introduction to chaos in Josephson junctions can refer to [Kautz93]


EXTENDING THE MODEL
-------------------

	Among the many things that could be made to extend this model, it would be simple to add a plot of the Poincare' section of the phase-space, i.e., the values of phi and phidot at the beginning of each cycle of the rf drive. This plot provides unambiguous information about the form of the solution, whether periodic or chaotic [Kautz93].

	Another trivial modification to the model would be to change the phase-space plot, using cos(phi) vs. phidot instead of phi vs. phidot, maybe by implementing a switch that sets up properly the scales of the plot, the axis labels, etc. This provides an alternative view of the phase-space plane, with the added important benefit that a periodic solution appears in this plane as a closed overlapping curve while a chaotic solution is easily recognizable because the resulting plot fills completely a region of the phase-plane.


NETLOGO FEATURES
----------------

	NetLogo seems very useful not only for a problem with interacting agents but also for a purely numerical problem like this. The inherently parallel approach  of the NetLogo language leads to a clean and simple to understand code. Of course, for heavy numerical work, a conventional language such as Fortran or C is still preferrable, for its raw speed and also because it is possible to run the simulation in unattended tasks, possibly collecting and analyzing automatically the results.

	The real benefits of NetLogo are different: the language is very simple but also powerful and a complete simulation, comprising a fully interactive user interface, can be built with very few lines of code, making it an invaluable didactic tool or even a tool for rapid prototyping of an algorithm. The present simulation has been written with about 70 lines of code (not considering comments, blank lines and isolated square parentheses.)

	Last but not least, NetLogo is free, is evolving rapidly and works reliably under most current operating systems.

	A useful improvement to the language would be the addition of some form of structured variable, at least of arrays. For instance, the lack of arrays has lead, in the present project, to the choice of the second-order Runge-Kutta method over the better but more complicated fourth-order Runge-Kutta method.
Another nice improvement could be the implementation of some sort of a multi-windowed interface, so that different graphic views of the agent behaviour could be observed either alternatively or in parallel during the simulation run.
Finally, the developers should consider the addition of a grid to align the interface widgets and the possibility of opening several files in the same session.


CREDITS AND REFERENCES
----------------------

[Maggi03]	S. Maggi, in preparation
[Langenberg66]	D. Langenberg et al., "The Josephson Effects", Scientific American, vol. 214, pp. 30-39 (May 1966).
[Anderson70]	P. W. Anderson, "How Josephson Discovered His Effect", Physics Today, vol. 23, pp. 23-29 (1970).
[McCumber68]	D. E. McCumber, "Effect of ac Impedance on dc Voltage-Current Characteristics of Superconductor
		Weak-Link Junctions", Journal Applied Physics, vol. 39, pp. 3113-18 (1968).
[Kautz93]	R. L. Kautz, "Chaos in a Computer-Animated Pendulum", Am. J. Phys., vol. 61, pp. 407-15 (1993)
@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

ant
true
0
Polygon -7566196 true true 136 61 129 46 144 30 119 45 124 60 114 82 97 37 132 10 93 36 111 84 127 105 172 105 189 84 208 35 171 11 202 35 204 37 186 82 177 60 180 44 159 32 170 44 165 60
Polygon -7566196 true true 150 95 135 103 139 117 125 149 137 180 135 196 150 204 166 195 161 180 174 150 158 116 164 102
Polygon -7566196 true true 149 186 128 197 114 232 134 270 149 282 166 270 185 232 171 195 149 186 149 186
Polygon -7566196 true true 225 66 230 107 159 122 161 127 234 111 236 106
Polygon -7566196 true true 78 58 99 116 139 123 137 128 95 119
Polygon -7566196 true true 48 103 90 147 129 147 130 151 86 151
Polygon -7566196 true true 65 224 92 171 134 160 135 164 95 175
Polygon -7566196 true true 235 222 210 170 163 162 161 166 208 174
Polygon -7566196 true true 249 107 211 147 168 147 168 150 213 150

arrow
true
0
Polygon -7566196 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

bee
true
0
Polygon -256 true false 151 152 137 77 105 67 89 67 66 74 48 85 36 100 24 116 14 134 0 151 15 167 22 182 40 206 58 220 82 226 105 226 134 222
Polygon -16777216 true false 151 150 149 128 149 114 155 98 178 80 197 80 217 81 233 95 242 117 246 141 247 151 245 177 234 195 218 207 206 211 184 211 161 204 151 189 148 171
Polygon -7566196 true true 246 151 241 119 240 96 250 81 261 78 275 87 282 103 277 115 287 121 299 150 286 180 277 189 283 197 281 210 270 222 256 222 243 212 242 192
Polygon -16777216 true false 115 70 129 74 128 223 114 224
Polygon -16777216 true false 89 67 74 71 74 224 89 225 89 67
Polygon -16777216 true false 43 91 31 106 31 195 45 211
Line -1 false 200 144 213 70
Line -1 false 213 70 213 45
Line -1 false 214 45 203 26
Line -1 false 204 26 185 22
Line -1 false 185 22 170 25
Line -1 false 169 26 159 37
Line -1 false 159 37 156 55
Line -1 false 157 55 199 143
Line -1 false 200 141 162 227
Line -1 false 162 227 163 241
Line -1 false 163 241 171 249
Line -1 false 171 249 190 254
Line -1 false 192 253 203 248
Line -1 false 205 249 218 235
Line -1 false 218 235 200 144

bird1
false
0
Polygon -7566196 true true 2 6 2 39 270 298 297 298 299 271 187 160 279 75 276 22 100 67 31 0

bird2
false
0
Polygon -7566196 true true 2 4 33 4 298 270 298 298 272 298 155 184 117 289 61 295 61 105 0 43

boat1
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 33 230 157 182 150 169 151 157 156
Polygon -7566196 true true 149 55 88 143 103 139 111 136 117 139 126 145 130 147 139 147 146 146 149 55

boat2
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 157 54 175 79 174 96 185 102 178 112 194 124 196 131 190 139 192 146 211 151 216 154 157 154
Polygon -7566196 true true 150 74 146 91 139 99 143 114 141 123 137 126 131 129 132 139 142 136 126 142 119 147 148 147

boat3
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 37 172 45 188 59 202 79 217 109 220 130 218 147 204 156 158 156 161 142 170 123 170 102 169 88 165 62
Polygon -7566196 true true 149 66 142 78 139 96 141 111 146 139 148 147 110 147 113 131 118 106 126 71

box
true
0
Polygon -7566196 true true 45 255 255 255 255 45 45 45

butterfly1
true
0
Polygon -16777216 true false 151 76 138 91 138 284 150 296 162 286 162 91
Polygon -7566196 true true 164 106 184 79 205 61 236 48 259 53 279 86 287 119 289 158 278 177 256 182 164 181
Polygon -7566196 true true 136 110 119 82 110 71 85 61 59 48 36 56 17 88 6 115 2 147 15 178 134 178
Polygon -7566196 true true 46 181 28 227 50 255 77 273 112 283 135 274 135 180
Polygon -7566196 true true 165 185 254 184 272 224 255 251 236 267 191 283 164 276
Line -7566196 true 167 47 159 82
Line -7566196 true 136 47 145 81
Circle -7566196 true true 165 45 8
Circle -7566196 true true 134 45 6
Circle -7566196 true true 133 44 7
Circle -7566196 true true 133 43 8

circle
false
0
Circle -7566196 true true 35 35 230

person
false
0
Circle -7566196 true true 155 20 63
Rectangle -7566196 true true 158 79 217 164
Polygon -7566196 true true 158 81 110 129 131 143 158 109 165 110
Polygon -7566196 true true 216 83 267 123 248 143 215 107
Polygon -7566196 true true 167 163 145 234 183 234 183 163
Polygon -7566196 true true 195 163 195 233 227 233 206 159

sheep
false
15
Rectangle -1 true true 90 75 270 225
Circle -1 true true 15 75 150
Rectangle -16777216 true false 81 225 134 286
Rectangle -16777216 true false 180 225 238 285
Circle -16777216 true false 1 88 92

spacecraft
true
0
Polygon -7566196 true true 150 0 180 135 255 255 225 240 150 180 75 240 45 255 120 135

thin-arrow
true
0
Polygon -7566196 true true 150 0 0 150 120 150 120 293 180 293 180 150 300 150

truck-down
false
0
Polygon -7566196 true true 225 30 225 270 120 270 105 210 60 180 45 30 105 60 105 30
Polygon -8716033 true false 195 75 195 120 240 120 240 75
Polygon -8716033 true false 195 225 195 180 240 180 240 225

truck-left
false
0
Polygon -7566196 true true 120 135 225 135 225 210 75 210 75 165 105 165
Polygon -8716033 true false 90 210 105 225 120 210
Polygon -8716033 true false 180 210 195 225 210 210

truck-right
false
0
Polygon -7566196 true true 180 135 75 135 75 210 225 210 225 165 195 165
Polygon -8716033 true false 210 210 195 225 180 210
Polygon -8716033 true false 120 210 105 225 90 210

turtle
true
0
Polygon -7566196 true true 138 75 162 75 165 105 225 105 225 142 195 135 195 187 225 195 225 225 195 217 195 202 105 202 105 217 75 225 75 195 105 187 105 135 75 142 75 105 135 105

wolf
false
0
Rectangle -7566196 true true 15 105 105 165
Rectangle -7566196 true true 45 90 105 105
Polygon -7566196 true true 60 90 83 44 104 90
Polygon -16777216 true false 67 90 82 59 97 89
Rectangle -1 true false 48 93 59 105
Rectangle -16777216 true false 51 96 55 101
Rectangle -16777216 true false 0 121 15 135
Rectangle -16777216 true false 15 136 60 151
Polygon -1 true false 15 136 23 149 31 136
Polygon -1 true false 30 151 37 136 43 151
Rectangle -7566196 true true 105 120 263 195
Rectangle -7566196 true true 108 195 259 201
Rectangle -7566196 true true 114 201 252 210
Rectangle -7566196 true true 120 210 243 214
Rectangle -7566196 true true 115 114 255 120
Rectangle -7566196 true true 128 108 248 114
Rectangle -7566196 true true 150 105 225 108
Rectangle -7566196 true true 132 214 155 270
Rectangle -7566196 true true 110 260 132 270
Rectangle -7566196 true true 210 214 232 270
Rectangle -7566196 true true 189 260 210 270
Line -7566196 true 263 127 281 155
Line -7566196 true 281 155 281 192

wolf-left
false
3
Polygon -6524078 true true 117 97 91 74 66 74 60 85 36 85 38 92 44 97 62 97 81 117 84 134 92 147 109 152 136 144 174 144 174 103 143 103 134 97
Polygon -6524078 true true 87 80 79 55 76 79
Polygon -6524078 true true 81 75 70 58 73 82
Polygon -6524078 true true 99 131 76 152 76 163 96 182 104 182 109 173 102 167 99 173 87 159 104 140
Polygon -6524078 true true 107 138 107 186 98 190 99 196 112 196 115 190
Polygon -6524078 true true 116 140 114 189 105 137
Rectangle -6524078 true true 109 150 114 192
Rectangle -6524078 true true 111 143 116 191
Polygon -6524078 true true 168 106 184 98 205 98 218 115 218 137 186 164 196 176 195 194 178 195 178 183 188 183 169 164 173 144
Polygon -6524078 true true 207 140 200 163 206 175 207 192 193 189 192 177 198 176 185 150
Polygon -6524078 true true 214 134 203 168 192 148
Polygon -6524078 true true 204 151 203 176 193 148
Polygon -6524078 true true 207 103 221 98 236 101 243 115 243 128 256 142 239 143 233 133 225 115 214 114

wolf-right
false
3
Polygon -6524078 true true 170 127 200 93 231 93 237 103 262 103 261 113 253 119 231 119 215 143 213 160 208 173 189 187 169 190 154 190 126 180 106 171 72 171 73 126 122 126 144 123 159 123
Polygon -6524078 true true 201 99 214 69 215 99
Polygon -6524078 true true 207 98 223 71 220 101
Polygon -6524078 true true 184 172 189 234 203 238 203 246 187 247 180 239 171 180
Polygon -6524078 true true 197 174 204 220 218 224 219 234 201 232 195 225 179 179
Polygon -6524078 true true 78 167 95 187 95 208 79 220 92 234 98 235 100 249 81 246 76 241 61 212 65 195 52 170 45 150 44 128 55 121 69 121 81 135
Polygon -6524078 true true 48 143 58 141
Polygon -6524078 true true 46 136 68 137
Polygon -6524078 true true 45 129 35 142 37 159 53 192 47 210 62 238 80 237
Line -16777216 false 74 237 59 213
Line -16777216 false 59 213 59 212
Line -16777216 false 58 211 67 192
Polygon -6524078 true true 38 138 66 149
Polygon -6524078 true true 46 128 33 120 21 118 11 123 3 138 5 160 13 178 9 192 0 199 20 196 25 179 24 161 25 148 45 140
Polygon -6524078 true true 67 122 96 126 63 144

@#$#@#$#@
NetLogo 1.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
