;;
;;  THE AMAZING MAZE MAKER
;;
;; Maze dimentions: explained
;; path-width  = 5 = # (path-width is [1,3,5,...] )
;; gap         = 3 = . (gap is [0,1,2...] )
;; screen-edge = 16
;;  -111111100000000000000000001111111
;;   654321098765432101234567890123456
;;     #####...#####...#####...#####
;;    #####...#####...#####...#####..._
;; A  []      ( edge +
;; B  [---]
;; C  [------]
;; D    ;;
;; A = Radius (patches from center to edge, center is 0)


globals [ depth         ;; measures the number of recursive calls
          max-depth     ;; holds the peak depth
          halt          ;; if set to 1, maze-building stops
          spacing       ;; the patch distance bewteen centers of maze corridors
          z-spacing     ;; 0 - spacing
          edge-vs-spacing-x
          edge-vs-spacing-y
          maze-edge-x   ;; like screen-edge for the maze
          maze-edge-y   ;;
          blocks-x       ;; the number of maze-blocks across
          blocks-y       ;; the number of maze-blocks down
          first-x       ;; marks the lower left corner.
          first-y      ;; ""
          room-count   ;; to total maze-blocks in the grid
          radius        ;; number of patches from the center patch.
          mark-color    ;; complements the gap-color. marks unused maze blocks
          tiles         ;; patches that are stepping points on the grid
        ]

turtles-own [ stack ]
to push ; turt;e pushes current coords onto stack, before turning
    set stack fput ( list xcor ycor ) stack
end

to pop ; turtle pops previous turn point from stack
  locals [ xy ]
  set xy item 0 stack
  set stack but-first stack
  setxy (item 0 xy) (item 1 xy)
end

to setup
  clear-all
  ;; path-width is width of drawn maze path, in patches
  ;; radius should always work out to integer, but just in case...
  set radius int( ( path-width - 1 ) / 2 )
  set mark-color white

  ; spacing is distance 'tween centers of paths
  set spacing gap + path-width
  ; zero minus spacing

  set tiles patches with
  [    pxcor mod spacing = 0
   and pycor mod spacing = 0
   and abs pxcor + radius + 1 < screen-edge-x
   and abs pycor + radius + 1 < screen-edge-y
  ]

  ; the total number of blocks in the maze
  set room-count count tiles

  mark-tiles

  set halt 0
  create-walkers

end

to create-walkers
  if walkers >= 1 + room-count / 10
  [ set walkers 1 + room-count / 10 ]
  create-custom-turtles walkers
  [ pick-spot
    while [ any? other-turtles-here ]
    [ pick-spot ]
    set heading 0
    set color pen-color
    if random-orientation? [ set heading 90 * random 4 ]
    if not one-color?
    [ while [ color = pen-color or color = mark-color ]
      [ set color 3 + 10 * random 13 + random-float 5.0
      ]
    ]
    ask patches in-radius radius [ set pcolor color-of myself ]
    set stack []
    push
  ]

end

to pick-spot
    locals [ spot ]
    set spot tiles with [ not any? turtles-here ]
    ifelse any? spot
    [ set spot random-one-of spot
      set xcor pxcor-of spot
      set ycor pycor-of spot
    ]
    [ die ]
end

to mark-tiles
   ask tiles [ set pcolor mark-color ]
end


to build-maze ;; turtle procedure
  locals [ paths target left-right straight curve? running my-color]

  if halt = 1 [ stop ]
  set depth depth + 1
  if depth > max-depth [ set max-depth depth ]

   ; make list of open directions to travel
   set paths find-open-paths
   ifelse not any? paths
   [ ifelse length stack > 0
     ; if there's no where to go, pop back to the location
     ; of the previous turn, and start again from there.
     [ pop ]
     [ stop ]
   ]
   [ ; there is somewhere to go, so...
     ; first, identify the patch that is straight ahead
     set straight patch-ahead spacing
     set left-right paths with [ self != straight ]
     ; check if I should go straight, or maybe curve?
     set curve? random-float 1.0 < curvyness
     ifelse ( curve? and any? left-right )
            or not is-open straight
     [ ; I should curve, or I can't go straight.
       ; so pick a direction, avoiding picking straight.
       set target random-one-of left-right
       ; mark the destination, to help prevent another
       ; turtle from trying to go there.
       set pcolor-of target color
       ; add my current location to the list of
       ; places where I made a turn. I come back
       ; here, later.
       push
       ; turn to the new location
       set heading towards target
       ; go there!
       draw-move
     ]
     [ ; I'm supposed to go straight.
       ; so first I'll leave myself a note, so I
       ; remember that I'm going straight for a while.
       set running true
       ; While I'm running...
       while [ running ]
       [ ; mark my target patch
         set pcolor-of straight color
         ; turn to face it
         set heading towards straight
         ; go there!
         draw-move
         ; identify the next patch
         set straight patch-at ( dx * spacing) ( dy * spacing )
         ; Am I still running?
         ; if I pick a number more than the curvyness factor,
         ; and the patch ahead is clear, I'm still running!
         set running ( random-int-or-float 1.0 >= curvyness and is-open straight )
       ]
     ]
   ]
   if length stack = 0 [ stop ]
end


to-report find-open-paths
  locals [ paths path-list ]
  set paths (patches
              at-points
              (map [ (list (?1 * spacing ) (?2 * spacing) )] [ 0 0 1 -1 ] [ 1 -1 0 0 ])
             ) with [ pcolor = mark-color ]
  report paths
end


to draw-move
    locals [ my-color start-spot]
    set my-color color
    set start-spot patch-here
    ifelse radius > 0
    [ repeat spacing
      [ ask patches in-radius radius [ set pcolor my-color ] ; with [ pcolor != my-color ][ set pcolor my-color ]
        jump 1 ]
      ask patches in-radius radius [ set pcolor my-color ]
    ]
    [ repeat spacing
      [ jump 1
        set pcolor color
      ]
    ]
    ask start-spot [ ask patches in-radius radius [ set pcolor my-color - 2 ] ]
 end


to-report is-open [ a-patch ]
    report (pcolor-of a-patch = mark-color)
end


to setup-and-go
    setup
    display
    go
end

to go
    ask turtles
    [ go-turtle
    ]
end

to go-turtle
    push
    while [ length stack > 0 ]
    [ build-maze ]
end

to randomize
    set walkers 1 + random 5
    set gap random 5
    set path-width 1 + 2 * random 5
    set curvyness random-float 1.0
    setup
    go
    print max-depth
    wait 1
    if halt = 1 [ stop ]
end

@#$#@#$#@
GRAPHICS-WINDOW
196
10
509
344
50
50
3.0
0
10
1
1
1

CC-WINDOW
12
378
147
439
Command Center

BUTTON
11
10
66
43
NIL
setup
NIL
1
T
OBSERVER
T

SLIDER
11
269
183
302
pen-color
pen-color
5
135
105
10
1
NIL

SLIDER
11
233
183
266
curvyness
curvyness
0
1
0.8
0.1
1
NIL

BUTTON
125
10
180
113
halt
set halt 1
NIL
1
T
OBSERVER
T

SLIDER
11
125
183
158
walkers
walkers
1
500
3
1
1
NIL

SWITCH
11
305
183
338
random-orientation?
random-orientation?
0
1
-1000

BUTTON
68
10
123
43
go
go-turtle
NIL
1
T
TURTLE
T

SWITCH
11
341
183
374
one-color?
one-color?
1
1
-1000

SLIDER
11
161
183
194
path-width
path-width
1
10
1
2
1
NIL

SLIDER
11
197
183
230
gap
gap
0
5
5
1
1
NIL

BUTTON
11
45
123
78
setup & go
setup-and-go
NIL
1
T
OBSERVER
NIL

BUTTON
11
80
123
113
...forever varying
randomize
T
1
T
OBSERVER
T

@#$#@#$#@
WHAT IS IT?
-----------
This model builds single-path or multi-path mazes with no cross-overs.

With one walker, the maze is traversable, and any point on the maze can be reached from any other point.

If more than one "walker" is active, then multiple mazes are drawn nestled in each other. Each individual maze is traversable, but the different mazes are not connected.

HOW IT WORKS
------------
A recursive subroutine is used to implement the maze-drawing. Each walker starts at a random location, then wanders the field. With every step, the location is pushed onto the stack. When a dead-end is reached, the walker pops back to the previous turn location, and continues, until no open space remains.

To implement multiple walkers, allow the "curvyness" to be controlled, and reduce stack length for straight runs, the maze procedure has become somewhat complicated, and its basic operation hard to discern. Here is a simplified version to illustrate the basic operation:

to go
  ask turtles
  [ empty-stack
    push
    build-maze
    die
  ]
end

to build-maze
  ifelse any-open-routes
  [ push-location-to-stack
    draw-while-moving-to-open-route
    build-maze
  ]
  [ if stack-not-empty
    [ pop-from-stack
      build-maze
    ]
  ]
end


HOW TO USE IT
-------------

Click "Setup and Build-Maze" to get things started.
Click Setup to see how the maze looks before it starts drawing
Then click Build-Maze to start the maze drawing

OR, click ...forever varying. This will setup and build the maze defined by the sliders, then randomize things and build a different maze, forever. Fun to watch.

Walkers controls the number of walkers drawing the maze.

Path-width controls the width of the path, in patches.
It's an integer diameter, with a center patch, so it is always odd.

Gap controls the gap between paths.

Curviness controls the tendency to go in a straight line.
If curvyness is 0, the walker will not turn unless a wall is hit. If curvyness is 1, the walker will randomly choose a direction from the 3 directions available.

Random-Orientation controls the initial direction of the walkers. If off, walkers all start out going up.

One-color controls walker coloring. If off, the walkers are assigned random colors from an attractive palette. If on, the selected pen-color is used for all walkers.

Pen-color, Gap-Color are self-explanitory.

THINGS TO NOTICE
----------------
How does the number of walkers affect how long it takes to fill the maze?
Why do you think that is?
How does the number of walkers affect the way the maze looks?

Usually we think of the path drawn by the walkers as the maze path, and the background as the "walls" of the maze. But what happens if the width is narrow, and the gap is wide? What qualities does the maze have if we think of the drawn path as "walls" and the gaps as "corridors"? Is this maze traversable?


THINGS TO TRY
-------------
Try different numbers of walkers
Try different path-width and gap sizes
Change screen-edge-x and -y to 50 (or some other largish size), patch size to 2, walkers 10 or more. While the maze is building, slide the curviness slider back and forth, to create curvy areas and straight areas inside the maze.
Try a maze with a gap of 0.
Try a large maze with gap 0, width 1, and many walkers. The maze looks like the irregular edges of a country or city map.

EXTENDING THE MODEL
-------------------
Create a subroutine to have a turtle (mouse?) traverse the maze(s). For a single-patch path-width and gap, this is fairly easy, but might be harder for other gaps and widths.

Would a non-recursive routine work better, faster, etc? Would a non-recursive method be easier, or harder to implement?

NETLOGO FEATURES
----------------
This model takes advantage of netlogo's support for recursion.
One challenge of implementing multiple walkers was the tendency of the walkers to step on each other. Since the model uses recursion, using "without-interruption" was not an option, as that would make the first walker complete the maze by itself, on it's first "turn". Early versions of the model used several tactics, including ethernet-style collision avoidance (if other turtles near, wait a while). The problem was that marking the space as taken was among the last things the walker did, so that another walker could also mistake the space for available. The solution turned out to be simple: The moment a walker determines that a space is open, it marks the space, then does the additional steps required to draw the path to the space. This seems to have eliminated the problem of walker collisions.

CREDITS AND REFERENCES
~~~~~~~~~~~~~~~~~~~~~~
This model was inspired by the memory of a game written in BASIC for the commodore VIC-20 and published in Compute's Gazette magazine in the early 80's. I remember the game was a simple maze game, but it had a nifty maze-generator routine that my father helped me reverse-engineer and use to create other more-interesting games of my own. I remembered the gist of the algorithm, and wondered how it would work out in NetLogo. Here it is, and more.

COPYRIGHT & LICENSE
-------------------
This work is Copyright  2004 James P. Steiner.
This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/1.0/ or send a letter to Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.
@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

ant
true
0
Polygon -7566196 true true 136 61 129 46 144 30 119 45 124 60 114 82 97 37 132 10 93 36 111 84 127 105 172 105 189 84 208 35 171 11 202 35 204 37 186 82 177 60 180 44 159 32 170 44 165 60
Polygon -7566196 true true 150 95 135 103 139 117 125 149 137 180 135 196 150 204 166 195 161 180 174 150 158 116 164 102
Polygon -7566196 true true 149 186 128 197 114 232 134 270 149 282 166 270 185 232 171 195 149 186 149 186
Polygon -7566196 true true 225 66 230 107 159 122 161 127 234 111 236 106
Polygon -7566196 true true 78 58 99 116 139 123 137 128 95 119
Polygon -7566196 true true 48 103 90 147 129 147 130 151 86 151
Polygon -7566196 true true 65 224 92 171 134 160 135 164 95 175
Polygon -7566196 true true 235 222 210 170 163 162 161 166 208 174
Polygon -7566196 true true 249 107 211 147 168 147 168 150 213 150

arrow
true
0
Polygon -7566196 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

bee
true
0
Polygon -256 true false 151 152 137 77 105 67 89 67 66 74 48 85 36 100 24 116 14 134 0 151 15 167 22 182 40 206 58 220 82 226 105 226 134 222
Polygon -16777216 true false 151 150 149 128 149 114 155 98 178 80 197 80 217 81 233 95 242 117 246 141 247 151 245 177 234 195 218 207 206 211 184 211 161 204 151 189 148 171
Polygon -7566196 true true 246 151 241 119 240 96 250 81 261 78 275 87 282 103 277 115 287 121 299 150 286 180 277 189 283 197 281 210 270 222 256 222 243 212 242 192
Polygon -16777216 true false 115 70 129 74 128 223 114 224
Polygon -16777216 true false 89 67 74 71 74 224 89 225 89 67
Polygon -16777216 true false 43 91 31 106 31 195 45 211
Line -1 false 200 144 213 70
Line -1 false 213 70 213 45
Line -1 false 214 45 203 26
Line -1 false 204 26 185 22
Line -1 false 185 22 170 25
Line -1 false 169 26 159 37
Line -1 false 159 37 156 55
Line -1 false 157 55 199 143
Line -1 false 200 141 162 227
Line -1 false 162 227 163 241
Line -1 false 163 241 171 249
Line -1 false 171 249 190 254
Line -1 false 192 253 203 248
Line -1 false 205 249 218 235
Line -1 false 218 235 200 144

bird1
false
0
Polygon -7566196 true true 2 6 2 39 270 298 297 298 299 271 187 160 279 75 276 22 100 67 31 0

bird2
false
0
Polygon -7566196 true true 2 4 33 4 298 270 298 298 272 298 155 184 117 289 61 295 61 105 0 43

boat1
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 33 230 157 182 150 169 151 157 156
Polygon -7566196 true true 149 55 88 143 103 139 111 136 117 139 126 145 130 147 139 147 146 146 149 55

boat2
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 157 54 175 79 174 96 185 102 178 112 194 124 196 131 190 139 192 146 211 151 216 154 157 154
Polygon -7566196 true true 150 74 146 91 139 99 143 114 141 123 137 126 131 129 132 139 142 136 126 142 119 147 148 147

boat3
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6524078 true false 150 32 157 162
Polygon -16776961 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7566196 true true 158 37 172 45 188 59 202 79 217 109 220 130 218 147 204 156 158 156 161 142 170 123 170 102 169 88 165 62
Polygon -7566196 true true 149 66 142 78 139 96 141 111 146 139 148 147 110 147 113 131 118 106 126 71

box
true
0
Polygon -7566196 true true 45 255 255 255 255 45 45 45

butterfly1
true
0
Polygon -16777216 true false 151 76 138 91 138 284 150 296 162 286 162 91
Polygon -7566196 true true 164 106 184 79 205 61 236 48 259 53 279 86 287 119 289 158 278 177 256 182 164 181
Polygon -7566196 true true 136 110 119 82 110 71 85 61 59 48 36 56 17 88 6 115 2 147 15 178 134 178
Polygon -7566196 true true 46 181 28 227 50 255 77 273 112 283 135 274 135 180
Polygon -7566196 true true 165 185 254 184 272 224 255 251 236 267 191 283 164 276
Line -7566196 true 167 47 159 82
Line -7566196 true 136 47 145 81
Circle -7566196 true true 165 45 8
Circle -7566196 true true 134 45 6
Circle -7566196 true true 133 44 7
Circle -7566196 true true 133 43 8

circle
false
0
Circle -7566196 true true 35 35 230

person
false
0
Circle -7566196 true true 155 20 63
Rectangle -7566196 true true 158 79 217 164
Polygon -7566196 true true 158 81 110 129 131 143 158 109 165 110
Polygon -7566196 true true 216 83 267 123 248 143 215 107
Polygon -7566196 true true 167 163 145 234 183 234 183 163
Polygon -7566196 true true 195 163 195 233 227 233 206 159

sheep
false
15
Rectangle -1 true true 90 75 270 225
Circle -1 true true 15 75 150
Rectangle -16777216 true false 81 225 134 286
Rectangle -16777216 true false 180 225 238 285
Circle -16777216 true false 1 88 92

spacecraft
true
0
Polygon -7566196 true true 150 0 180 135 255 255 225 240 150 180 75 240 45 255 120 135

thin-arrow
true
0
Polygon -7566196 true true 150 0 0 150 120 150 120 293 180 293 180 150 300 150

truck-down
false
0
Polygon -7566196 true true 225 30 225 270 120 270 105 210 60 180 45 30 105 60 105 30
Polygon -8716033 true false 195 75 195 120 240 120 240 75
Polygon -8716033 true false 195 225 195 180 240 180 240 225

truck-left
false
0
Polygon -7566196 true true 120 135 225 135 225 210 75 210 75 165 105 165
Polygon -8716033 true false 90 210 105 225 120 210
Polygon -8716033 true false 180 210 195 225 210 210

truck-right
false
0
Polygon -7566196 true true 180 135 75 135 75 210 225 210 225 165 195 165
Polygon -8716033 true false 210 210 195 225 180 210
Polygon -8716033 true false 120 210 105 225 90 210

turtle
true
0
Polygon -7566196 true true 138 75 162 75 165 105 225 105 225 142 195 135 195 187 225 195 225 225 195 217 195 202 105 202 105 217 75 225 75 195 105 187 105 135 75 142 75 105 135 105

wolf
false
0
Rectangle -7566196 true true 15 105 105 165
Rectangle -7566196 true true 45 90 105 105
Polygon -7566196 true true 60 90 83 44 104 90
Polygon -16777216 true false 67 90 82 59 97 89
Rectangle -1 true false 48 93 59 105
Rectangle -16777216 true false 51 96 55 101
Rectangle -16777216 true false 0 121 15 135
Rectangle -16777216 true false 15 136 60 151
Polygon -1 true false 15 136 23 149 31 136
Polygon -1 true false 30 151 37 136 43 151
Rectangle -7566196 true true 105 120 263 195
Rectangle -7566196 true true 108 195 259 201
Rectangle -7566196 true true 114 201 252 210
Rectangle -7566196 true true 120 210 243 214
Rectangle -7566196 true true 115 114 255 120
Rectangle -7566196 true true 128 108 248 114
Rectangle -7566196 true true 150 105 225 108
Rectangle -7566196 true true 132 214 155 270
Rectangle -7566196 true true 110 260 132 270
Rectangle -7566196 true true 210 214 232 270
Rectangle -7566196 true true 189 260 210 270
Line -7566196 true 263 127 281 155
Line -7566196 true 281 155 281 192

wolf-left
false
3
Polygon -6524078 true true 117 97 91 74 66 74 60 85 36 85 38 92 44 97 62 97 81 117 84 134 92 147 109 152 136 144 174 144 174 103 143 103 134 97
Polygon -6524078 true true 87 80 79 55 76 79
Polygon -6524078 true true 81 75 70 58 73 82
Polygon -6524078 true true 99 131 76 152 76 163 96 182 104 182 109 173 102 167 99 173 87 159 104 140
Polygon -6524078 true true 107 138 107 186 98 190 99 196 112 196 115 190
Polygon -6524078 true true 116 140 114 189 105 137
Rectangle -6524078 true true 109 150 114 192
Rectangle -6524078 true true 111 143 116 191
Polygon -6524078 true true 168 106 184 98 205 98 218 115 218 137 186 164 196 176 195 194 178 195 178 183 188 183 169 164 173 144
Polygon -6524078 true true 207 140 200 163 206 175 207 192 193 189 192 177 198 176 185 150
Polygon -6524078 true true 214 134 203 168 192 148
Polygon -6524078 true true 204 151 203 176 193 148
Polygon -6524078 true true 207 103 221 98 236 101 243 115 243 128 256 142 239 143 233 133 225 115 214 114

wolf-right
false
3
Polygon -6524078 true true 170 127 200 93 231 93 237 103 262 103 261 113 253 119 231 119 215 143 213 160 208 173 189 187 169 190 154 190 126 180 106 171 72 171 73 126 122 126 144 123 159 123
Polygon -6524078 true true 201 99 214 69 215 99
Polygon -6524078 true true 207 98 223 71 220 101
Polygon -6524078 true true 184 172 189 234 203 238 203 246 187 247 180 239 171 180
Polygon -6524078 true true 197 174 204 220 218 224 219 234 201 232 195 225 179 179
Polygon -6524078 true true 78 167 95 187 95 208 79 220 92 234 98 235 100 249 81 246 76 241 61 212 65 195 52 170 45 150 44 128 55 121 69 121 81 135
Polygon -6524078 true true 48 143 58 141
Polygon -6524078 true true 46 136 68 137
Polygon -6524078 true true 45 129 35 142 37 159 53 192 47 210 62 238 80 237
Line -16777216 false 74 237 59 213
Line -16777216 false 59 213 59 212
Line -16777216 false 58 211 67 192
Polygon -6524078 true true 38 138 66 149
Polygon -6524078 true true 46 128 33 120 21 118 11 123 3 138 5 160 13 178 9 192 0 199 20 196 25 179 24 161 25 148 45 140
Polygon -6524078 true true 67 122 96 126 63 144

@#$#@#$#@
NetLogo 2.0.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
